@@ -72,10 +72,20 @@ OC.L10N.register(
     "Description: %s" : "Description: %s",
     "Where: %s" : "Where: %s",
     "%1$s via %2$s" : "%1$s via %2$s",
-    "In a %1$s on %2$s for the entire day" : "In a %1$s on %2$s for the entire day",
-    "In a %1$s on %2$s between %3$s - %4$s" : "In a %1$s on %2$s between %3$s - %4$s",
-    "In %1$s %2$s on %3$s for the entire day" : "In %1$s %2$s on %3$s for the entire day",
-    "In %1$s %2$s on %3$s between %4$s - %5$s" : "In %1$s %2$s on %3$s between %4$s - %5$s",
+    "In the past on %1$s for the entire day" : "In the past on %1$s for the entire day",
+    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["In a minute on %1$s for the entire day","In %n minutes on %1$s for the entire day"],
+    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["In a hour on %1$s for the entire day","In %n hours on %1$s for the entire day"],
+    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["In a day on %1$s for the entire day","In %n days on %1$s for the entire day"],
+    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["In a week on %1$s for the entire day","In %n weeks on %1$s for the entire day"],
+    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["In a month on %1$s for the entire day","In %n months on %1$s for the entire day"],
+    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["In a year on %1$s for the entire day","In %n years on %1$s for the entire day"],
+    "In the past on %1$s between %2$s - %3$s" : "In the past on %1$s between %2$s - %3$s",
+    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["In a minute on %1$s between %2$s - %3$s","In %n minutes on %1$s between %2$s - %3$s"],
+    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["In a hour on %1$s between %2$s - %3$s","In %n hours on %1$s between %2$s - %3$s"],
+    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["In a day on %1$s between %2$s - %3$s","In %n days on %1$s between %2$s - %3$s"],
+    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["In a week on %1$s between %2$s - %3$s","In %n weeks on %1$s between %2$s - %3$s"],
+    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["In a month on %1$s between %2$s - %3$s","In %n months on %1$s between %2$s - %3$s"],
+    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["In a year on %1$s between %2$s - %3$s","In %n years on %1$s between %2$s - %3$s"],
     "Could not generate when statement" : "Could not generate when statement",
     "Every Day for the entire day" : "Every Day for the entire day",
     "Every Day for the entire day until %1$s" : "Every Day for the entire day until %1$s",
@@ -112,12 +122,27 @@ OC.L10N.register(
     "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s",
     "On specific dates for the entire day until %1$s" : "On specific dates for the entire day until %1$s",
     "On specific dates between %1$s - %2$s until %3$s" : "On specific dates between %1$s - %2$s until %3$s",
-    "In a %1$s on %2$s" : "In a %1$s on %2$s",
-    "In a %1$s on %2$s then on %3$s" : "In a %1$s on %2$s then on %3$s",
-    "In a %1$s on %2$s then on %3$s and %4$s" : "In a %1$s on %2$s then on %3$s and %4$s",
-    "In %1$s %2$s on %3$s" : "In %1$s %2$s on %3$s",
-    "In %1$s %2$s on %3$s then on %4$s" : "In %1$s %2$s on %3$s then on %4$s",
-    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "In %1$s %2$s on %3$s then on %4$s and %5$s",
+    "In the past on %1$s" : "In the past on %1$s",
+    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["In a minute on %1$s","In %n minutes on %1$s"],
+    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["In a hour on %1$s","In %n hours on %1$s"],
+    "_In a day on %1$s_::_In %n days on %1$s_" : ["In a day on %1$s","In %n days on %1$s"],
+    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["In a week on %1$s","In %n weeks on %1$s"],
+    "_In a month on %1$s_::_In %n months on %1$s_" : ["In a month on %1$s","In %n months on %1$s"],
+    "_In a year on %1$s_::_In %n years on %1$s_" : ["In a year on %1$s","In %n years on %1$s"],
+    "In the past on %1$s then on %2$s" : "In the past on %1$s then on %2$s",
+    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["In a minute on %1$s then on %2$s","In %n minutes on %1$s then on %2$s"],
+    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["In a hour on %1$s then on %2$s","In %n hours on %1$s then on %2$s"],
+    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["In a day on %1$s then on %2$s","In %n days on %1$s then on %2$s"],
+    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["In a week on %1$s then on %2$s","In %n weeks on %1$s then on %2$s"],
+    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["In a month on %1$s then on %2$s","In %n months on %1$s then on %2$s"],
+    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["In a year on %1$s then on %2$s","In %n years on %1$s then on %2$s"],
+    "In the past on %1$s then on %2$s and %3$s" : "In the past on %1$s then on %2$s and %3$s",
+    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["In a minute on %1$s then on %2$s and %3$s","In %n minutes on %1$s then on %2$s and %3$s"],
+    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["In a hour on %1$s then on %2$s and %3$s","In %n hours on %1$s then on %2$s and %3$s"],
+    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["In a day on %1$s then on %2$s and %3$s","In %n days on %1$s then on %2$s and %3$s"],
+    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["In a week on %1$s then on %2$s and %3$s","In %n weeks on %1$s then on %2$s and %3$s"],
+    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["In a month on %1$s then on %2$s and %3$s","In %n months on %1$s then on %2$s and %3$s"],
+    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["In a year on %1$s then on %2$s and %3$s","In %n years on %1$s then on %2$s and %3$s"],
     "Could not generate next recurrence statement" : "Could not generate next recurrence statement",
     "Cancelled: %1$s" : "Cancelled: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" has been cancelled",
@@ -164,12 +189,12 @@ OC.L10N.register(
     "Second" : "Second",
     "Third" : "Third",
     "Fourth" : "Fourth",
-    "Fifty" : "Fifty",
+    "Fifth" : "Fifth",
     "Last" : "Last",
     "Second Last" : "Second Last",
     "Third Last" : "Third Last",
     "Fourth Last" : "Fourth Last",
-    "Fifty Last" : "Fifty Last",
+    "Fifth Last" : "Fifth Last",
     "Contacts" : "Contacts",
     "{actor} created address book {addressbook}" : "{actor} created address book {addressbook}",
     "You created address book {addressbook}" : "You created address book {addressbook}",
@@ -198,6 +223,7 @@ OC.L10N.register(
     "Accounts" : "Accounts",
     "System address book which holds all accounts" : "System address book which holds all accounts",
     "File is not updatable: %1$s" : "File is not updatable: %1$s",
+    "Failed to get storage for file" : "Failed to get storage for file",
     "Could not write to final file, canceled by hook" : "Could not write to final file, cancelled by hook",
     "Could not write file contents" : "Could not write file contents",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
@@ -206,7 +232,8 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "Could not rename part file to final file, cancelled by hook",
     "Could not rename part file to final file" : "Could not rename part file to final file",
     "Failed to check file size: %1$s" : "Failed to check file size: %1$s",
-    "Could not open file" : "Could not open file",
+    "Could not open file: %1$s, file does seem to exist" : "Could not open file: %1$s, file does seem to exist",
+    "Could not open file: %1$s, file doesn't seem to exist" : "Could not open file: %1$s, file doesn't seem to exist",
     "Encryption not ready: %1$s" : "Encryption not ready: %1$s",
     "Failed to open file: %1$s" : "Failed to open file: %1$s",
     "Failed to unlink: %1$s" : "Failed to unlink: %1$s",
@@ -223,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "Completed on %s",
     "Due on %s by %s" : "Due on %s by %s",
     "Due on %s" : "Due on %s",
+    "System Address Book" : "System Address Book",
+    "The system address book contains contact information for all users in your instance." : "The system address book contains contact information for all users in your instance.",
+    "Enable System Address Book" : "Enable System Address Book",
     "DAV system address book" : "DAV system address book",
     "No outstanding DAV system address book sync." : "No outstanding DAV system address book sync.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\".",
@@ -234,6 +264,10 @@ OC.L10N.register(
     "Calendars including events, details and attendees" : "Calendars including events, details and attendees",
     "Contacts and groups" : "Contacts and groups",
     "WebDAV" : "WebDAV",
+    "Absence saved" : "Absence saved",
+    "Failed to save your absence settings" : "Failed to save your absence settings",
+    "Absence cleared" : "Absence cleared",
+    "Failed to clear your absence settings" : "Failed to clear your absence settings",
     "First day" : "First day",
     "Last day (inclusive)" : "Last day (inclusive)",
     "Out of office replacement (optional)" : "Out of office replacement (optional)",
@@ -244,10 +278,9 @@ OC.L10N.register(
     "Long absence Message" : "Long absence Message",
     "Save" : "Save",
     "Disable absence" : "Disable absence",
-    "Absence saved" : "Absence saved",
-    "Failed to save your absence settings" : "Failed to save your absence settings",
-    "Absence cleared" : "Absence cleared",
-    "Failed to clear your absence settings" : "Failed to clear your absence settings",
+    "Failed to load availability" : "Failed to load availability",
+    "Saved availability" : "Saved availability",
+    "Failed to save availability" : "Failed to save availability",
     "Time zone:" : "Time zone:",
     "to" : "to",
     "Delete slot" : "Delete slot",
@@ -257,13 +290,12 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "Pick a start time for {dayName}",
     "Pick a end time for {dayName}" : "Pick a end time for {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications.",
-    "Failed to load availability" : "Failed to load availability",
-    "Saved availability" : "Saved availability",
-    "Failed to save availability" : "Failed to save availability",
     "Availability" : "Availability",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "If you configure your working hours, other people will see when you are out of office when they book a meeting.",
     "Absence" : "Absence",
     "Configure your next absence period." : "Configure your next absence period.",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Please make sure to properly set up {emailopen}the email server{linkclose}.",
     "Calendar server" : "Calendar server",
     "Send invitations to attendees" : "Send invitations to attendees",
     "Automatically generate a birthday calendar" : "Automatically generate a birthday calendar",
@@ -274,17 +306,14 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Send reminder notifications to calendar sharees as well",
     "Reminders are always sent to organizers and attendees." : "Reminders are always sent to organisers and attendees.",
     "Enable notifications for events via push" : "Enable notifications for events via push",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Please make sure to properly set up {emailopen}the email server{linkclose}.",
     "There was an error updating your attendance status." : "There was an error updating your attendance status.",
     "Please contact the organizer directly." : "Please contact the organiser directly.",
     "Are you accepting the invitation?" : "Are you accepting the invitation?",
     "Tentative" : "Tentative",
     "Your attendance was updated successfully." : "Your attendance was updated successfully.",
-    "To-dos" : "To-dos",
     "Time:" : "Time:",
+    "Could not open file" : "Could not open file",
     "Invalid chunk name" : "Invalid chunk name",
-    "Could not rename part file assembled from chunks" : "Could not rename part file assembled from chunks",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "If you configure your working hours, other users will see when you are out of office when they book a meeting."
+    "Could not rename part file assembled from chunks" : "Could not rename part file assembled from chunks"
 },
 "nplurals=2; plural=(n != 1);");
