@@ -72,8 +72,43 @@ OC.L10N.register(
     "Description: %s" : "Опис: %s",
     "Where: %s" : "Місце: %s",
     "%1$s via %2$s" : "%1$s через %2$s",
-    "Could not generate when statement" : "Неможливо створити твердження \"коли\"",
-    "Could not generate next recurrence statement" : "Неможливо створити твердження наступного повторення",
+    "Could not generate when statement" : "Не вдалося створити оператор \"коли\"",
+    "Every Day for the entire day" : "Щодня впродовж усього дня",
+    "Every Day for the entire day until %1$s" : "Щодня впродовж усього дня до %1$s",
+    "Every Day between %1$s - %2$s" : "Щодня між %1$s - %2$s",
+    "Every Day between %1$s - %2$s until %3$s" : "Щодня між %1$s- %2$sдо %3$s ",
+    "Every %1$d Days for the entire day" : "Що %1$d днів впродовж усього дня",
+    "Every %1$d Days for the entire day until %2$s" : "Що %1$d днів впродовж усього дня до %2$s",
+    "Every %1$d Days between %2$s - %3$s" : "Що %1$dднів між %2$s - %3$s",
+    "Every %1$d Days between %2$s - %3$s until %4$s" : "Що %1$d днів між %2$s - %3$s до %4$s",
+    "Could not generate event recurrence statement" : "Не вдалося створити оператор повторення події",
+    "Every Week on %1$s for the entire day" : "Щотижня в %1$s впродовж усього дня",
+    "Every Week on %1$s for the entire day until %2$s" : "Щотижня в %1$s впродовж усього дня до %2$s",
+    "Every Week on %1$s between %2$s - %3$s" : "Щотижня в %1$s між %2$s - %3$s",
+    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Щотижня в %1$s між %2$s - %3$s до %4$s ",
+    "Every %1$d Weeks on %2$s for the entire day" : "Що %1$d тижні в %2$s впродовж усього дня ",
+    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Що %1$dтижні в %2$s впродовж усього дня до %3$s",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Що %1$d тижні в %2$s між %3$s - %4$s",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Що %1$d тижні в %2$s між %3$s - %4$s до %5$s",
+    "Every Month on the %1$s for the entire day" : "Щомісяця %1$s впродовж усього дня ",
+    "Every Month on the %1$s for the entire day until %2$s" : "Щомісяця %1$s  впродовж усього дня до %2$s",
+    "Every Month on the %1$s between %2$s - %3$s" : "Щомісяця %1$s між %2$s - %3$s",
+    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Щомісяця %1$s між %2$s - %3$s до %4$s",
+    "Every %1$d Months on the %2$s for the entire day" : "Що %1$d місяці %2$s впродовж усього дня",
+    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Що %1$d місяці %2$s  впродовж усього дня до %3$s",
+    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Що %1$d місяці %2$s між %3$s - %4$s",
+    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Що %1$dмісяці %2$s між %3$s - %4$s до %5$s",
+    "Every Year in %1$s on the %2$s for the entire day" : "Щороку в %1$s, %2$s, впродовж усього дня",
+    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Щороку в %1$s, %2$s, впродовж усього дня до %3$s ",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Щороку в %1$s, %2$s, між %3$s - %4$s",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Щороку в %1$s, %2$s, між %3$s - %4$s до %5$s",
+    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Що %1$d роки в %2$s, %3$s, впродовж усього дня",
+    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Що %1$d роки в %2$s, %3$s, впродовж усього дня до %4$s",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Що %1$d роки в %2$s, %3$s, між %4$s - %5$s",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Що %1$d роки в %2$s, %3$s, між %4$s - %5$s до %6$s",
+    "On specific dates for the entire day until %1$s" : "У визначені дати впродовж усього дня до %1$s",
+    "On specific dates between %1$s - %2$s until %3$s" : "У визначені дати між %1$s - %2$s до %3$s",
+    "Could not generate next recurrence statement" : "Не вдалося створити оператор наступного повторення",
     "Cancelled: %1$s" : "Скасовано: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" скасовано",
     "Re: %1$s" : "Re: %1$s",
@@ -91,6 +126,7 @@ OC.L10N.register(
     "When:" : "Коли:",
     "Location:" : "Місцевість:",
     "Link:" : "Посилання:",
+    "Occurring:" : "Відбувається:",
     "Accept" : "Прийняти",
     "Decline" : "Відхилити",
     "More options …" : "Більше варіантів …",
@@ -114,7 +150,14 @@ OC.L10N.register(
     "October" : "Жовтень",
     "November" : "Листопад",
     "December" : "Грудень",
+    "First" : "Перший",
+    "Second" : "Другий",
+    "Third" : "Третій",
+    "Fourth" : "Четвертий",
     "Last" : "Останній",
+    "Second Last" : "Другий(-а) останній(-я)",
+    "Third Last" : "Третій(-я) останній(-я)",
+    "Fourth Last" : "Четвертий(-а) останній(-я)",
     "Contacts" : "Контакти",
     "{actor} created address book {addressbook}" : "{actor} створив(-ла) адресну книгу {addressbook}",
     "You created address book {addressbook}" : "Ви створили адресну книгу {addressbook}",
@@ -143,6 +186,7 @@ OC.L10N.register(
     "Accounts" : "Облікові записи",
     "System address book which holds all accounts" : "Системна адресна книга, в якій містяться всі облікові записи",
     "File is not updatable: %1$s" : "Файл не оновлюється: %1$s",
+    "Failed to get storage for file" : "Не вдалося отримати дані про сховище для файлу",
     "Could not write to final file, canceled by hook" : "Не вдалося записати в остаточний файл, скасовано перехопленням",
     "Could not write file contents" : "Не вдалося записати вміст файлу",
     "_%n byte_::_%n bytes_" : ["%n байт","%n байтів","%n байтів","%n байтів"],
@@ -151,7 +195,8 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "Не вдалося перейменувати файл частини на остаточний файл, скасовано підхопленням",
     "Could not rename part file to final file" : "Не вдалося перейменувати файл частини на остаточний файл",
     "Failed to check file size: %1$s" : "Не вдалося перевірити розмір файлу: %1$s",
-    "Could not open file" : "Не вдалося відкрити файл",
+    "Could not open file: %1$s, file does seem to exist" : "Неможливо відкрити файл: %1$s, хоча файл скоріше за все присутній",
+    "Could not open file: %1$s, file doesn't seem to exist" : "Неможливо відкрити файл: %1$s, скоріше за все файл відсутній",
     "Encryption not ready: %1$s" : "Шифрування не готове: %1$s",
     "Failed to open file: %1$s" : "Не вдалося відкрити файл: %1$s",
     "Failed to unlink: %1$s" : "Не вдалося від’єднати: %1$s",
@@ -159,7 +204,7 @@ OC.L10N.register(
     "File not found: %1$s" : "Файл не знайдено: %1$s",
     "Invalid target path" : "Недійсний шлях призначення",
     "System is in maintenance mode." : "Система в режимі обслуговування.",
-    "Upgrade needed" : "Потрібно оновитися",
+    "Upgrade needed" : "Потрібне оновлення",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ваш %s мусить бути налаштований на використання HTTPS для надання доступу до CalDAV і CardDAV з iOS/macOS.",
     "Configures a CalDAV account" : "Налаштовує обліковий запис CalDAV",
     "Configures a CardDAV account" : "Налаштовує обліковий запис CardDAV",
@@ -179,6 +224,10 @@ OC.L10N.register(
     "Calendars including events, details and attendees" : "Календарі, включно з подіями, деталями та відвідувачами",
     "Contacts and groups" : "Контакти та групи",
     "WebDAV" : "WebDAV",
+    "Absence saved" : "Відсутність збережено",
+    "Failed to save your absence settings" : "Не вдалося зберегти налаштуванння про відсутність",
+    "Absence cleared" : "Відсутність вилучено",
+    "Failed to clear your absence settings" : "Не вдалося скинути ваші налаштування про відсутність",
     "First day" : "Перший день",
     "Last day (inclusive)" : "Останній день (включно)",
     "Out of office replacement (optional)" : "Заміна під час відсутності (необов'язково)",
@@ -189,10 +238,9 @@ OC.L10N.register(
     "Long absence Message" : "Довге повідомлення про відсутність",
     "Save" : "Зберегти",
     "Disable absence" : "Вимкнути відсутність",
-    "Absence saved" : "Відсутність збережено",
-    "Failed to save your absence settings" : "Не вдалося зберегти налаштуванння про відсутність",
-    "Absence cleared" : "Відсутність вилучено",
-    "Failed to clear your absence settings" : "Не вдалося скинути ваші налаштування про відсутність",
+    "Failed to load availability" : "Не вдалося завантажити доступність",
+    "Saved availability" : "Збережена наявність",
+    "Failed to save availability" : "Не вдалося зберегти наявність",
     "Time zone:" : "Часовий пояс:",
     "to" : "до",
     "Delete slot" : "Вилучити діапазон",
@@ -202,13 +250,12 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "Виберіть час початку для {dayName}",
     "Pick a end time for {dayName}" : "Виберіть час завершення для {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Автоматично встановлювати статус користувача у \"Не турбувати\", коли ви не доступні. В цей проміжок часу ви не отримуватимете сповіщення.",
-    "Failed to load availability" : "Не вдалося завантажити доступність",
-    "Saved availability" : "Збережена наявність",
-    "Failed to save availability" : "Не вдалося зберегти наявність",
     "Availability" : "Доступність",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Будь ласка, налаштуйте ваші робочі години, щоб інші користувачі могли бачити, коли ви відсутні під час створення зустрічей.",
     "Absence" : "Відсутність",
     "Configure your next absence period." : "Налаштувати проміжки вашої відсутности",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Встановіть {calendarappstoreopen}застосунок Календар{linkclose}, {calendardocopen}з'єднайте ваш ноутбук та смартфон для синхронізації вашого календаря ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Будь-ласка переконайтеся у коректності налаштувань {emailopen}поштового сервера{linkclose}.",
     "Calendar server" : "Календар",
     "Send invitations to attendees" : "Надсилати запрошення учасникам",
     "Automatically generate a birthday calendar" : "Автоматично створити календар днів народження",
@@ -219,17 +266,14 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Також надсилайте нагадування користувачам вашого спільного календаря",
     "Reminders are always sent to organizers and attendees." : "Нагадування завжди надсилаються організаторам і учасникам.",
     "Enable notifications for events via push" : "Увімкнути push-сповіщення для подій",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Встановіть {calendarappstoreopen}застосунок Календар{linkclose}, {calendardocopen}з'єднайте ваш ноутбук та смартфон для синхронізації вашого календаря ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Будь-ласка переконайтеся у коректності налаштувань {emailopen}поштового сервера{linkclose}.",
     "There was an error updating your attendance status." : "Виникла помилка при оновленні вашого статусу учасника.",
     "Please contact the organizer directly." : "Будь-ласка повідомте організатора.",
     "Are you accepting the invitation?" : "Чи приймаєте ви запрошення?",
     "Tentative" : "Попередній",
     "Your attendance was updated successfully." : "Ваша участь успішно оновлена.",
-    "To-dos" : "Завдання",
     "Time:" : "Час:",
+    "Could not open file" : "Не вдалося відкрити файл",
     "Invalid chunk name" : "Недійсна назва блоку",
-    "Could not rename part file assembled from chunks" : "Не вдалося перейменувати файл частини, зібраний із фрагментів",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Будь ласка, налаштуйте ваш робочий час, щоби інші користувачі могли бачити, коли ви відсутні під час бронювання зустрічей."
+    "Could not rename part file assembled from chunks" : "Не вдалося перейменувати файл частини, зібраний із фрагментів"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
