@@ -46,6 +46,14 @@ OC.L10N.register(
     "Failed to authorize" : "Autorisierung fehlgeschlagen",
     "Invalid folder path" : "Ungültiger Order-Pfad",
     "Folder not found" : "Ordner nicht gefunden",
+    "The file cannot be found" : "Die Datei kann nicht gefunden werden",
+    "The destination path does not exist: %1$s" : "Der Zielpfad existiert nicht: %1$s",
+    "You do not have permission to create a file at the specified location" : "Keine Berechtigung, eine Datei am angegebenen Speicherort zu erstellen",
+    "The file could not be converted." : "Die Datei konnte nicht konvertiert werden.",
+    "Could not get relative path to converted file" : "Relativer Pfad zur konvertierten Datei konnte nicht ermittelt werden",
+    "Favorite files" : "Favorisierte Dateien",
+    "No favorites" : "Keine Favoriten",
+    "More favorites" : "Weitere Favoriten",
     "Upload (max. %s)" : "Hochladen (max. %s)",
     "Accept" : "Akzeptieren",
     "Reject" : "Ablehnen",
@@ -66,65 +74,63 @@ OC.L10N.register(
     "Enforce Windows compatibility" : "Windows-Kompatibilität erzwingen",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dadurch werden Dateinamen blockiert, die auf Windows-Systemen unzulässig sind, z. B. reservierte Namen oder Sonderzeichen. Die Kompatibilität der Groß-/Kleinschreibung wird dadurch jedoch nicht erzwungen.",
     "File Management" : "Dateiverwaltung",
-    "Current directory path" : "Aktueller Verzeichnispfad",
     "Home" : "Home",
     "Target folder does not exist any more" : "Zielordner existiert nicht mehr",
     "Reload current directory" : "Aktuelles Verzeichnis neu laden",
-    "Go to the \"{dir}\" directory" : "In das Verzeichnis \"{dir}“ wechseln",
-    "Drag and drop files here to upload" : "Dateien zum Hochladen hierher ziehen und ablegen",
+    "Go to the \"{dir}\" directory" : "In das Verzeichnis \"{dir}\" wechseln",
+    "Current directory path" : "Aktueller Verzeichnispfad",
     "Your have used your space quota and cannot upload files anymore" : "Dein Speicherplatzkontigent ist aufgebraucht, du kannst keine weiteren Dateien hochladen.",
-    "You don’t have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
+    "You do not have permission to upload or create files here." : "Du hast nicht die Berechtigung, hier Dateien hochzuladen oder zu erstellen.",
+    "Drag and drop files here to upload" : "Dateien zum Hochladen hierher ziehen und ablegen",
     "Favorite" : "Favorit",
-    "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" erfolgreich ausgeführt",
-    "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
+    "Back" : "Zurück",
     "Toggle selection for file \"{displayName}\"" : "Auswahl für die Datei \"{displayName}\" umschalten",
     "Toggle selection for folder \"{displayName}\"" : "Auswahl für den Ordner \"{displayName}\" umschalten",
     "File is loading" : "Datei wird geladen",
     "Folder is loading" : "Ordner wird geladen",
-    "Rename file" : "Datei umbenennen",
     "Filename" : "Dateiname",
     "Folder name" : "Ordnername",
     "This node is unavailable" : "Dieser Knoten ist nicht verfügbar.",
     "Another entry with the same name already exists." : "Ein anderer Eintrag mit diesem Namen existiert bereits.",
     "Invalid filename." : "Ungültiger Dateiname.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" in \"{newName}\" umbenannt",
+    "Rename file" : "Datei umbenennen",
     "Pending" : "Ausstehend",
+    "Unknown date" : "Unbekanntes Datum",
     "Clear filter" : "Filter zurücksetzen",
     "Modified" : "Geändert",
     "Type" : "Typ",
     "Active filters" : "Aktive Filter",
     "Remove filter" : "Filter entfernen",
     "Total rows summary" : "Zusammenfassung aller Zeilen",
+    "Toggle selection for all files and folders" : "Auswahl für alle Dateien und Ordner umschalten",
     "Name" : "Name",
     "Size" : "Größe",
-    "Toggle selection for all files and folders" : "Auswahl für alle Dateien und Ordner umschalten",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
+    "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" erfolgreich ausgeführt",
+    "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
     "Actions" : "Aktionen",
     "(selected)" : "(ausgewählt)",
-    "\"{displayName}\" failed on some elements " : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
-    "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" erfolgreich ausgeführt",
-    "{count} selected" : "{count} ausgewählt",
     "List of files and folders." : "Liste der Dateien und Ordner",
+    "You have used your space quota and cannot upload files anymore." : "Dein Speicherplatzkontigent ist aufgebraucht, Du kannst keine weiteren Dateien hochladen.",
     "Column headers with buttons are sortable." : "Spaltenüberschriften mit Schaltflächen sind sortierbar.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Diese Liste wird aus Performance-Gründen nicht vollständig angezeigt. Die Dateien werden angezeigt, wenn du durch die Liste navigierst.",
     "File not found" : "Datei nicht gefunden",
-    "Storage information" : "Speicherinformation",
-    "Storage quota" : "Speicherkontingent",
+    "{count} selected" : "{count} ausgewählt",
     "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
     "{used} of {quota} used" : "{used} von {quota} verwendet",
     "{relative}% used" : "{relative}% verwendet",
     "Could not refresh storage stats" : "Die Speicherstatistik konnte nicht aktualisiert werden",
-    "Your storage is full, files can not be updated or synced anymore!" : "Dein Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
-    "Create" : "Erstellen",
+    "Your storage is full, files can not be updated or synced anymore!" : "Der Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
+    "Storage information" : "Speicherinformation",
+    "Storage quota" : "Speicherkontingent",
     "New folder" : "Neuer Ordner",
     "Create new folder" : "Neuen Ordner erstellen",
     "This name is already in use." : "Dieser Name wird bereits verwendet.",
+    "Create" : "Erstellen",
     "Fill template fields" : "Vorlagenfelder ausfüllen",
-    "Submitting fields…" : "Felder werden übermittelt…",
+    "Submitting fields …" : "Felder werden übermittelt …",
     "Submit" : "Übermitteln",
-    "Transfer ownership of a file or folder" : "Besitz einer Datei oder eines Ordners übertragen",
-    "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
-    "Change" : "Ändern",
-    "New owner" : "Neuer Besitzer",
     "Choose a file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
     "Transfer" : "Übertragen",
     "Transfer {path} to {userid}" : "Übertrage {path} an {userid}",
@@ -132,31 +138,48 @@ OC.L10N.register(
     "Unknown error" : "Unbekannter Fehler",
     "Ownership transfer request sent" : "Anforderung für die Übertragung des Besitzes gesendet",
     "Cannot transfer ownership of a file or folder you do not own" : "Der Besitz an einer Datei oder einem Ordner, der dir nicht gehört, kann nicht übertragen werden",
+    "Transfer ownership of a file or folder" : "Besitz einer Datei oder eines Ordners übertragen",
+    "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
+    "Change" : "Ändern",
+    "New owner" : "Neuer Besitzer",
+    "Keep {old}" : "{old} behalten",
+    "Keep without extension" : "Ohne Erweiterung behalten",
+    "Use {new}" : "{new} verwenden",
+    "Remove extension" : "Dateierweiterung entfernen",
+    "Change file extension" : "Dateierweiterungen ändern",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Ändern der Dateierweiterung von \"{old}\" zu \"{new}\" kann dazu führen, dass die Datei unlesbar wird.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "Entfernen der Dateierweiterung \"{old}\" kann dazu führen, dass die Datei unlesbar wird.",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "Hinzufügen der Dateierweiterung \"{new}\" kann dazu führen, dass die Datei unlesbar wird.",
+    "Do not show this dialog again." : "Diesen Dialog nicht mehr anzeigen.",
     "Select file or folder to link to" : "Datei oder Ordner zum Verknüpfen auswählen",
     "Choose {file}" : "{file} auswählen",
-    "Loading current folder" : "Lade aktuellen Ordner",
-    "Retry" : "Wiederholen",
-    "No files in here" : "Keine Dateien vorhanden",
-    "Upload some content or sync with your devices!" : "Lade Inhalte hoch oder synchronisiere sie mit deinen Geräten!",
-    "Go back" : "Zurückgehen",
     "Share" : "Teilen",
     "Shared by link" : "Über einen Link geteilt",
     "Shared" : "Geteilt",
     "Switch to list view" : "Zur Listenansicht wechseln",
     "Switch to grid view" : "Zur Rasteransicht wechseln",
+    "The file could not be found" : "Die Datei konnte nicht gefunden werden",
     "Upload was cancelled by user" : "Das Hochladen wurde vom Benutzer abgebrochen.",
     "Not enough free space" : "Nicht genügend freier Speicherplatz",
     "Operation is blocked by access control" : "Vorgang wird durch die Zugangskontrolle blockiert",
     "Error during upload: {message}" : "Fehler beim Hochladen: {message}",
     "Error during upload, status code {status}" : "Fehler beim Hochladen, Statuscode {status}",
     "Unknown error during upload" : "unbekannte Fehler während des Hochladens",
-    "Filter filenames…" : "Dateinamen filtern…",
+    "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" erfolgreich ausgeführt",
+    "Loading current folder" : "Lade aktuellen Ordner",
+    "Retry" : "Wiederholen",
+    "No files in here" : "Keine Dateien vorhanden",
+    "Upload some content or sync with your devices!" : "Lade Inhalte hoch oder synchronisiere sie mit deinen Geräten!",
+    "Go back" : "Zurückgehen",
+    "Filter file names …" : "Dateinamen filtern …",
     "Views" : "Ansichten",
     "Files settings" : "Dateien-Einstellungen",
-    "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Die Datei konnte nicht gefunden werden oder Du hast keine Berechtigung, um sie anzuzeigen. Bitte den Absender, die Datei zu teilen.",
     "Your files" : "Deine Dateien",
     "Open in files" : "In Dateien öffnen",
+    "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Die Datei konnte nicht gefunden werden oder Du hast keine Berechtigung, um sie anzuzeigen. Bitte den Absender, die Datei zu teilen.",
+    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
+    "WebDAV URL copied to clipboard" : "WebDAV-URL in die Zwischenablage kopiert",
     "Sort favorites first" : "Favoriten zuerst sortieren",
     "Sort folders before files" : "Ordner vor Dateien sortieren",
     "Show hidden files" : "Versteckte Dateien anzeigen",
@@ -169,21 +192,57 @@ OC.L10N.register(
     "Copy to clipboard" : "In die Zwischenablage kopieren",
     "Use this address to access your Files via WebDAV" : "Diese Adresse benutzen, um über WebDAV auf deine Dateien zuzugreifen",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Wenn du 2FA aktiviert hast, musst du ein neues App-Passwort erstellen und verwenden, indem du hier klickst.",
-    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
-    "WebDAV URL copied to clipboard" : "WebDAV-URL in die Zwischenablage kopiert",
-    "Owner" : "Besitzer",
-    "Remove from favorites" : "Von Favoriten entfernen",
-    "Add to favorites" : "Zu den Favoriten hinzufügen",
-    "Tags" : "Schlagworte",
+    "Warnings" : "Warnungen",
+    "Prevent warning dialogs from open or reenable them." : "Öffnen von Warndialogen verhindern oder diese erneut aktivieren.",
+    "Show a warning dialog when changing a file extension." : "Beim Ändern einer Dateierweiterung einen Warndialog anzeigen.",
+    "Keyboard shortcuts" : "Tastaturkürzel",
+    "Speed up your Files experience with these quick shortcuts." : "Mit diesen Schnellzugriffen schneller mit Dateien arbeiten.",
+    "Open the actions menu for a file" : "Aktionsmenü für eine Datei öffnen",
+    "Rename a file" : "Eine Datei umbenennen",
+    "Delete a file" : "Eine Datei löschen",
+    "Favorite or remove a file from favorites" : "Datei favorisieren oder aus den Favoriten entfernen",
+    "Manage tags for a file" : "Schlagworte für eine Datei verwalten",
+    "Selection" : "Auswahl",
+    "Select all files" : "Alle Dateien auswählen",
+    "Deselect all files" : "Auswahl aller Dateien aufheben",
+    "Select or deselect a file" : "Auswählen oder Auswahl einer Datei aufheben",
+    "Select a range of files" : "Einen Bereich von Dateien auswählen",
+    "Navigation" : "Navigation",
+    "Navigate to the parent folder" : "In den übergeordneten Ordner navigieren",
+    "Navigate to the file above" : "Zur obigen Datei navigieren",
+    "Navigate to the file below" : "Zur unteren Datei navigieren",
+    "Navigate to the file on the left (in grid mode)" : "Zur Datei links navigieren (In der Kachelansicht)",
+    "Navigate to the file on the right (in grid mode)" : "Zur Datei rechts navigieren (In der Kachelansicht)",
+    "View" : "Ansehen",
+    "Toggle the grid view" : "Kachelansicht umschalten",
+    "Open the sidebar for a file" : "Seitenleiste für eine Datei öffnen",
+    "Show those shortcuts" : "Diese Tastaturkürzel anzeigen",
     "You" : "Du",
     "Shared multiple times with different people" : "Mehrmals mit verschiedenen Personen geteilt",
-    "Unable to change the favourite state of the file" : "Der favorisierte Status der Datei konnte nicht geändert werden",
     "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
+    "Owner" : "Besitzer",
+    "Remove from favorites" : "Aus Favoriten entfernen",
+    "Add to favorites" : "Zu den Favoriten hinzufügen",
+    "Tags" : "Schlagworte",
+    "Blank" : "Leer",
+    "Unable to create new file from template" : "Neue Datei konnte nicht aus Vorlage erstellt werden",
     "Pick a template for {name}" : "Eine Vorlage für {name} wählen",
     "Create a new file with the selected template" : "Eine neue Datei anhand der ausgewählten Vorlage erstellen",
     "Creating file" : "Datei erstellen",
-    "Blank" : "Leer",
-    "Unable to create new file from template" : "Neue Datei konnte nicht aus Vorlage erstellt werden",
+    "Save as {displayName}" : "Speichern als {displayName}",
+    "Save as …" : "Speichern als …",
+    "Converting files …" : "Dateien werden konvertiert …",
+    "Failed to convert files: {message}" : "Fehler beim Konvertieren der Dateien: {message}",
+    "All files failed to be converted" : "Alle Dateien konnten nicht konvertiert werden",
+    "One file could not be converted: {message}" : "Eine Datei konnte nicht konvertiert werden: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["Eine Datei konnte nicht konvertiert werden","%n Dateien konnten nicht konvertiert werden"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Eine Datei erfolgreich konvertiert","%n Dateien erfolgreich konvertiert"],
+    "Files successfully converted" : "Dateien erfolgreich konvertiert",
+    "Failed to convert files" : "Dateien konnten nicht konvertiert werden",
+    "Converting file …" : "Datei wird konvertiert …",
+    "File successfully converted" : "Datei erfolgreich konvertiert",
+    "Failed to convert file: {message}" : "Fehler beim Konvertieren der Datei: {message}",
+    "Failed to convert file" : "Datei konnte nicht konvertiert werden",
     "Deletion cancelled" : "Löschen abgebrochen",
     "Leave this share" : "Diese Freigabe verlassen",
     "Leave these shares" : "Diese Freigaben verlassen",
@@ -200,12 +259,6 @@ OC.L10N.register(
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Sie sind dabei, {count} Element zu löschen","Du bist dabei, {count} Elemente zu löschen."],
     "Confirm deletion" : "Löschen bestätigen",
     "Cancel" : "Abbrechen",
-    "Edit file locally" : "Datei lokal bearbeiten",
-    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Die Datei sollte sich jetzt auf Ihrem Gerät öffnen. Wenn dies nicht der Fall ist, überprüfe, ob Du die Desktop-App installiert hast.",
-    "Retry and close" : "Erneut versuchen und schließen",
-    "Edit online" : "Online bearbeiten",
-    "Failed to redirect to client" : "Umleitung zum Client fehlgeschlagen",
-    "Edit locally" : "Lokal bearbeiten",
     "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden.",
@@ -223,9 +276,15 @@ OC.L10N.register(
     "Move or copy operation failed" : "Verschiebe- oder Kopieroperation ist fehlgeschlagen.",
     "Move or copy" : "Verschieben oder kopieren",
     "Cancelled move or copy of \"{filename}\"." : "Verschieben oder Kopieren von \"{filename}\" abgebrochen.",
-    "Cancelled move or copy operation" : "Verschieben oder kopieren abgebrochen",
+    "Cancelled move or copy operation" : "Verschieben oder Kopieren abgebrochen",
     "Open folder {displayName}" : "Ordner {displayName} öffnen",
-    "Open in Files" : "In App \"Dateien\" öffnen",
+    "Open in Files" : "In \"Dateien\" öffnen",
+    "Open file locally" : "Datei lokal öffnen",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Die Datei sollte sich jetzt auf deinem Gerät öffnen. Wenn dies nicht der Fall ist, überprüfe, ob du die Desktop-App installiert hast.",
+    "Retry and close" : "Erneut versuchen und schließen",
+    "Open online" : "Online öffnen",
+    "Failed to redirect to client" : "Umleitung zum Client fehlgeschlagen",
+    "Open locally" : "Lokal öffnen",
     "Rename" : "Umbenennen",
     "Open details" : "Details öffnen",
     "View in folder" : "In Ordner anzeigen",
@@ -242,7 +301,7 @@ OC.L10N.register(
     "Audio" : "Audio",
     "Photos and images" : "Fotos und Bilder",
     "Videos" : "Videos",
-    "New folder creation cancelled" : "Erstellung des neuen Ordners abgrebrochen",
+    "New folder creation cancelled" : "Erstellung des neuen Ordners abgebrochen",
     "Created new folder \"{name}\"" : "Neuer Ordner \"{name}\" wurde erstellt",
     "Unable to initialize the templates directory" : "Der Vorlagenordner konnte nicht initialisiert werden",
     "Create templates folder" : "Vorlagenordner erstellen",
@@ -254,17 +313,17 @@ OC.L10N.register(
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Dein Browser unterstützt die Dateisystem-API nicht. Verzeichnisse werden nicht hochgeladen.",
     "No files to upload" : "Keine Dateien zum Hochladen",
     "Unable to create the directory {directory}" : "Der Ordner {directory} konnte nicht erstellt werden",
-    "Some files could not be uploaded" : "Einige Dateien konnten nicht hochgeladen werden.",
+    "Some files could not be uploaded" : "Einige Dateien konnten nicht hochgeladen werden",
     "Files uploaded successfully" : "Dateien hochgeladen",
     "No files to process" : "Keine Dateien zum Verarbeiten",
     "Some files could not be copied" : "Einige Dateien konnten nicht kopiert werden",
     "Some files could not be moved" : "Einige Dateien konnten nicht verschoben werden.",
     "Files copied successfully" : "Dateien kopiert",
     "Files moved successfully" : "Dateien verschoben",
-    "Conflicts resolution skipped" : "Konfliktelösung übersprungen",
+    "Conflicts resolution skipped" : "Konfliktlösung übersprungen",
     "Upload cancelled" : "Hochladen abgebrochen",
     "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte die Logdateien überprüfen oder den Administrator kontaktieren.",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte die Logdateien überprüfen oder die Administration kontaktieren.",
     "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
     "Unexpected error: {error}" : "Unerwarteter Fehler: {error}",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} Ordner","{folderCount} Ordner"],
@@ -273,7 +332,7 @@ OC.L10N.register(
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} Datei und 1 Ordner","{fileCount} Dateien und 1 Ordner"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} Dateien und {folderCount} Ordner",
     "Filename must not be empty." : "Dateiname darf nicht leer sein.",
-    "\"{char}\" is not allowed inside a filename." : "\"{char}“ ist innerhalb eines Dateinamens nicht zulässig.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ist innerhalb eines Dateinamens nicht zulässig.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" ist ein reservierter Name und für Dateinamen nicht zulässig.",
     "\"{extension}\" is not an allowed filetype." : "\"{extension}\" ist kein zulässiger Dateityp.",
     "Filenames must not end with \"{extension}\"." : "Dateinamen dürfen nicht mit \"{extension}\" enden.",
@@ -283,7 +342,7 @@ OC.L10N.register(
     "All files" : "Alle Dateien",
     "List of your files and folders." : "Liste deiner Dateien und Ordner",
     "All folders" : "Alle Ordner",
-    "Personal Files" : "Persönliche Dateien",
+    "Personal files" : "Persönliche Dateien",
     "List of your files and folders that are not shared." : "Liste deiner Dateien und Ordner, die nicht geteilt wurden.",
     "No personal files found" : "Keine persönlichen Dateien gefunden",
     "Files that are not shared will show up here." : "Dateien, die nicht geteilt wurden, werden hier angezeigt.",
@@ -291,7 +350,6 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Liste der zuletzt geänderten Dateien und Ordner",
     "No recently modified files" : "Keine kürzlich geänderten Dateien",
     "Files and folders you recently modified will show up here." : "Die von dir kürzlich geänderten Dateien und Ordner werden hier angezeigt.",
-    "You do not have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
     "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
     "Select all" : "Alle auswählen",
     "Upload too large" : "Der Upload ist zu groß",
@@ -319,10 +377,11 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Fehler beim Zusammenführen der Teile (Chunks), Fehlermeldung {status}",
     "Choose target folder" : "Zielordner wählen",
     "Set reminder" : "Erinnerung erstellen",
+    "Edit locally" : "Lokal bearbeiten",
     "Open" : "Öffnen",
     "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
     "Details" : "Details",
-    "Please select tag(s) to add to the selection" : "Bitte wähle das/die Schlagwort(e) aus, das/die du zur Auswahl hinzufügen möchtest",
+    "Please select tag(s) to add to the selection" : "Bitte das/die Schlagwort(e) auswählen, das/die zur Auswahl hinzugefügt werden soll(en)",
     "Apply tag(s) to selection" : "Schlagwort(e) auf die Auswahl anwenden",
     "Select directory \"{dirName}\"" : "Verzeichnis \"{dirName}\" auswählen",
     "Select file \"{fileName}\"" : "Datei \"{fileName}\" auswählen",
@@ -336,7 +395,7 @@ OC.L10N.register(
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} und {nbfiles} weitere Dateien wurden nach {destination} kopiert",
     "{newName} already exists" : "{newName} existiert bereits",
     "Could not rename \"{fileName}\", it does not exist any more" : "Die Datei \"{fileName}\" konnte nicht umbenannt werden, da sie nicht mehr existiert",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name „{targetName}“ wird bereits im Ordner „{dir}“ benutzt. Bitte einen anderen Namen verwenden.",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{targetName}\" wird bereits im Ordner \"{dir}\" benutzt. Bitte einen anderen Namen verwenden.",
     "Could not rename \"{fileName}\"" : "Die Datei konnte nicht umbenannt werden \"{fileName}\"",
     "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden, da diese bereits existiert.",
@@ -349,16 +408,17 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
     "{dirs} and {files}" : "{dirs} und {files}",
     "_including %n hidden_::_including %n hidden_" : ["%n versteckte eingeschlossen","%n versteckte eingeschlossen"],
+    "You do not have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
     "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hochgeladen","%n Dateien werden hochgeladen"],
     "New" : "Neu",
     "New file/folder menu" : "Menü für neue Datei/Ordner",
     "Select file range" : "Dateibereich auswählen",
     "{used}%" : "{used}%",
     "{used} used" : "{used} verwendet",
-    "\"{name}\" is an invalid file name." : "„{name}“ ist kein gültiger Dateiname.",
+    "\"{name}\" is an invalid file name." : "\"{name}\" ist kein gültiger Dateiname.",
     "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
     "\"/\" is not allowed inside a file name." : "\"/\" ist innerhalb eines Dateinamens nicht erlaubt.",
-    "\"{name}\" is not an allowed filetype" : "„{name}“ ist kein erlaubter Dateityp",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" ist kein erlaubter Dateityp",
     "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Der Speicher von {owner} ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
     "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppenordner \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
     "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externer Speicher \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
@@ -368,40 +428,33 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externer Speicher \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Dein Speicher ist beinahe voll ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["stimmt mit \"{filter}\" überein","stimmen mit \"{filter}\" überein"],
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Benutzer, die Zugriff auf diese Datei/Ordner haben)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
     "Path" : "Pfad",
     "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
     "Favorited" : "Favorisiert",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Benutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Direktlink kopieren (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
     "Upload file" : "Datei hochladen",
     "Not favorited" : "Nicht favorisiert",
     "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Tags aufgetreten",
-    "\"remote user\"" : "„Externer Benutzer“",
-    "{newName} already exists." : "{newName} existiert bereits.",
-    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" ist in einem Dateinamen unzulässig.",
-    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" ist ein unzulässiger Datei- oder Ordnername.",
-    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" ist kein zulässiger Dateityp.",
-    "Filenames must not end with \"{segment}\"." : "Dateinamen dürfen nicht mit \"{segment}\" enden.",
-    "Name cannot be empty" : "Der Name darf nicht leer sein",
-    "Another entry with the same name already exists" : "Ein anderer Eintrag mit diesem Namen existiert bereits.",
-    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" konnte nicht umbenannt werden, da es nicht mehr existiert.",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}“ wird bereits im Ordner \"{dir}“ verwendet. Bitte wähle einen anderen Namen.",
-    "Could not rename \"{oldName}\"" : "\"{oldName}\" konnte nicht umbenannt werden.",
+    "You don't have permission to upload or create files here." : "Keine Berechtigung, hier Dateien hochzuladen oder zu erstellen.",
     "Storage informations" : "Speicherinformationen",
     "Choose file" : "Datei auswählen",
     "Go to the previous folder" : "Zum vorherigen Ordner wechseln",
     "Open the files app settings" : "Einstellungen der Dateien-App öffnen",
-    "You might not have have permissions to view it, ask the sender to share it" : "Möglicherweise hast du nicht die Berechtigung zur Anzeige. Bitte den Absender, die Datei freizugeben.",
-    "The files is locked" : "Die Datei ist gesperrt",
+    "Unable to change the favourite state of the file" : "Der Favorisiert-Status der Datei konnte nicht geändert werden",
+    "Edit file locally" : "Datei lokal bearbeiten",
+    "Edit online" : "Online bearbeiten",
     "Create new templates folder" : "Neuen Vorlagenordner erstellen",
     "List of favorites files and folders." : "Liste der favorisierten Ordner und Dateien",
-    "Toggle %1$s sublist" : "Unterliste %1$s umschalten",
+    "Personal Files" : "Persönliche Dateien",
     "Text file" : "Textdatei",
     "New text file.txt" : "Neue Textdatei file.txt",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Direktlink kopieren (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
     "Favored" : "Favorisiert",
     "Favor" : "Favorisieren",
-    "Not favored" : "Nicht favorisiert"
+    "Not favored" : "Nicht favorisiert",
+    "Submitting fields…" : "Felder werden übermittelt…",
+    "Filter filenames…" : "Dateinamen filtern…",
+    "{count} files could not be converted" : "{count} Dateien konnten nicht konvertiert werden",
+    "{count} files successfully converted" : "{count} Dateien erfolgreich konvertiert"
 },
 "nplurals=2; plural=(n != 1);");
