@@ -1,120 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "File could not be found" : "找不到檔案",
-    "Move or copy" : "移動或複製",
-    "Download" : "下載",
-    "Delete" : "刪除",
-    "Tags" : "標籤",
-    "Show list view" : "顯示清單視圖",
-    "Show grid view" : "顯示網格視圖",
-    "Home" : "主目錄",
-    "Close" : "關閉",
-    "Could not create folder \"{dir}\"" : "無法建立資料夾 \"{dir}\"",
-    "This will stop your current uploads." : "這會終止目前任何的上傳。",
-    "Upload cancelled." : "上傳已取消",
-    "Processing files …" : "正在處理檔案…",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "資料夾 \"{dir}\" 不存在",
-    "Not enough free space" : "空間不足",
-    "An unknown error has occurred" : "發生了不詳的錯誤",
-    "File could not be uploaded" : "檔案無法上傳",
-    "Uploading …" : "上傳中...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "上傳中 ... （{currentNumber}／{total}）",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中的 {loadedSize}（{bitrate}）",
-    "Uploading that item is not supported" : "不支援上傳該項目",
-    "Target folder does not exist any more" : "目標資料夾已經不存在了",
-    "Operation is blocked by access control" : "操作已被存取控制封鎖",
-    "Error when assembling chunks, status code {status}" : "重組檔案片段時出錯，狀態代碼 {status}",
-    "Actions" : "操作",
-    "Rename" : "重新命名",
-    "Move" : "移動",
-    "Copy" : "複製",
-    "Choose target folder" : "選擇目標資料夾",
-    "Set reminder" : "設定提醒",
-    "Edit locally" : "在近端編輯",
-    "Open" : "開啟",
-    "Delete file" : "刪除檔案",
-    "Delete folder" : "刪除資料夾",
-    "Disconnect storage" : "解除連結儲存空間",
-    "Leave this share" : "保留該共用",
-    "Could not load info for file \"{file}\"" : "無法讀取 \"{file}\" 的詳細資料",
-    "Files" : "檔案",
-    "Details" : "詳細資料",
-    "Please select tag(s) to add to the selection" : "請選擇要添加到所選項目中的標籤",
-    "Apply tag(s) to selection" : "將標籤應用於所選項目",
-    "Select directory \"{dirName}\"" : "選擇目錄「{dirName}」",
-    "Select file \"{fileName}\"" : "選擇檔案「{fileName}」",
-    "Pending" : "待定的",
-    "Unable to determine date" : "無法確定日期",
-    "This operation is forbidden" : "此操作被禁止",
-    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
-    "Storage is temporarily not available" : "儲存空間暫時無法使用",
-    "Could not move \"{file}\", target exists" : "無法移動「{file}」，目標已經存在",
-    "Could not move \"{file}\"" : "無法移動 \"{file}\"",
-    "copy" : "複製",
-    "Could not copy \"{file}\", target exists" : "無法複製\"{file}\"，目標已存在",
-    "Could not copy \"{file}\"" : "無法複製\"{file}\"",
-    "Copied {origin} inside {destination}" : "已複製 {origin} 至 {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "已複製 {origin} 和其他 {nbfiles} 個檔案至 {destination}",
-    "Failed to redirect to client" : "無法重定向到客戶端",
-    "{newName} already exists" : "{newName} 已經存在",
-    "Could not rename \"{fileName}\", it does not exist any more" : "無法命名檔案 \"{fileName}\"，因為此檔案已經不存在",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱 \"{targetName}\" 在這資料夾 \"{dir}\" 已經被使用。請重新選擇不同的名稱",
-    "Could not rename \"{fileName}\"" : "無法重新命名「{fileName}」",
-    "Could not create file \"{file}\"" : "無法建立檔案 \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "無法建立檔案「{file}」，因為此檔案已存在",
-    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾 \"{dir}\"，因為此資料夾已存在",
-    "Could not fetch file details \"{file}\"" : "不能取得檔案細節\"{file}\"",
-    "Error deleting file \"{fileName}\"." : "刪除 \"{fileName}\" 出錯",
-    "No search results in other folders for {tag}{filter}{endtag}" : "在其它資料夾中沒有找到 {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "輸入兩個字元以上以便在其它資料夾搜尋",
-    "Name" : "名稱",
-    "Size" : "大小",
-    "Modified" : "修改時間",
-    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
-    "_%n file_::_%n files_" : ["%n 個檔案"],
-    "{dirs} and {files}" : "{dirs} 和 {files}",
-    "_including %n hidden_::_including %n hidden_" : ["包括 %n 個隱藏檔"],
-    "You do not have permission to upload or create files here" : "您無權限上傳或建立檔案",
-    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
-    "New" : "新",
-    "New file/folder menu" : "新檔案/資料夾選項單",
-    "Select file range" : "選擇多個檔案",
-    "{used}%" : "{used}%",
-    "{used} of {quota} used" : "已使用 {quota} 當中的 {used}",
-    "{used} used" : "已使用 {used}",
-    "\"{name}\" is an invalid file name." : "\"{name}\" 是無效的檔案名稱。",
-    "File name cannot be empty." : "檔名不能為空",
-    "\"/\" is not allowed inside a file name." : "不允許檔名中出現 \"/\"",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" 是不允許的檔案類型",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} 的儲存空間已滿，沒有辦法再更新或是同步檔案！",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "群組資料夾 \"{mountPoint}\" 已滿，已無法再更新或同步檔案！",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部儲存空間 \"{mountPoint}\" 已滿，已無法再更新或同步檔案！",
-    "Your storage is full, files cannot be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} 的儲存空間將近已滿（{usedSpacePercent}%）。",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "群組資料夾 \"{mountPoint}\" 將近已滿（{usedSpacePercent}%）。",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部儲存空間 \"{mountPoint}\" 將近已滿（{usedSpacePercent}%）。",
-    "Your storage is almost full ({usedSpacePercent}%)." : "您的儲存空間將近已滿（{usedSpacePercent}%）。",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["符合「{filter}」"],
-    "View in folder" : "在資料夾中檢視",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "已複製直接連結（僅適用於有權訪問此檔案/資料夾的人仕）",
-    "Path" : "路徑",
-    "_%n byte_::_%n bytes_" : ["%n 位元組"],
-    "Favorited" : "已加入最愛",
-    "Favorite" : "我的最愛",
-    "Copy direct link (only works for people who have access to this file/folder)" : "複製直接連結（只對能存取的人仕有用）",
-    "New folder" : "新資料夾",
-    "Create new folder" : "新增資料夾",
-    "Upload file" : "上傳檔案",
-    "Recent" : "最新",
-    "Not favorited" : "未加入至最愛",
-    "Remove from favorites" : "從最愛中移除",
-    "Add to favorites" : "加到我的最愛",
-    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
     "Added to favorites" : "已加到我的最愛",
     "Removed from favorites" : "已從最愛中移除",
     "You added {file} to your favorites" : "你已添加 {file} 至最愛",
@@ -154,13 +40,27 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "您將 {oldfile} 移到 {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} 將 {oldfile} 移到 {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "已將檔案添加到<strong>我的最愛</strong>收藏夾中或從其中刪除",
+    "Files" : "檔案",
     "A file or folder has been <strong>changed</strong>" : "檔案或資料夾有所<strong>更改</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "收藏的檔案或資料夾有所<strong>更改</strong>",
+    "Failed to authorize" : "無法授權",
+    "Invalid folder path" : "無效的資料夾路徑",
+    "Folder not found" : "找不到資料夾",
+    "The file cannot be found" : "無法找到此檔案",
+    "The destination path does not exist: %1$s" : "目的途徑不存在：%1$s",
+    "You do not have permission to create a file at the specified location" : "您無權在指定的位置創建檔案",
+    "The file could not be converted." : "無法轉換檔案。",
+    "Could not get relative path to converted file" : "無法取得轉換檔案的相對路徑",
+    "Favorite files" : "最愛的檔案",
+    "No favorites" : "沒有最愛",
+    "More favorites" : "更多最愛",
     "Upload (max. %s)" : "上傳（上限 %s）",
     "Accept" : "接受",
     "Reject" : "拒絕",
     "Incoming ownership transfer from {user}" : "來自 {user} 的擁有權轉移",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "您想要接收 \"{path}\" 嗎？\n\n註：所有權轉移的流程最多需要一小時",
+    "Ownership transfer denied" : "擁有權轉移被拒絕",
+    "Your ownership transfer of {path} was denied by {user}." : "您 \"{path}\" 的擁有權轉移被 {user} 拒絕",
     "Ownership transfer failed" : "擁有權轉讓失敗",
     "Your ownership transfer of {path} to {user} failed." : "您將 \"{path}\" 的擁有權轉移給 {user} 失敗",
     "The ownership transfer of {path} from {user} failed." : "來自 {user} 的 \"{path}\" 擁有權轉移失敗",
@@ -168,51 +68,69 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "您將 \"{path}\" 的所有權轉移給 {user} 已經完成",
     "The ownership transfer of {path} from {user} has completed." : "來自 {user} 的 \"{path}\" 所有權轉移已經完成",
     "in %s" : "在 %s",
+    "Transferred from %1$s on %2$s" : "於 %2$s 從 %1$s 轉移",
+    "Files compatibility" : "檔案兼容性",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允許限製檔案名稱以確保檔案可以與所有客戶端同步。默認情況下，允許 POSIX（例如 Linux 或 macOS）上有效的所有檔案名稱。",
+    "Enforce Windows compatibility" : "實施 Windows 兼容性",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "這將阻止在 Windows 系統上無效的檔案名，例如使用保留名稱或特殊字元。但這不會強制區分大小寫的兼容性。",
     "File Management" : "檔案管理",
-    "Current directory path" : "目前目錄途徑",
+    "Home" : "主目錄",
+    "Target folder does not exist any more" : "目標資料夾已經不存在了",
     "Reload current directory" : "重新加載目前目錄",
     "Go to the \"{dir}\" directory" : "前往「{dir}」目錄",
-    "Drag and drop files here to upload" : "將檔案拖拽到此處即可上傳",
+    "Current directory path" : "目前目錄途徑",
     "Your have used your space quota and cannot upload files anymore" : "您已用完您的空間配額，無法再上傳檔案",
-    "You don’t have permission to upload or create files here" : "您無權限上傳或建立檔案",
-    "\"{displayName}\" action executed successfully" : "成功執行 “{displayName}” 操作",
-    "\"{displayName}\" action failed" : "“{displayName}” 操作失敗",
+    "You do not have permission to upload or create files here." : "您無權在此上傳或建立檔案。",
+    "Drag and drop files here to upload" : "將檔案拖拽到此處即可上傳",
+    "Favorite" : "我的最愛",
+    "Back" : "上星期",
     "Toggle selection for file \"{displayName}\"" : "切換對檔案 \"{displayName}\" 的選擇",
     "Toggle selection for folder \"{displayName}\"" : "切換對資料夾 \"{displayName}\" 的選擇",
-    "Rename file" : "重新命名檔案",
-    "File name" : "檔案名稱",
+    "File is loading" : "正在加載檔案",
+    "Folder is loading" : "正在加載資料夾",
+    "Filename" : "檔案名稱",
     "Folder name" : "資料夾名稱",
     "This node is unavailable" : "此節點不可用",
-    "Download file {name}" : "下載檔案 {name}",
-    "\"{name}\" is not an allowed filetype." : "「{name}」是不允許的檔案類型。",
-    "{newName} already exists." : "{newName} 已經存在。",
-    "\"{char}\" is not allowed inside a file name." : "不允許檔案名稱中出現 \"{char}\"。",
-    "Name cannot be empty" : "名稱不能空白",
-    "Another entry with the same name already exists" : "另一個同名的條目已經存在",
+    "Another entry with the same name already exists." : "另一個同名的條目已經存在。",
+    "Invalid filename." : "檔案名稱無效。",
     "Renamed \"{oldName}\" to \"{newName}\"" : "已將「{oldName}」重新命名為「{newName}」",
-    "Could not rename \"{oldName}\", it does not exist any more" : "無法命名檔案「{oldName}」，因為此檔案已經不存在",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱「{newName}」在這資料夾「{dir}」已經被使用。請選擇其他名稱。",
-    "Could not rename \"{oldName}\"" : "無法重新命名「{oldName}」",
+    "Rename file" : "重新命名檔案",
+    "Pending" : "待定的",
+    "Unknown date" : "日期不詳",
+    "Clear filter" : "清空過濾器",
+    "Modified" : "修改時間",
+    "Type" : "類型",
+    "Active filters" : "有效的過濾器",
+    "Remove filter" : "移除過濾",
     "Total rows summary" : "總列摘要",
     "Toggle selection for all files and folders" : "切換所有檔案和資料夾的選擇",
-    "\"{displayName}\" failed on some elements " : "“{displayName}” 在某些元素上失敗",
+    "Name" : "名稱",
+    "Size" : "大小",
+    "\"{displayName}\" failed on some elements" : "“{displayName}” 在某些元素上失敗",
     "\"{displayName}\" batch action executed successfully" : "成功執行 “{displayName}” 批處理操作",
-    "{count} selected" : "已選擇 {count} 項",
+    "\"{displayName}\" action failed" : "“{displayName}” 操作失敗",
+    "Actions" : "操作",
+    "(selected)" : "（已選擇）",
     "List of files and folders." : "檔案與資料夾清單。",
+    "You have used your space quota and cannot upload files anymore." : "您已用完您的空間配額，無法再上傳檔案。",
     "Column headers with buttons are sortable." : "具有按鈕的縱列標題可排序。",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出於性能考慮，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
     "File not found" : "找不到檔案",
-    "Storage informations" : "儲存資訊",
+    "{count} selected" : "已選擇 {count} 項",
     "{usedQuotaByte} used" : "已使用 {usedQuotaByte} ",
+    "{used} of {quota} used" : "已使用 {quota} 當中的 {used}",
     "{relative}% used" : "已使用 {relative}%",
     "Could not refresh storage stats" : "無法更新儲存統計數據",
     "Your storage is full, files can not be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
+    "Storage information" : "儲存資訊",
+    "Storage quota" : "儲存配額",
+    "New folder" : "新資料夾",
+    "Create new folder" : "新增資料夾",
+    "This name is already in use." : "這個用戶名稱已經有人使用了。",
     "Create" : "創建",
-    "A file or folder with that name already exists." : "已存在同名的檔案或資料夾°。",
-    "Transfer ownership of a file or folder" : "轉移檔案或資料夾的擁有權",
-    "Choose file or folder to transfer" : "選擇要轉移的檔案或資料夾",
-    "Change" : "更改",
-    "New owner" : "新的擁有者",
+    "Fill template fields" : "填寫模板欄位",
+    "Submitting fields …" : "正在遞交欄位 …",
+    "Submit" : "遞交",
     "Choose a file or folder to transfer" : "選擇要轉移的檔案或資料夾",
     "Transfer" : "轉移",
     "Transfer {path} to {userid}" : "轉移 \"{path}\" 給 {userid}",
@@ -220,60 +138,129 @@ OC.L10N.register(
     "Unknown error" : "錯誤不詳",
     "Ownership transfer request sent" : "已送出擁有權轉移的請求",
     "Cannot transfer ownership of a file or folder you do not own" : "無法轉移您未擁有的檔案或是資料夾所有權",
+    "Transfer ownership of a file or folder" : "轉移檔案或資料夾的擁有權",
+    "Choose file or folder to transfer" : "選擇要轉移的檔案或資料夾",
+    "Change" : "更改",
+    "New owner" : "新的擁有者",
+    "Keep {old}" : "保留 {old}",
+    "Keep without extension" : "保留但不包含副檔名",
+    "Use {new}" : "使用 {new}",
+    "Remove extension" : "移除副檔名",
+    "Change file extension" : "變更檔案副檔名",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "將檔案副檔名從「{old}」改為「{new}」可能會導致檔案無法讀取。",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "移除檔案副檔名「{old}」可能會導致檔案無法讀取。",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "加入檔案副檔名「{new}」可能會導致檔案無法讀取。",
+    "Do not show this dialog again." : "不要再次顯示此對話框。",
     "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
-    "Choose file" : "選擇檔案",
     "Choose {file}" : "選擇 {file}",
-    "Loading current folder" : "目前資料夾加載中",
-    "No files in here" : "沒有任何檔案",
-    "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
-    "Go to the previous folder" : "前往上一個資料夾",
-    "Go back" : "返回",
     "Share" : "分享",
     "Shared by link" : "由連結分享",
     "Shared" : "已分享",
     "Switch to list view" : "切換到列表檢視",
     "Switch to grid view" : "切換到網格檢視",
+    "The file could not be found" : "找不到檔案",
+    "Upload was cancelled by user" : "用戶已取消上傳",
+    "Not enough free space" : "空間不足",
+    "Operation is blocked by access control" : "操作已被存取控制封鎖",
     "Error during upload: {message}" : "上傳時發生錯誤：{message}",
     "Error during upload, status code {status}" : "上傳期間發生錯誤，狀態代碼 {status}",
     "Unknown error during upload" : "上傳時發生未知的錯誤",
-    "Open the files app settings" : "開啟 Files 應用程式設定",
+    "\"{displayName}\" action executed successfully" : "成功執行 “{displayName}” 操作",
+    "Loading current folder" : "目前資料夾加載中",
+    "Retry" : "重試",
+    "No files in here" : "沒有任何檔案",
+    "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
+    "Go back" : "返回",
+    "Filter file names …" : "過濾檔案名稱 …",
+    "Views" : "視圖",
     "Files settings" : "檔案設定",
-    "File cannot be accessed" : "檔案無法存取",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到該檔案，或是您沒有檢視該檔案的權限。請要求寄件者分享。",
     "Your files" : "您的檔案",
     "Open in files" : "在「檔案」應用程式中打開",
+    "File cannot be accessed" : "檔案無法存取",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到該檔案，或是您沒有檢視該檔案的權限。請要求寄件者分享。",
+    "Clipboard is not available" : "剪貼板不可用",
+    "WebDAV URL copied to clipboard" : "WebDAV 連結已複製到剪貼板",
     "Sort favorites first" : "先排序最愛",
     "Sort folders before files" : "將資料夾在檔案之前排序",
-    "Show hidden files" : "顯示隱藏檔",
+    "Show hidden files" : "顯示隱藏檔案",
     "Crop image previews" : "圖片裁剪預覽",
     "Enable the grid view" : "啟用網格檢視",
+    "Enable folder tree" : "啟用資料夾樹狀結構",
     "Additional settings" : "其他設定",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
     "Copy to clipboard" : "複製到剪貼板",
     "Use this address to access your Files via WebDAV" : "用這位址使用 WebDAV 存取你的檔案。",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "如果您啟用了 2FA，則必須通過單擊此處創建和使用新的應用程式密碼。",
-    "Clipboard is not available" : "剪貼板不可用",
-    "WebDAV URL copied to clipboard" : "WebDAV 連結已複製到剪貼板",
-    "Unable to change the favourite state of the file" : "無法更改檔案的最愛狀態",
+    "Warnings" : "警告",
+    "Prevent warning dialogs from open or reenable them." : "避免開啟警告對話框或重新啟用它們。",
+    "Show a warning dialog when changing a file extension." : "在變更副檔名時顯示警告對話框。",
+    "Keyboard shortcuts" : "鍵盤快捷鍵",
+    "Speed up your Files experience with these quick shortcuts." : "這些快速捷徑可加快您的 Files 體驗。",
+    "Open the actions menu for a file" : "開啟檔案的操作選項單",
+    "Rename a file" : "重新命名檔案",
+    "Delete a file" : "刪除檔案",
+    "Favorite or remove a file from favorites" : "加入最愛或從最愛移除檔案",
+    "Manage tags for a file" : "管理檔案的標籤",
+    "Selection" : "選擇",
+    "Select all files" : "選擇所有檔案",
+    "Deselect all files" : "取消選擇所有檔案",
+    "Select or deselect a file" : "選擇或取消選擇檔案",
+    "Select a range of files" : "選擇一系列檔案",
+    "Navigation" : "導覽列",
+    "Navigate to the parent folder" : "前往上層資料夾",
+    "Navigate to the file above" : "前往以上檔案",
+    "Navigate to the file below" : "前往以下檔案",
+    "Navigate to the file on the left (in grid mode)" : "前往左側的檔案（在網格模式下）",
+    "Navigate to the file on the right (in grid mode)" : "前往右側的檔案（在網格模式下）",
+    "View" : "檢視",
+    "Toggle the grid view" : "切換網格檢視",
+    "Open the sidebar for a file" : "開啟檔案側邊欄",
+    "Show those shortcuts" : "顯示這些快捷鍵",
+    "You" : "您",
+    "Shared multiple times with different people" : "與不同的人多次分享",
     "Error while loading the file data" : "載入檔案資料失敗",
+    "Owner" : "擁有者",
+    "Remove from favorites" : "從最愛中移除",
+    "Add to favorites" : "加到我的最愛",
+    "Tags" : "標籤",
+    "Blank" : "空白",
+    "Unable to create new file from template" : "無法從模板創建新檔案",
     "Pick a template for {name}" : "為 {name} 選擇一個模板",
     "Create a new file with the selected template" : "使用所選模板創建一個新檔案",
     "Creating file" : "創建檔案中",
-    "Blank" : "空白",
-    "Unable to create new file from template" : "無法從模板創建新檔案",
+    "Save as {displayName}" : "保存為 {displayName}",
+    "Save as …" : "另存為 ...",
+    "Converting files …" : "正在轉換檔案 …",
+    "Failed to convert files: {message}" : "無法轉換檔案：{message}",
+    "All files failed to be converted" : "所有檔案轉換失敗",
+    "One file could not be converted: {message}" : "有一個檔案無法轉換：{message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["%n 個檔案無法轉換"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["%n 個檔案成功轉換"],
+    "Files successfully converted" : "成功轉換檔案",
+    "Failed to convert files" : "無法轉換檔案",
+    "Converting file …" : "正在轉換檔案 …",
+    "File successfully converted" : "成功轉換檔案",
+    "Failed to convert file: {message}" : "無法轉換檔案：{message}",
+    "Failed to convert file" : "無法轉換檔案",
+    "Deletion cancelled" : "刪除已取消",
+    "Leave this share" : "保留該共用",
+    "Leave these shares" : "保留這些分享",
+    "Disconnect storage" : "解除連結儲存空間",
+    "Disconnect storages" : "解除連結儲存空間",
     "Delete permanently" : "永久刪除",
     "Delete and unshare" : "刪除並取消分享",
-    "Leave these shares" : "保留這些分享",
-    "Disconnect storages" : "解除連結儲存空間",
+    "Delete file" : "刪除檔案",
     "Delete files" : "刪除檔案",
+    "Delete folder" : "刪除資料夾",
     "Delete folders" : "刪除資料夾",
-    "You are about to delete {count} items." : "您即將刪除 {count} 項。",
+    "Delete" : "刪除",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["您即將永久刪除 {count} 個項目"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["您即將刪除 {count} 個項目"],
     "Confirm deletion" : "確認刪除",
     "Cancel" : "取消",
-    "Deletion cancelled" : "刪除已取消",
-    "Destination is not a folder" : "目標地不是資料夾",
-    "This file/folder is already in that directory" : "此檔案/資料夾已在該目錄中",
+    "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」…",
+    "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」…",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "您無法將檔案/資料夾移動到其自身或子資料夾中",
     "(copy)" : "（複本）",
     "(copy %n)" : "（複本 %n）",
@@ -283,16 +270,41 @@ OC.L10N.register(
     "The file does not exist anymore" : "檔案已不存在",
     "Choose destination" : "選擇目標地",
     "Copy to {target}" : "複製到 {target}",
+    "Copy" : "複製",
     "Move to {target}" : "移動到 {target}",
-    "Cancelled move or copy operation" : "已取消移動或複製操作",
+    "Move" : "移動",
     "Move or copy operation failed" : "移動或複製操作失敗",
+    "Move or copy" : "移動或複製",
+    "Cancelled move or copy of \"{filename}\"." : "已取消移動或複製 \"{filename}\"。",
+    "Cancelled move or copy operation" : "已取消移動或複製操作",
     "Open folder {displayName}" : "打開資料夾 {displayName}",
     "Open in Files" : "在「檔案」應用程式中打開",
+    "Open file locally" : "在近端打開檔案",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "檔案現在應該在您的裝置上打開。如果沒有，請檢查您是否已安裝桌面應用程式。",
+    "Retry and close" : "重試和關閉",
+    "Open online" : "線上開啟",
+    "Failed to redirect to client" : "無法重定向到客戶端",
+    "Open locally" : "在近端打開",
+    "Rename" : "重新命名",
     "Open details" : "開啟細節",
+    "View in folder" : "在資料夾中檢視",
+    "Today" : "今日",
+    "Last 7 days" : "過去7日",
+    "Last 30 days" : "過去30日",
+    "This year ({year})" : "今年 ({year})",
+    "Last year ({year})" : "去年 ({year})",
+    "Documents" : "文件",
+    "Spreadsheets" : "試算表",
+    "Presentations" : "簡報",
+    "PDFs" : "PDF",
+    "Folders" : "資料夾",
+    "Audio" : "音頻",
+    "Photos and images" : "照片與圖像",
+    "Videos" : "影片",
+    "New folder creation cancelled" : "已取消建立新資料夾",
     "Created new folder \"{name}\"" : "創建了新資料夾 \"{name}\"",
-    "Filename" : "檔案名稱",
     "Unable to initialize the templates directory" : "無法初始化模板目錄",
-    "Create new templates folder" : "創建新範本資料夾",
+    "Create templates folder" : "創建模板資料夾",
     "Templates" : "模板",
     "New template folder" : "新範本資料夾",
     "In folder" : "在資料夾中",
@@ -310,20 +322,31 @@ OC.L10N.register(
     "Files moved successfully" : "檔案移動成功",
     "Conflicts resolution skipped" : "已略過衝突解決",
     "Upload cancelled" : "上傳已取消",
+    "This operation is forbidden" : "此操作被禁止",
+    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
+    "Storage is temporarily not available" : "儲存空間暫時無法使用",
+    "Unexpected error: {error}" : "意外錯誤：{error}",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 個資料夾"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 個檔案"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
-    "List of favorites files and folders." : "最愛檔案與資料夾的清單。",
+    "Filename must not be empty." : "檔案名稱不能為空。",
+    "\"{char}\" is not allowed inside a filename." : "檔案名稱中不允許出現「{char}」",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "「{segment}」是保留名稱，不允許用在檔案名稱。",
+    "\"{extension}\" is not an allowed filetype." : "「{extension}」是不允許的檔案類型。",
+    "Filenames must not end with \"{extension}\"." : "檔案名稱不能以「{extension}」結尾。",
+    "List of favorite files and folders." : "最愛檔案與資料夾的清單。",
     "No favorites yet" : "尚無最愛",
     "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
     "All files" : "所有檔案",
     "List of your files and folders." : "您的檔案與資料夾清單。",
-    "Personal Files" : "個人檔案",
+    "All folders" : "所有資料夾",
+    "Personal files" : "個人檔案",
     "List of your files and folders that are not shared." : "未分享的檔案與資料夾清單。",
     "No personal files found" : "找不到個人檔案",
     "Files that are not shared will show up here." : "尚未分享的檔案將會顯示在此處。",
+    "Recent" : "最新",
     "List of recently modified files and folders." : "最近修改的檔案和資料夾的清單。",
     "No recently modified files" : "近期無修改檔案",
     "Files and folders you recently modified will show up here." : "您最近修改的檔案和資料夾將顯示在此處。",
@@ -331,33 +354,107 @@ OC.L10N.register(
     "Select all" : "全選",
     "Upload too large" : "上傳過大",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制",
+    "File could not be found" : "找不到檔案",
+    "Download" : "下載",
+    "Show list view" : "顯示清單視圖",
+    "Show grid view" : "顯示網格視圖",
+    "Close" : "關閉",
+    "Could not create folder \"{dir}\"" : "無法建立資料夾 \"{dir}\"",
+    "This will stop your current uploads." : "這會終止目前任何的上傳。",
+    "Upload cancelled." : "上傳已取消",
+    "Processing files …" : "正在處理檔案…",
+    "…" : "...",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
+    "Target folder \"{dir}\" does not exist any more" : "資料夾 \"{dir}\" 不存在",
+    "An unknown error has occurred" : "發生了不詳的錯誤",
+    "File could not be uploaded" : "檔案無法上傳",
+    "Uploading …" : "上傳中...",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "上傳中 ... （{currentNumber}／{total}）",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中的 {loadedSize}（{bitrate}）",
+    "Uploading that item is not supported" : "不支援上傳該項目",
+    "Error when assembling chunks, status code {status}" : "重組檔案片段時出錯，狀態代碼 {status}",
+    "Choose target folder" : "選擇目標資料夾",
+    "Set reminder" : "設定提醒",
+    "Edit locally" : "在近端編輯",
+    "Open" : "開啟",
+    "Could not load info for file \"{file}\"" : "無法讀取 \"{file}\" 的詳細資料",
+    "Details" : "詳細資料",
+    "Please select tag(s) to add to the selection" : "請選擇要添加到所選項目中的標籤",
+    "Apply tag(s) to selection" : "將標籤應用於所選項目",
+    "Select directory \"{dirName}\"" : "選擇目錄「{dirName}」",
+    "Select file \"{fileName}\"" : "選擇檔案「{fileName}」",
+    "Unable to determine date" : "無法確定日期",
+    "Could not move \"{file}\", target exists" : "無法移動「{file}」，目標已經存在",
+    "Could not move \"{file}\"" : "無法移動 \"{file}\"",
+    "copy" : "複製",
+    "Could not copy \"{file}\", target exists" : "無法複製\"{file}\"，目標已存在",
+    "Could not copy \"{file}\"" : "無法複製\"{file}\"",
+    "Copied {origin} inside {destination}" : "已複製 {origin} 至 {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "已複製 {origin} 和其他 {nbfiles} 個檔案至 {destination}",
+    "{newName} already exists" : "{newName} 已經存在",
+    "Could not rename \"{fileName}\", it does not exist any more" : "無法命名檔案 \"{fileName}\"，因為此檔案已經不存在",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱 \"{targetName}\" 在這資料夾 \"{dir}\" 已經被使用。請重新選擇不同的名稱",
+    "Could not rename \"{fileName}\"" : "無法重新命名「{fileName}」",
+    "Could not create file \"{file}\"" : "無法建立檔案 \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "無法建立檔案「{file}」，因為此檔案已存在",
+    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾 \"{dir}\"，因為此資料夾已存在",
+    "Could not fetch file details \"{file}\"" : "不能取得檔案細節\"{file}\"",
+    "Error deleting file \"{fileName}\"." : "刪除 \"{fileName}\" 出錯",
+    "No search results in other folders for {tag}{filter}{endtag}" : "在其它資料夾中沒有找到 {tag}{filter}{endtag}",
+    "Enter more than two characters to search in other folders" : "輸入兩個字元以上以便在其它資料夾搜尋",
+    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
+    "_%n file_::_%n files_" : ["%n 個檔案"],
+    "{dirs} and {files}" : "{dirs} 和 {files}",
+    "_including %n hidden_::_including %n hidden_" : ["包括 %n 個隱藏檔"],
+    "You do not have permission to upload or create files here" : "您無權限上傳或建立檔案",
+    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
+    "New" : "新",
+    "New file/folder menu" : "新檔案/資料夾選項單",
+    "Select file range" : "選擇多個檔案",
+    "{used}%" : "{used}%",
+    "{used} used" : "已使用 {used}",
+    "\"{name}\" is an invalid file name." : "\"{name}\" 是無效的檔案名稱。",
+    "File name cannot be empty." : "檔名不能為空",
+    "\"/\" is not allowed inside a file name." : "不允許檔名中出現 \"/\"",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" 是不允許的檔案類型",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} 的儲存空間已滿，沒有辦法再更新或是同步檔案！",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "群組資料夾 \"{mountPoint}\" 已滿，已無法再更新或同步檔案！",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部儲存空間 \"{mountPoint}\" 已滿，已無法再更新或同步檔案！",
+    "Your storage is full, files cannot be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} 的儲存空間將近已滿（{usedSpacePercent}%）。",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "群組資料夾 \"{mountPoint}\" 將近已滿（{usedSpacePercent}%）。",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部儲存空間 \"{mountPoint}\" 將近已滿（{usedSpacePercent}%）。",
+    "Your storage is almost full ({usedSpacePercent}%)." : "您的儲存空間將近已滿（{usedSpacePercent}%）。",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["符合「{filter}」"],
+    "Direct link was copied (only works for people who have access to this file/folder)" : "已複製直接連結（僅適用於有權訪問此檔案/資料夾的人仕）",
+    "Path" : "路徑",
+    "_%n byte_::_%n bytes_" : ["%n 位元組"],
+    "Favorited" : "已加入最愛",
+    "Copy direct link (only works for people who have access to this file/folder)" : "複製直接連結（只對能存取的人仕有用）",
+    "Upload file" : "上傳檔案",
+    "Not favorited" : "未加入至最愛",
+    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
+    "You don't have permission to upload or create files here." : "您無權在此上傳或建立檔案。",
+    "Storage informations" : "儲存資訊",
+    "Choose file" : "選擇檔案",
+    "Go to the previous folder" : "前往上一個資料夾",
+    "Open the files app settings" : "開啟 Files 應用程式設定",
+    "Unable to change the favourite state of the file" : "無法更改檔案的最愛狀態",
+    "Edit file locally" : "在近端編輯檔案",
+    "Edit online" : "在線編輯",
+    "Create new templates folder" : "創建新範本資料夾",
+    "List of favorites files and folders." : "最愛檔案與資料夾的清單。",
+    "Personal Files" : "個人檔案",
     "Text file" : "文字檔",
     "New text file.txt" : "新文字檔.txt",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "已複製直接連結（僅適用於有權訪問此檔案/資料夾的用戶）",
-    "Copy direct link (only works for users who have access to this file/folder)" : "複製直接連結（只對能存取的用戶有用）",
-    "You can only favorite a single file or folder at a time" : "您一次只能為一個檔案或資料夾加星號",
-    "This file has the tag {tag}" : "此檔案有標籤 {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "此檔案有標籤 {firstTags} 與 {lastTag}",
-    "\"remote user\"" : "「遠端用戶」",
-    "Select the row for {displayName}" : "選擇 {displayName} 的行",
-    "Open folder {name}" : "打開資料夾 {name}",
-    "Unselect all" : "取消全選",
-    "ascending" : "升",
-    "descending" : "降",
-    "Sort list by {column} ({direction})" : "按 {column} ({direction}) 排序清單",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "出於性能考慮，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
-    "Search for an account" : "搜尋賬號",
-    "Choose" : "選擇",
-    "No files or folders have been deleted yet" : "尚未刪除任何檔案或資料夾",
-    "You might not have have permissions to view it, ask the sender to share it" : "您可能沒有權限檢視它，請要求寄件者分享它",
-    "Set up templates folder" : "設定範本資料夾",
-    "Toggle %1$s sublist" : "切換 %1$s 子列表",
-    "Toggle grid view" : "切換網格檢視",
-    "Shares" : "分享",
-    "Shared with others" : "與其他人分享",
-    "Shared with you" : "與您分享",
-    "Deleted shares" : "已刪除的分享",
-    "Pending shares" : "等待分享",
-    "The files is locked" : "檔案已被上鎖"
+    "Favored" : "已加入最愛",
+    "Favor" : "加入最愛",
+    "Not favored" : "未加入最愛",
+    "Submitting fields…" : "正在遞交欄位 …",
+    "Filter filenames…" : "過濾檔案名 ...",
+    "{count} files could not be converted" : "{count} 個檔案無法轉換",
+    "{count} files successfully converted" : "{count} 個檔案成功轉換"
 },
 "nplurals=1; plural=0;");
