@@ -1,47 +1,6 @@
 OC.L10N.register(
     "files_sharing",
     {
-    "Shared with you" : "Jaettu kanssasi",
-    "Nothing shared with you yet" : "Kanssasi ei ole vielä jaettu mitään",
-    "Files and folders others share with you will show up here" : "Kanssasi jaetut tiedostot ja kansiot näkyvät täällä",
-    "Shared with others" : "Jaettu muiden kanssa",
-    "Nothing shared yet" : "Ei mitään jaettua",
-    "Files and folders you share will show up here" : "Jakamasi tiedostot ja kansiot näkyvät täällä",
-    "Shared by link" : "Jaettu linkin kautta",
-    "No shared links" : "Ei jaettuja linkkejä",
-    "Files and folders you share by link will show up here" : "Linkin kautta jakamasi tiedostot ja kansiot näkyvät täällä",
-    "Deleted shares" : "Poistetut jaot",
-    "No deleted shares" : "Ei poistettuja jakoja",
-    "Shares you deleted will show up here" : "Poistamasi jaot näkyvät täällä",
-    "Pending shares" : "Odottavat jaot",
-    "No pending shares" : "Ei odottavia jakoja",
-    "Shares you have received but not confirmed will show up here" : "Vastaanottamasi jaot, joita ei ole vahvistettu, näkyvät täällä",
-    "Shares" : "Jaot",
-    "No shares" : "Ei jakoja",
-    "Shares will show up here" : "Jaot näkyvät täällä",
-    "Restore" : "Palauta",
-    "Restore share" : "Palauta jako",
-    "Something happened. Unable to restore the share." : "Jotain tapahtui. Jakoa ei kyetty palauttamaan.",
-    "Accept share" : "Hyväksy jako",
-    "Something happened. Unable to accept the share." : "Jotain tapahtui. Jakoa ei voitu hyväksyä.",
-    "Reject share" : "Hylkää jako",
-    "Something happened. Unable to reject the share." : "Tapahtui virhe. Ei voida hylätä jakoa.",
-    "Waiting…" : "Odotetaan…",
-    "error" : "virhe",
-    "finished" : "valmis",
-    "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
-    "Move or copy" : "Siirrä tai kopioi",
-    "Download" : "Lataa",
-    "Delete" : "Poista",
-    "You can upload into this folder" : "Voit lähettää tiedostoja tähän kansioon",
-    "Terms of service" : "Käyttöehdot",
-    "Show list view" : "Näytä listanäkymä",
-    "Show grid view" : "Näytä ruudukkonäkymä",
-    "No compatible server found at {remote}" : "Yhteensopivaa palvelinta ei löytynyt osoitteesta {remote}",
-    "Invalid server URL" : "Virheellinen palvelimen URL",
-    "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
-    "No expiration date set" : "Ei vanhenemispäivää asetettu",
-    "Shared by" : "Jakanut",
     "File shares" : "Tiedostojaot",
     "Downloaded via public link" : "Ladattu julkista linkkiä käyttäen",
     "Downloaded by {email}" : "Ladannut {email}",
@@ -97,7 +56,7 @@ OC.L10N.register(
     "Share for file {file} expired" : "Tiedoston {file} jako vanhentui",
     "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Tiedosto tai kansio, joka on jaettu sähköpostitse tai julkisen linkin kautta, on <strong>ladattu</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "Tiedosto tai kansio on jaettu <strong>toiselta palvelimelta</strong>",
-    "Files" : "Tiedostot",
+    "Sharing" : "Jakaminen",
     "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
     "Shared link" : "Jaettu linkki",
     "Wrong share ID, share does not exist" : "Väärä jaon ID, jakoa ei ole olemassa",
@@ -105,60 +64,55 @@ OC.L10N.register(
     "Please specify a file or folder path" : "Määritä tiedoston tai kansion polku",
     "Wrong path, file/folder does not exist" : "Väärä polku, tiedostoa/kansiota ei ole olemassa",
     "Could not create share" : "Jaon luominen epäonnistui",
-    "Invalid permissions" : "Virheelliset käyttöoikeudet",
-    "Please specify a valid user" : "Määritä kelvollinen käyttäjä",
     "Group sharing is disabled by the administrator" : "Ylläpitäjä on estänyt ryhmäjakamisen",
     "Please specify a valid group" : "Määritä kelvollinen ryhmä",
     "Public link sharing is disabled by the administrator" : "Ylläpitäjä on estänyt julkisen linkin jakamisen",
-    "Public upload disabled by the administrator" : "Ylläpitäjä on estänyt julkisen lähetyksen",
-    "Public upload is only possible for publicly shared folders" : "Julkinen lähettäminen on mahdollista vain julkisesti jaetuille kansioille",
     "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Kohteen %s jakaminen lähettämällä salasana Nextcloud Talkin kautta epäonnistui, koska Nextcloud Talk ei ole käytössä",
-    "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päivämäärän muodon tulee olla VVVV-KK-PP",
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Kohteen %1$s jakaminen epäonnistui, koska tietovarasto ei salli %2$s tyyppisiä jakoja",
-    "You cannot share to a Circle if the app is not enabled" : "Et voi jakaa piiriin, jos sovellusta ei ole aktivoitu",
-    "Please specify a valid circle" : "Määritä kelvollinen piiri",
     "Sharing %s failed because the back end does not support room shares" : "Kohteen %s jakaminen epäonnistui, koska taustaosa ei tue huonejakoja",
     "Unknown share type" : "Tuntematon jaon tyyppi",
     "Not a directory" : "Ei hakemisto",
     "Could not lock node" : "Solmua ei voitu lukita",
+    "Public upload is only possible for publicly shared folders" : "Julkinen lähettäminen on mahdollista vain julkisesti jaetuille kansioille",
+    "Share must at least have READ or CREATE permissions" : "Jaolla tulee olla vähintään luku- tai kirjoitusoikeus",
+    "Public upload disabled by the administrator" : "Ylläpitäjä on estänyt julkisen lähetyksen",
     "Could not lock path" : "Polun lukitseminen ei onnistunut",
     "Wrong or no update parameter given" : "Päivitettävä parametri puuttuu tai on väärin",
+    "Wrong password" : "Väärä salasana",
     "shared by %s" : "käyttäjän %s jakama",
-    "Download all files" : "Lataa kaikki tiedostot",
-    "Direct link" : "Suora linkki",
+    "Download" : "Lataa",
     "Add to your %s" : "Lisää %siisi",
+    "Direct link" : "Suora linkki",
     "Share API is disabled" : "Jakamisrajapinta on poistettu käytöstä",
     "File sharing" : "Tiedostonjako",
     "Share will expire tomorrow" : "Jako vanhenee huomenna",
-    "One or more of your shares will expire tomorrow" : "Yksi tai useampi jaoistasi vanhenee huomenna",
+    "Your share of {node} will expire tomorrow" : "Jakosi {node} vanhenee huomenna",
     "You received {share} as a share by {user}" : "Vastaanotit jaon {share} käyttäjältä {user}",
     "You received {share} to group {group} as a share by {user}" : "Vastaanotit jaon {share} ryhmään {group} käyttäjältä {user}",
     "Accept" : "Hyväksy",
-    "Reject" : "Hylkää",
-    "Sharing" : "Jakaminen",
-    "Accept user and group shares by default" : "Hyväksy käyttäjä- ja ryhmäjaot oletuksena",
-    "Set default folder for accepted shares" : "Aseta oletuskansio hyväksytyille jaoille",
-    "Reset" : "Palauta",
-    "Reset folder to system default" : "Palauta kansio järjestelmän oletukseksi",
+    "Decline" : "Kieltäydy",
+    "People" : "Ihmiset",
+    "Expiration date" : "Vanhenemispäivä",
+    "Select a date" : "Valitse päivämäärä",
+    "Set a password" : "Aseta salasana",
+    "Password" : "Salasana",
+    "Link copied to clipboard" : "Linkki kopioitu leikepöydälle",
+    "Share link" : "Jaa linkki",
+    "Copy to clipboard" : "Kopioi leikepöydälle",
+    "Send link via email" : "Lähetä linkki sähköpostitse",
+    "Select" : "Valitse",
+    "Close" : "Sulje",
+    "Error creating the share: {errorMessage}" : "Virhe luotaessa jakoa: {errorMessage}",
+    "Error creating the share" : "Virhe jakoa luotaessa",
+    "Cancel" : "Peruuta",
+    "Continue" : "Jatka",
+    "Accept shares from other accounts and groups by default" : "Hyväksy jaot muilta tileiltä ja ryhmiltä oletusarvoisesti",
     "Choose a default folder for accepted shares" : "Valitse oletuskansio hyväksytyille jaoille",
     "Invalid path selected" : "Virheellinen polku valittu",
     "Unknown error" : "Tuntematon virhe",
-    "Allow editing" : "Salli muokkaus",
-    "Read only" : "Vain luku",
-    "Allow upload and editing" : "Salli lähetys ja muokkaus",
-    "File drop (upload only)" : "Tiedostojen pudotus (vain lähetys)",
-    "Custom permissions" : "Mukautetut oikeudet",
-    "Read" : "Lue",
-    "Upload" : "Lähetä",
-    "Edit" : "Muokkaa",
-    "Allow creating" : "Salli luominen",
-    "Allow deleting" : "Salli poistaminen",
-    "Allow resharing" : "Salli uudelleenjakaminen",
-    "Expiration date enforced" : "Vanhenemispäivä pakotettu",
-    "Set expiration date" : "Aseta vanhenemispäivä",
-    "Enter a date" : "Syötä päivämäärä",
-    "Note to recipient" : "Huomio vastaanottajalle",
-    "Unshare" : "Lopeta jakaminen",
+    "Set default folder for accepted shares" : "Aseta oletuskansio hyväksytyille jaoille",
+    "Reset" : "Palauta",
+    "Reset folder to system default" : "Palauta kansio järjestelmän oletukseksi",
     "group" : "ryhmä",
     "conversation" : "keskustelu",
     "remote" : "etä",
@@ -167,88 +121,158 @@ OC.L10N.register(
     "Shared with the group {user} by {owner}" : "Jaettu ryhmän {user} kanssa käyttäjältä {owner}",
     "Shared with the conversation {user} by {owner}" : "Jaettu keskustelun {user} kanssa käyttäjältä {owner}",
     "Shared with {user} by {owner}" : "{owner} jakoi käyttäjälle {user}",
-    "Allow download" : "Salli lataus",
+    "Open Sharing Details" : "Avaa jakamisen yksityiskohdat",
     "Added by {initiator}" : "Lisäyksen tehnyt {initiator}",
     "Via “{folder}”" : "“{folder}” kautta",
-    "Internal link" : "Sisäinen linkki",
+    "Unshare" : "Lopeta jakaminen",
+    "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
     "Copy internal link to clipboard" : "Kopioi sisäinen linkki leikepöydälle",
     "Link copied" : "Linkki kopioitu",
-    "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
-    "Copy to clipboard" : "Kopioi leikepöydälle",
-    "Only works for users with access to this folder" : "Toimii vain käyttäjille, joilla on oikeus tähän kansioon",
-    "Only works for users with access to this file" : "Toimii vain käyttäjille, joilla on käyttöoikeus tähän tiedostoon",
-    "Copy public link to clipboard" : "Kopioi julkinen linkki leikepöydälle",
+    "Internal link" : "Sisäinen linkki",
+    "Shared via link by {initiator}" : "Jaettu linkin kautta käyttäjältä {initiator}",
+    "Mail share ({label})" : "Sähköpostijako ({label})",
+    "Share link ({label})" : "Jaa linkki ({label})",
+    "Share link ({index})" : "Jaa linkki ({index})",
+    "Create public link" : "Luo julkinen linkki",
+    "Actions for \"{title}\"" : "Toiminnot kohteelle \"{title}\"",
+    "Copy public link of \"{title}\" to clipboard" : "Kopioi kohteen \"{title}\" julkinen linkki leikepöydälle",
+    "Error, please enter proper password and/or expiration date" : "Virhe, lisää kelvollinen salasana ja/tai päättymispäivä",
+    "Link share created" : "Linkkijako luotu",
+    "Error while creating the share" : "Virhe jakoa luotaessa",
     "Please enter the following required information before creating the share" : "Anna seuraavat vaaditut tiedot, ennen kuin luot jaon",
     "Password protection (enforced)" : "Salasanasuojaus (pakotettu)",
     "Password protection" : "Salasanasuojaus",
     "Enter a password" : "Syötä salasana",
-    "Expiration date (enforced)" : "Vanhenemispäivä (pakotettu)",
     "Create share" : "Luo jako",
-    "Cancel" : "Peruuta",
-    "Share label" : "Jaon nimi",
-    "Hide download" : "Piilota lataus",
-    "Password protect" : "Suojaa salasanalla",
-    "Password expires {passwordExpirationTime}" : "Salasana vanhenee {passwordExpirationTime}",
-    "Password expired" : "Salasana vanheni",
-    "Video verification" : "Videovarmistus",
-    "Enter a note for the share recipient" : "Lisää muistiinpano jaon vastaanottajalle",
+    "Customize link" : "Mukauta linkkiä",
+    "Generate QR code" : "Luo QR-koodi",
     "Add another link" : "Lisää toinen linkki",
     "Create a new share link" : "Luo uusi jakolinkki",
-    "Shared via link by {initiator}" : "Jaettu linkin kautta käyttäjältä {initiator}",
-    "Mail share ({label})" : "Sähköpostijako ({label})",
-    "Share link ({label})" : "Jaa linkki ({label})",
-    "Share link" : "Jaa linkki",
-    "Error, please enter proper password and/or expiration date" : "Virhe, lisää kelvollinen salasana ja/tai päättymispäivä",
-    "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
-    "Resharing is not allowed" : "Uudellenjako ei ole salluttu",
+    "View only" : "Vain katselu",
+    "Can edit" : "Voi muokata",
+    "Custom permissions" : "Mukautetut oikeudet",
+    "Resharing is not allowed" : "Uudelleenjako ei ole sallittu",
     "Name or email …" : "Nimi tai sähköposti...",
     "Name, email, or Federated Cloud ID …" : "Nimi, sähköposti tai federoitu Cloud ID...",
     "Searching …" : "Haetaan…",
     "No elements found." : "Elementtejä ei löytynyt.",
     "Search globally" : "Hae globaalisti",
+    "Guest" : "Vieras",
+    "Group" : "Ryhmä",
+    "Email" : "Sähköposti",
+    "Team" : "Tiimi",
+    "Talk conversation" : "Talk-keskustelu",
+    "Deck board" : "Deck-taulu",
     "on {server}" : "palvelimella {server}",
+    "Note:" : "Huomioi:",
+    "File drop" : "Tiedoston pudotus",
+    "Terms of service" : "Käyttöehdot",
+    "Nickname" : "Nimimerkki",
+    "Share with {userName}" : "Jaa käyttäjän {userName} kanssa",
+    "Share with group" : "Jaa ryhmän kanssa",
+    "Share in conversation" : "Jaa keskustelussa",
+    "Share with remote group" : "Jaa etäryhmän kanssa",
+    "Share with guest" : "Jaa vieraan kanssa",
+    "Update share" : "Päivitä jako",
+    "Save share" : "Tallenna jako",
+    "Read" : "Lue",
+    "Create" : "Luo",
+    "Edit" : "Muokkaa",
+    "Share" : "Jaa",
+    "Delete" : "Poista",
+    "Allow upload and editing" : "Salli lähetys ja muokkaus",
+    "Allow editing" : "Salli muokkaus",
+    "Advanced settings" : "Lisäasetukset",
+    "Share label" : "Jaon nimi",
+    "Set password" : "Aseta salasana",
+    "Password expires {passwordExpirationTime}" : "Salasana vanhenee {passwordExpirationTime}",
+    "Password expired" : "Salasana vanheni",
+    "Video verification" : "Videovarmistus",
+    "Expiration date (enforced)" : "Vanhenemispäivä (pakotettu)",
+    "Set expiration date" : "Aseta vanhenemispäivä",
+    "Hide download" : "Piilota lataus",
+    "Note to recipient" : "Huomio vastaanottajalle",
+    "Enter a note for the share recipient" : "Lisää muistiinpano jaon vastaanottajalle",
+    "Delete share" : "Poista jako",
     "Others with access" : "Muut, joilla on käyttöoikeus",
-    "No other users with access found" : "Ei löytynyt muita käyttäjiä, joilla olisi käyttöoikeus",
     "Toggle list of others with access to this directory" : "Vaihda näkymää kansioon käyttöoikeuden omaavista käyttäjistä",
     "Toggle list of others with access to this file" : "Vaihda näkymää tiedostoon käyttöoikeuden omaavista käyttäjistä",
+    "Shares" : "Jaot",
     "Unable to load the shares list" : "Jakolistan haku epäonnistui",
     "Expires {relativetime}" : "Vanhenee {relativetime}",
     "this share just expired." : "tämä jako vanheni juuri.",
     "Shared with you by {owner}" : "{owner} jakoi tämän kanssasi",
+    "Internal shares" : "Sisäiset jaot",
+    "External shares" : "Ulkoiset jaot",
     "Link to a file" : "Linkki tiedostoon",
-    "Error creating the share: {errorMessage}" : "Virhe luotaessa jakoa: {errorMessage}",
-    "Error creating the share" : "Virhe jakoa luotaessa",
+    "_Accept share_::_Accept shares_" : ["Hyväksy jako","Hyväksy jaot"],
+    "Open in Files" : "Avaa tiedostosovelluksessa",
+    "_Reject share_::_Reject shares_" : ["Hylkää jako","Hylkää jaot"],
+    "_Restore share_::_Restore shares_" : ["Palauta jako","Palauta jaot"],
+    "Shared" : "Jaettu",
+    "Shared by {ownerDisplayName}" : "Jakanut {ownerDisplayName}",
+    "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
+    "Show sharing options" : "Näytä jakamisen valinnat",
+    "Shared with others" : "Jaettu muiden kanssa",
+    "No file" : "Ei tiedostoa",
+    "Public share" : "Julkinen jako",
+    "Overview of shared files." : "Yleisnäkymä jaetuista tiedostoista.",
+    "No shares" : "Ei jakoja",
+    "Files and folders you shared or have been shared with you will show up here" : "Tiedostot ja kansiot, jotka olet jakanut tai jotka on jaettu kanssasi, näkyvät täällä",
+    "Shared with you" : "Jaettu kanssasi",
+    "List of files that are shared with you." : "Luettelo kanssasi jaetuista tiedostoista.",
+    "Nothing shared with you yet" : "Kanssasi ei ole vielä jaettu mitään",
+    "Files and folders others shared with you will show up here" : "Kanssasi jaetut tiedostot ja kansiot näkyvät täällä",
+    "List of files that you shared with others." : "Luettelo muille jakamistasi tiedostoista.",
+    "Nothing shared yet" : "Ei mitään jaettua",
+    "Files and folders you shared will show up here" : "Tiedostot ja kansiot, jotka olet jakanut, näkyvät täällä",
+    "Shared by link" : "Jaettu linkin kautta",
+    "List of files that are shared by link." : "Luettelo tiedostoista, jotka on jaettu linkin kautta.",
+    "No shared links" : "Ei jaettuja linkkejä",
+    "Files and folders you shared by link will show up here" : "Linkin kautta jakamasi tiedostot ja kansiot näkyvät täällä",
+    "Deleted shares" : "Poistetut jaot",
+    "No deleted shares" : "Ei poistettuja jakoja",
+    "Pending shares" : "Odottavat jaot",
+    "List of unapproved shares." : "Luettelo hyväksymättömistä jaoista.",
+    "No pending shares" : "Ei odottavia jakoja",
+    "Shares you have received but not approved will show up here" : "Vastaanottamasi jaot, joita ei ole hyväksytty, näkyvät täällä",
     "Error updating the share: {errorMessage}" : "Virhe päivittäessä jakoa: {errorMessage}",
     "Error updating the share" : "Virhe jakoa päivittäessä",
-    "Shared" : "Jaettu",
-    "Share" : "Jaa",
+    "File \"{path}\" has been unshared" : "Tiedoston \"{path}\" jakaminen on lopetettu",
+    "Folder \"{path}\" has been unshared" : "Kansion \"{path}\" jakaminen on lopetettu",
+    "Shared by" : "Jakanut",
     "Shared with" : "Jaettu",
+    "Password created successfully" : "Salasana luotu onnistuneesti",
     "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjältä {owner}",
     "Shared with you and {circle} by {owner}" : "{owner} on jakanut tämän sinun ja piirin {circle} kanssa",
     "Shared with you and the conversation {conversation} by {owner}" : "{owner} on jakanut tämän sinun ja keskustelun {conversation} kanssa",
     "Shared with you in a conversation by {owner}" : "{owner} jakoi tämän kanssasi keskustelussa",
-    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
-    "Name" : "Nimi",
-    "Share time" : "Jakamisen ajankohta",
-    "Expiration date" : "Vanhenemispäivä",
-    "Sorry, this link does not seem to work anymore." : "Valitettavasti tämä linkki ei vaikuta enää toimivan.",
-    "Reasons might be:" : "Mahdollisia syitä saattavat olla:",
-    "the item was removed" : "kohde poistettiin",
-    "the link expired" : "linkki vanheni",
-    "sharing is disabled" : "jakaminen on poistettu käytöstä",
-    "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin.",
     "Share note" : "Jaa muistiinpano",
+    "Show list view" : "Näytä listanäkymä",
+    "Show grid view" : "Näytä ruudukkonäkymä",
     "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
     "Note" : "Huomio",
     "Select or drop files" : "Valitse tai pudota tiedostoja",
     "Uploading files" : "Lähetetään tiedostoja",
     "Uploaded files:" : "Lähetetyt tiedostot:",
     "By uploading files, you agree to the %1$sterms of service%2$s." : "Tiedostoja lähettämällä hyväksyt %1$skäyttöehdot%2$s.",
+    "Share not found" : "Jakoa ei löytynyt",
+    "Back to %s" : "Takaisin kohtaan %s",
     "Add to your Nextcloud" : "Lisää Nextcloudiisi",
-    "Wrong share ID, share doesn't exist" : "Väärä jakotunniste, jakoa ei ole olemassa",
-    "Wrong path, file/folder doesn't exist" : "Väärä polku, tiedostoa tai kansiota ei ole olemassa",
-    "Cannot change permissions for public share links" : "Julkisten jakolinkkien oikeuksia ei voi muuttaa",
-    "Sorry, this link doesn’t seem to work anymore." : "Valitettavasti linkki ei vaikuta enää toimivan.",
-    "Toggle grid view" : "Ruudukkonäkymä päälle/pois"
+    "Waiting…" : "Odotetaan…",
+    "error" : "virhe",
+    "finished" : "valmis",
+    "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
+    "Move or copy" : "Siirrä tai kopioi",
+    "You can upload into this folder" : "Voit lähettää tiedostoja tähän kansioon",
+    "No compatible server found at {remote}" : "Yhteensopivaa palvelinta ei löytynyt osoitteesta {remote}",
+    "Invalid server URL" : "Virheellinen palvelimen URL",
+    "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
+    "Files" : "Tiedostot",
+    "Download all files" : "Lataa kaikki tiedostot",
+    "Search for share recipients" : "Etsi jaon vastaanottajia",
+    "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
+    "Allow download" : "Salli lataus",
+    "Enter your name" : "Kirjoita nimesi"
 },
 "nplurals=2; plural=(n != 1);");
