@@ -14,62 +14,54 @@ OC.L10N.register(
     "On this day" : "На този ден",
     "Shared with you" : "Споделени с вас",
     "Tags" : "Етикети",
-    "Locations" : "Местоположения",
+    "Places" : "Места",
+    "Map" : "Карта",
     "Photos settings" : "Настройки на снимки",
     "Mark selection as favorite" : "Маркиране на селекцията като любима",
     "Add selection to favorites" : "Добавяне на селекция към любими",
     "Remove selection from favorites" : "Премахване на селекция от любими",
     "Name of the album" : "Име на албума",
     "Location of the album" : "Местоположение на албума",
-    "Go back to the previous view." : "Връщане към предишния изглед.",
     "Back" : "Назад",
-    "Go to the add collaborators view." : "Отиване до изглед за добавяне на сътрудници.",
     "Add collaborators" : "Добавяне на сътрудници",
-    "Save." : "Запиши.",
-    "Create the album." : "Създаване на албума.",
     "Save" : "Запиши",
     "Create album" : "Създаване на албум",
-    "Back to the new album form." : "Обратно към формата на новия албум.",
     "Add to Album" : "Добавяне към Албум",
     "Add selection to album {albumName}" : "Добавяне на селекция към албум {ablumName}",
+    "Shared by" : "Споделено от",
     "Create a new album." : "Създаване на нов албум.",
     "Create new album" : "Създаване на нов албум",
     "New album" : "Нов албум",
     "_%n item_::_%n photos and videos_" : ["%n снимки и видеоклипове","%n снимки и видеоклипове"],
-    "_Share with %n user_::_Share with %n users_" : ["Споделяне с %n потребители","Споделяне с %n потребители"],
+    "Failed to fetch collaborators list." : "Неуспешно извличане на списък със сътрудници.",
+    "Failed to update album." : "Неуспешно обновяване на албум.",
     "Add people or groups who can edit your album" : "Добавяне на хора или групи, които могат да редактират вашият албум",
-    "Search for collaborators" : "Търсене на сътрудници",
     "Search people or groups" : "Търсене на хора или групи",
-    "Add {collaboratorLabel} to the collaborators list" : "Добавяне на {collaboratorLabel} към списъка със сътрудници",
-    "No collaborators available" : "Няма налични сътрудници",
+    "No recommendations. Start typing." : "Няма препоръки. Започнете да пишете.",
     "Remove {collaboratorLabel} from the collaborators list" : "Премахване на {collaboratorLabel} от списъка със сътрудници",
     "Copy the public link" : "Копиране на публичната връзка",
     "Public link copied!" : "Копирана е публична връзка!",
     "Copy public link" : "Копирай публичната връзка",
     "Delete the public link" : "Изтриване на публичната връзка",
     "Share via public link" : "Споделяне чрез публична връзка",
-    "Failed to fetch collaborators list." : "Неуспешно извличане на списък със сътрудници.",
-    "Failed to fetch album." : "Неуспешно извличане на албум.",
-    "Failed to update album." : "Неуспешно обновяване на албум.",
     "This collection does not exist" : "Тази колекция не съществува",
     "An error occurred" : "Възникна грешка",
-    "_%n photos_::_%n photos_" : ["%n снимки ","%n снимки"],
-    "Select image {imageName}" : "Избор на изображение {imageName}",
-    "The file is in the favorites" : "Файлът е в любими",
+    "Favorite" : "Любими",
     "Open the full size \"{name}\" image" : "Отваряне на изображението\"{name}“  в пълен размер ",
-    "There are no photos or videos yet!" : "Все още няма снимки или видеоклипове!",
-    "Add to {destination}" : "Добавяне към  {destination}",
-    "Open the \"{name}\" sub-directory" : "Отваряне на \"{name}“  поддиректория ",
+    "Select image {imageName}" : "Избор на изображение {imageName}",
     "Back to {folder}" : "Назад към {folder}",
+    "Go back" : "Назад",
     "Share this folder" : "Споделяне на тази папка",
+    "Add to {destination}" : "Добавяне към  {destination}",
+    "There are no photos or videos yet!" : "Все още няма снимки или видеоклипове!",
     "_{years} year ago_::_{years} years ago_" : ["Преди {years} години","Преди {years} години"],
     "Enable squared photos view" : "Активирайте изгледа на снимки в квадратче",
-    "Default Photos upload and Albums location" : "Качване на снимки и местоположение на албуми по подразбиране",
-    "Select the default location for your media" : "Избор местоположение по подразбиране за вашата медия",
-    "Invalid location selected" : "Избрано е невалидно местоположение",
+    "Add folder" : "Добави папка",
+    "Home" : "Начало",
     "View" : "Изглед",
-    "Photos directory" : "Директория със снимки",
     "_%n photo_::_%n photos_" : ["%n снимки","%n снимки"],
+    "Unselect all" : "Отмяна на избора на всички",
+    "Add photos to this album" : "Добавяне на снимки към този албум",
     "Manage collaborators for this album" : "Управление на сътрудници за този албум",
     "Open actions menu" : "Отворяне на менюто с действия",
     "Edit album details" : "Редактиране на подробности за албума",
@@ -78,8 +70,6 @@ OC.L10N.register(
     "Download selected files" : "Изтегляне на избраните файлове",
     "Remove selection from album" : "Премахване на селекция от албума",
     "This album does not have any photos or videos yet!" : "Този албум все още няма снимки или видеоклипове!",
-    "Add photos to this album" : "Добавяне на снимки към този албум",
-    "Add photos to the album" : "Добавяне на снимки към албума",
     "Manage collaborators" : "Управление на сътрудници",
     "Save collaborators for this album." : "Запис на сътрудници за този албум.",
     "Cover photo for album {albumName}" : "Снимка на корицата на албум {albumName}",
@@ -88,44 +78,51 @@ OC.L10N.register(
     "Rename person" : "Преименуване на лице",
     "Merge with different person" : "Обединяване с различно лице",
     "Download selected photos" : "Изтегляне на избрани снимки",
-    "Favorite" : "Любими",
     "Remove from favorites" : "Премахване от любими",
     "Remove person" : "Премахване на лице",
     "Name of this person" : "Име лицето",
+    "Save." : "Запиши.",
     "Merge person" : "Обединяване на лице",
+    "_Move photo to a different person_::_Move photos to a different person_" : ["Преместване на снимки към друго лице","Преместване на снимки към друго лице"],
     "_Remove photo from person_::_Remove photos from person_" : ["Премахване на снимки от лице","Премахване на снимки от лице"],
     "This might take some time depending on the size of your photo library." : "Това може да отнеме известно време в зависимост от размера на вашата библиотека със снимки.",
     "Recognized people will show up here" : "Разпознатите хора ще се показват тук",
     "This folder does not exist" : "Тази папка не съществува",
     "Loading folders …" : "Зареждане на папките …",
     "No photos in here" : "Тук няма снимки",
-    "Failed to fetch albums list." : "Неуспешно извличане на списък с албуми.",
-    "Shared albums" : "Споделени албуми",
+    "This place does not have any photos or videos yet!" : "Това място все още няма снимки или видеоклипове!",
+    "Add photos to this place" : "Добавяне на снимки към това място",
+    "Cover photo for place {placeName}" : "Снимка на корицата за място {placeName}",
+    "There is no place yet!" : "Все още няма място!",
     "Cover photo for shared album {albumName}." : "Снимка на корицата на споделен албум {albumName}",
     "Back to tags overview" : "Обратно към преглед на етикети",
     "No photos with this tag yet" : "Все още няма снимки с този етикет",
     "No tags yet" : "Все още няма етикети",
     "Photos with tags will show up here" : " Снимки с етикети ще се покажат тук",
     "Popular tags" : "Популярни етикети",
-    "Add" : "Добавяне",
-    "Create a new album" : "Създаване на нов албум",
-    "Add selection to an album" : "Добавяне на селекция към албум",
     "Add to album" : "Добавяне към албум",
     "Delete selection" : "Изтриите селекцията",
+    "No photos or videos in here" : "Тук няма снимки или видеоклипове",
+    "_%n photos_::_%n photos_" : ["%n снимки ","%n снимки"],
+    "Failed to fetch collection." : "Неуспешно извличане на колекция.",
+    "Failed to fetch collections list." : "Неуспешно извличане на списък с колекции.",
     "Failed to fetch faces list." : "Неуспешно извличане на списък с лица.",
     "All your media" : "Всички ваши медии",
+    "Album {title}" : "Албум {title}",
+    "Shared Albums" : "Споделени албуми",
+    "Shared album {title}" : "Споделен албум {title}",
+    "Public album {title}" : "Публичен албум {title}",
     "Tagged photos" : "Маркирани снимки",
-    "Failed to create {albumName}." : "Неуспешно създаване на {albumName}.",
-    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Неуспешно преименуване от {currentAlbumName} на {newAlbumName}.",
+    "Tagged photo {title}" : "Маркирана снимка {title}",
+    "{title}'s face" : "Лицето на {title}",
+    "{startDate} to {endDate}" : "{startDate} до {endDate}",
+    "Details" : "Подробности",
     "Failed to rename {oldName} to {faceName}." : "Неуспешно преименуване от {oldName} на {faceName}.",
     "Failed to delete {faceName}." : "Неуспешно изтриване на {faceName}.",
     "Failed to delete {fileId}." : "Неуспешно изтриване на {fileId}.",
     "Failed to delete {fileName}." : "Неуспешно изтриване на {fileName}.",
     "Failed to set favorite state for {fileId}." : "Неуспешно задаване на предпочитано/любимо/ състояние за {fileId}.",
     "Failed to set favorite state for {fileName}." : "Неуспешно задаване на предпочитано/любимо/ състояние за {fileName}.",
-    "Your photos" : "Вашите снимки",
-    "Your videos" : "Вашите видеа",
-    "Your folders" : "Вашите папки",
-    "Settings" : "Настройки"
+    "Add" : "Добавяне"
 },
 "nplurals=2; plural=(n != 1);");
