@@ -3,73 +3,90 @@ OC.L10N.register(
     {
     "Public link" : "公开链接",
     "Photos" : "照片",
+    "On This Day" : "在这一天",
     "Your memories under your control" : "您的回忆在您的掌控之下",
     "All media" : "所有媒体",
     "Videos" : "视频",
-    "Albums" : "专辑",
+    "Albums" : "相册",
     "Collaborative albums" : "协作相册",
     "People" : "人物",
     "Folders" : "文件夹",
     "Favorites" : "收藏",
     "On this day" : "当年今日",
-    "Shared with you" : "共享给您的",
+    "Shared with you" : "与你共享",
     "Tags" : "标签",
-    "Locations" : "地点",
+    "Places" : "地点",
+    "Map" : "地图",
     "Photos settings" : "照片设置",
     "Mark selection as favorite" : "将已选项标记为最爱",
     "Add selection to favorites" : "添加已选项至最爱",
     "Remove selection from favorites" : "从最爱中移除所选项",
     "Name of the album" : "相册名称",
     "Location of the album" : "相册位置",
-    "Go back to the previous view." : "返回上一个视图。",
     "Back" : "返回",
-    "Go to the add collaborators view." : "到添加协作者视图。",
     "Add collaborators" : "添加协作者",
-    "Save." : "保存。",
-    "Create the album." : "创建相册。",
     "Save" : "保存",
     "Create album" : "创建相册",
-    "Back to the new album form." : "回到创建新相册表单。",
     "Add to Album" : "添加至相册",
     "Add selection to album {albumName}" : "将所选项加入相册 {ablumName}",
+    "Shared by" : "共享人",
     "Create a new album." : "创建新相册。",
     "Create new album" : "创建新相册",
     "New album" : "新相册",
     "_%n item_::_%n photos and videos_" : ["%n 张照片与视频"],
-    "_Share with %n user_::_Share with %n users_" : ["与 %n 位用户分享"],
+    "Failed to fetch collaborators list." : "获取协作者列表失败。",
+    "Failed to update album." : "更新相册失败。",
     "Add people or groups who can edit your album" : "添加可以编辑您相册的用户与群组",
-    "Search for collaborators" : "搜索协作者",
     "Search people or groups" : "搜索用户或群组",
-    "Add {collaboratorLabel} to the collaborators list" : "将 {collaboratorLabel} 加入协作者列表",
-    "No collaborators available" : "没有可用的协作者",
+    "No recommendations. Start typing." : "无建议。开始输入。",
+    "Group" : "群组",
     "Remove {collaboratorLabel} from the collaborators list" : "将 {collaboratorLabel} 移除协作者列表",
     "Copy the public link" : "复制公开链接",
     "Public link copied!" : "已复制公开链接！",
     "Copy public link" : "复制公开链接",
     "Delete the public link" : "删除公开链接",
+    "Create public link share" : "创建公开链接分享",
     "Share via public link" : "通过公开链接分享",
-    "Failed to fetch collaborators list." : "无法获取协作者列表。",
-    "Failed to fetch album." : "无法获取相册。",
-    "Failed to update album." : "无法更新相册。",
     "This collection does not exist" : "此收藏不存在",
     "An error occurred" : "发生错误",
-    "_%n photos_::_%n photos_" : ["%n张照片"],
-    "Select image {imageName}" : "选择图像 {imageName}",
-    "The file is in the favorites" : "此文件在最爱中",
+    "No picture for this day" : "这一天没有照片",
+    "Picture taken on this day will show up here." : "在这一天拍摄的照片将显示在这。",
+    "More photos from this day" : "这一天更多的照片",
+    "_%n unassigned photo_::_%n unassigned photos_" : ["%n张尚未指派的照片"],
+    "Favorite" : "收藏",
+    "Favorite image, open the full size \"{name}\" image" : "收藏图像，打开 “{name}” 原图。",
     "Open the full size \"{name}\" image" : "打开图片 “{name}” 的完整尺寸",
-    "There are no photos or videos yet!" : "还没有照片或视频！",
-    "Add to {destination}" : "添加到 {destination}",
-    "Open the \"{name}\" sub-directory" : "打开 “{name}” 的子目录",
+    "Select image {imageName}" : "选择图像 {imageName}",
+    "Open the \"{name}\" folder" : "打开 “{name}” 文件夹",
     "Back to {folder}" : "返回 {folder}",
+    "Go back" : "返回",
     "Share this folder" : "共享此文件夹",
+    "Dates" : "日期",
+    "Jump to specific date in list" : "跳转至列表中指定时间",
+    "Jump to {date}" : "跳转至 {date}",
+    "Add to {destination}" : "添加到 {destination}",
+    "The destination folder is owned by {owner}" : "目标文件夹所有者为 {owner}",
+    "There are no photos or videos yet!" : "还没有照片或视频！",
     "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
     "Enable squared photos view" : "启用平铺照片视图",
-    "Default Photos upload and Albums location" : "默认的照片上传与相册位置",
-    "Select the default location for your media" : "选择您媒体的默认位置",
-    "Invalid location selected" : "所选位置无效",
+    "Delete source directory" : "删除源目录",
+    "Pick folder" : "选择文件夹",
+    "Select a source folder for your media" : "为你的媒体文件选择一个源文件夹",
+    "All folders" : "所有文件夹",
+    "Add a Photos source for the timelines" : "为时间轴添加一个照片源",
+    "Add folder" : "添加文件夹",
+    "Select the default upload location for your media" : "选择你的媒体文件默认上传位置",
+    "Home" : "首页",
+    "Choose default Photos upload and Albums location" : "选择预设照片上传与相册位置",
+    "Choose a different folder" : "选择一个不同的文件夹",
     "View" : "查看",
-    "Photos directory" : "照片目录",
+    "Media folders" : "多媒体文件夹",
+    "Choose the folders from where photos and videos are shown." : "选择显示照片和视频的文件夹。",
+    "Upload folder" : "上传文件夹",
+    "Choose the folder where photos and albums are uploaded to." : "选择照片和相册上传的文件夹。",
     "_%n photo_::_%n photos_" : ["%n张照片"],
+    "Unselect all" : "取消全选",
+    "Add photos to this album" : "添加照片至此相册",
     "Manage collaborators for this album" : "管理此相册的协作者。",
     "Open actions menu" : "打开操作菜单",
     "Edit album details" : "编辑相册详情",
@@ -78,54 +95,67 @@ OC.L10N.register(
     "Download selected files" : "下载选择的文件",
     "Remove selection from album" : "从相册中移除所选项",
     "This album does not have any photos or videos yet!" : "这个相册中还没有任何照片或视频！",
-    "Add photos to this album" : "添加照片至此相册",
-    "Add photos to the album" : "添加照片至此相册",
+    "Add photos to {albumName}" : "添加照片至相簿 {albumName}",
     "Manage collaborators" : "管理协作者",
     "Save collaborators for this album." : "保存此相册的协作者。",
     "Cover photo for album {albumName}" : "相册 {albumName} 的封面照片",
-    "There is no album yet!" : "还没有相册",
+    "There is no album yet!" : "还没有相册！",
     "This person could not be found" : "找不到这个人",
     "Rename person" : "修改此人姓名",
     "Merge with different person" : "与另一个人合并为同一人",
     "Download selected photos" : "下载所选照片",
-    "Favorite" : "收藏",
     "Remove from favorites" : "从收藏中移除",
     "Remove person" : "移除这个人",
     "Name of this person" : "这个人的名字",
-    "Merge person" : "合并人",
+    "Save." : "保存。",
+    "Merge person" : "合并人物",
+    "Move to different person" : "移动到其他人",
+    "_Move photo to a different person_::_Move photos to a different person_" : ["将照片移动给其他人"],
     "_Remove photo from person_::_Remove photos from person_" : ["从关联人移除照片"],
     "This might take some time depending on the size of your photo library." : "取决于您的相册库大小，这可能会花上一些时间。",
     "Recognized people will show up here" : "被识别出的人会显示在此处",
     "This folder does not exist" : "此文件夹不存在",
     "Loading folders …" : "正在加载文件夹……",
-    "No photos in here" : "这里没有照片",
-    "Failed to fetch albums list." : "无法获取相册列表。",
-    "Shared albums" : "共享的相册",
+    "No photos in here" : "此处没有照片",
+    "Taken on {date} at {time}" : "拍摄于 {date} {time}",
+    "This place does not have any photos or videos yet!" : "这个地点还没有任何照片和视频！",
+    "Add photos to this place" : "添加照片至此地点",
+    "Cover photo for place {placeName}" : "地点{placeName}的封面照片",
+    "There is no place yet!" : "还没有地点！",
     "Cover photo for shared album {albumName}." : "共享相册 {albumName} 的封面照片",
     "Back to tags overview" : "回到标签一览",
     "No photos with this tag yet" : "还没有照片拥有该标签",
     "No tags yet" : "尚无标签",
     "Photos with tags will show up here" : "带标签的照片将显示在此处",
     "Popular tags" : "常用标签",
-    "Add" : "添加",
-    "Create a new album" : "创建新相册",
-    "Add selection to an album" : "将所选项添加至相册",
+    "All tags" : "所有标签",
+    "One of the source folders does not exist" : "其中一个源文件夹不存在",
     "Add to album" : "添加至相册",
     "Delete selection" : "删除选择项",
-    "Failed to fetch faces list." : "无法获取人脸列表。",
-    "All your media" : "您的所有媒体",
+    "No photos or videos in here" : "此处没有图片或视频",
+    "Unassigned faces" : "未指派的人脸",
+    "_%n photos_::_%n photos_" : ["%n张照片"],
+    "Failed to fetch collection." : "获取合集失败",
+    "Failed to fetch collections list." : "获取合集列表失败",
+    "Failed to fetch faces list." : "获取人脸列表失败。",
+    "All your media" : "所有媒体",
+    "Album {title}" : "相册{title}",
+    "Shared Albums" : "共享的相册",
+    "Shared album {title}" : "共享的相册{title}",
+    "Public album {title}" : "公共相册{title}",
     "Tagged photos" : "标记的照片",
-    "Failed to create {albumName}." : "创建 {albumName} 失败",
-    "Failed to rename {currentAlbumName} to {newAlbumName}." : "重命名 {currentAlbumName} 为 {newAlbumName} 的操作失败",
+    "Tagged photo {title}" : "标记的相册{title}",
+    "{title}'s face" : "{title}的脸",
+    "{startDate} to {endDate}" : "{startDate} 到 {endDate}",
+    "Details" : "详情",
     "Failed to rename {oldName} to {faceName}." : "重命名 {oldName} 为 {faceName} 的操作失败",
     "Failed to delete {faceName}." : "删除 {faceName} 失败",
-    "Failed to delete {fileId}." : "删除 {field} 失败",
-    "Failed to delete {fileName}." : "删除 {fileName} 失败",
-    "Failed to set favorite state for {fileId}." : "未能为 {field} 设定最爱状态",
-    "Failed to set favorite state for {fileName}." : "未能为 {fileName} 设定最爱状态",
-    "Your photos" : "你的照片",
-    "Your videos" : "您的视频",
-    "Your folders" : "您的文件夹",
-    "Settings" : "设置"
+    "Failed to delete {fileId}." : "删除{field}失败",
+    "Failed to delete {fileName}." : "删除{fileName}失败",
+    "Failed to set favorite state for {fileId}." : "为{field}设定收藏状态失败",
+    "Failed to set favorite state for {fileName}." : "为{fileName}设定收藏状态失败",
+    "Could not load photos folder" : "无法加载照片文件夹",
+    "One of the source folders does not exists" : "其中一个源文件夹不存在",
+    "Add" : "添加"
 },
 "nplurals=1; plural=0;");
