@@ -71,7 +71,6 @@ OC.L10N.register(
     "Calendar" : "Calendario",
     "Personal info" : "Información Personal",
     "Email server" : "Servidor de correo electrónico",
-    "Security & setup warnings" : "Advertencias de seguridad y configuración",
     "Background jobs" : "Trabajos en segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificando",
@@ -79,6 +78,7 @@ OC.L10N.register(
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
+    "Enable" : "Habilitar",
     "None" : "Ninguno",
     "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
     "Allow resharing" : "Permitir volver a compartir",
@@ -92,7 +92,6 @@ OC.L10N.register(
     "Limit to groups" : "Limitar a grupos",
     "Save changes" : "Guardar cambios",
     "Remove" : "Eliminar",
-    "Disable" : "Deshabilitar",
     "Featured" : "Destacado",
     "Icon" : "Ícono",
     "Name" : "Nombre",
@@ -100,7 +99,16 @@ OC.L10N.register(
     "Level" : "Nivel",
     "Actions" : "Acciones",
     "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
+    "Type" : "Tipo",
+    "Display Name" : "Nombre a desplegar",
+    "Learn more" : "Conoce más",
+    "Confirm" : "Confirmar",
+    "Cancel" : "Cancelar",
     "Description" : "Descripción",
+    "View in store" : "Ver en la tienda",
+    "Visit website" : "Visita el sitio web",
+    "Admin documentation" : "Documentación del administrador",
+    "Developer documentation" : "Documentación del desarrollador",
     "Details" : "Detalles",
     "All" : "Todos",
     "No results" : "No hay resultados",
@@ -115,37 +123,31 @@ OC.L10N.register(
     "Request feature" : "Solicitar una funcionalidad",
     "Ask questions or discuss" : "Hacer una pregunta o comentario",
     "Rate" : "Calificar",
-    "View in store" : "Ver en la tienda",
-    "Visit website" : "Visita el sitio web",
-    "Admin documentation" : "Documentación del administrador",
-    "Developer documentation" : "Documentación del desarrollador",
     "Changelog" : "Bitácora de cambios",
+    "Google Chrome for Android" : "Google Chrome para Android",
+    "This session" : "Esta sesión",
     "Allow filesystem access" : "Permitir acceso al sistema de archivos",
     "Rename" : "Renombrar",
     "Revoke" : "Revocar",
-    "Google Chrome for Android" : "Google Chrome para Android",
-    "This session" : "Esta sesión",
     "Device" : "Dispositivo",
     "Last activity" : "Última actividad",
     "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de escritorio y móviles han iniciado sesión en tu cuenta. ",
+    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
     "App name" : "Nombre de la aplicación",
     "Create new app password" : "Crear una nueva contraseña de aplicación",
-    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
     "Login" : "Iniciar sesión",
     "Password" : "Contraseña",
-    "Enable" : "Habilitar",
     "Server-side encryption" : "Encripción del lado del servidor",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
     "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, por favor habilita un módulo de encripción en el menú de la aplicación. ",
+    "Select default encryption module:" : "Selecciona el modulo de encripción predeterminado:",
+    "Enable encryption" : "Habilitar encripción",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que la encripción se encuentre habilitada, todos lo archivos cargados al servidor desde ese momento en tiempo, se encriptarán en el servidor. Sólo será posible deshabilitar la encripción en una fecha posterior si el modulo de encripción activo soporta esa funcionalidad y si todas las preciondiciones están satisfechas (ejem. establecer una llave de recuperación).",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La encripción por sí sola no garantiza la seguridad del sistema. Por favor consulta la documentación para mayores informes de cómo funciona la aplicación de encripción y de los casos de uso soportados. ",
     "Be aware that encryption always increases the file size." : "Por favor considera que la encripción siempre aumenta el tamaño de los archivos. ",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea generar respaldos de tus datos, en caso de tener encripción asegúrate de respaldar las llaves de encripción junto con tus datos. ",
     "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente deseas habilitar la encripción?",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, por favor habilita un módulo de encripción en el menú de la aplicación. ",
-    "Select default encryption module:" : "Selecciona el modulo de encripción predeterminado:",
-    "Cancel" : "Cancelar",
-    "Confirm" : "Confirmar",
     "Submit" : "Enviar",
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña",
@@ -164,11 +166,10 @@ OC.L10N.register(
     "Quota" : "Cuota",
     "Language" : "Idioma",
     "Avatar" : "Avatar",
-    "Username" : "Usuario",
     "Group admin for" : "Administrador del grupo para",
-    "User backend" : "Backend del usuario",
     "Storage location" : "Úbicación del almacenamiento",
     "Last login" : "Último inicio de sesión",
+    "Account actions" : "Acciones de la cuenta",
     "{size} used" : "{size} usado",
     "Delete account" : "Borrar cuenta",
     "Done" : "Terminado",
@@ -193,8 +194,11 @@ OC.L10N.register(
     "Updates" : "Actualizaciones",
     "App bundles" : "Paquetes de aplicación",
     "Hide" : "Ocultar",
+    "Disable" : "Deshabilitar",
+    "Unknown" : "Desconocido",
     "Never" : "Nunca",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación está habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
+    "Error" : "Error",
     "Forum" : "Foro",
     "SSL" : "SSL",
     "Open documentation" : "Abrir documentación",
@@ -209,42 +213,14 @@ OC.L10N.register(
     "Credentials" : "Credenciales",
     "SMTP Password" : "Contraseña SMTP",
     "Save" : "Guardar",
+    "Security & setup warnings" : "Advertencias de seguridad y configuración",
     "All checks passed." : "Pasaron todas las verificaciones. ",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
-    "Follow us on Twitter" : "Síguenos en Twitter",
     "Check out our blog" : "Visita nuestro blog",
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
-    "No user supplied" : "No se proporcionó usuario alguno",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
-    "Federated Cloud Sharing" : "Compartir en la Nube Federada",
-    "Invalid user" : "Usuario inválido",
-    "Your username is: %s" : "Tu Usuario es: %s",
-    "Enable all" : "Habilitar todo",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Sync client - {os}" : "Sync client - {os}",
-    "Error while deleting the token" : "Se presentó un error al borrar la ficha",
-    "Use the credentials below to configure your app or device." : "Usa las siguientes credenciales para configurar tu aplicación o dispositivo. ",
-    "For security reasons this password will only be shown once." : "Por razones de seguridad esta contraseña sólo se mostrará una vez. ",
-    "Copied!" : "¡Copiado!",
-    "Copy" : "Copiar",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para correr esto necesitas la extensión POSIX de PHP. Por favor ve la {linkstart}documentación de PHP{linkend} para más detalles. ",
-    "png or jpg, max. 20 MB" : "png o jpg max. 20 MB",
-    "Your email address" : "Tu dirección de correo electrónico",
-    "Your Twitter handle" : "Tu cuenta de Twitter",
-    "Add group" : "Agregar grupo",
-    "Active users" : "Usuarios activos",
-    "Show user backend" : "Mostrar backend del usuario",
-    "Send email to new user" : "Enviar un correo electrónico al usuario nuevo",
-    "Not saved" : "No guardado",
-    "Twitter" : "Twitter",
-    "SMTP Username" : "Usuario SMTP",
-    "Set default expiration date" : "Establecer la fecha de expiración predeterminada",
-    "Exclude groups from sharing" : "Evitar que los grupos compartan",
-    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir elementos compartidos, pero no los podrán iniciar."
+    "Username" : "Usuario",
+    "User backend" : "Backend del usuario",
+    "Follow us on Twitter" : "Síguenos en Twitter"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
