@@ -10,12 +10,12 @@ OC.L10N.register(
     "Could not write file to disk" : "Nu s-a putut scrie fișierul pe disc",
     "A PHP extension stopped the file upload" : "O extensie PHP a oprit încărcarea fișierelor",
     "No file uploaded or file size exceeds maximum of %s" : "Niciun fișier pentru încărcare sau s-a depășit maximul de %s",
+    "File not found" : "Fișierul nu a fost găsit",
     "Text" : "Text",
     "Translate" : "Tradu",
-    "Use current version" : "Folosește versiunea curentă",
-    "Use the saved version" : "Folosește versiuna salvată",
     "Reload" : "Reîncarcă",
     "Guest" : "Invitat",
+    "Remove link" : "Șterge link-ul",
     "guest" : "invitat",
     "Offline" : "Offline",
     "Saving …" : "Se salvează",
@@ -23,8 +23,10 @@ OC.L10N.register(
     "Unsaved changes" : "Modificări nesalvate",
     "Keyboard shortcuts" : "Scurtături din tastatură",
     "Quoted text" : "Text citat",
+    "Link" : "Legătură",
     "Undo" : "Anulează ultima acțiune",
     "Redo" : "Repetă",
+    "Cannot copy, please copy the link manually" : "Nu s-a putut copia, vă rugăm să copiați link-ul manual",
     "Edit link" : "Editare link",
     "Cancel" : "Anulare",
     "URL" : "URL",
@@ -34,9 +36,15 @@ OC.L10N.register(
     "Replace" : "Înlocuiește",
     "Edit" : "Editează",
     "Source code" : "Cod sursă",
+    "Done" : "Realizat",
+    "Lists" : "Liste",
+    "Details" : "Detalii",
+    "Formatting" : "Formatare",
+    "Add folder description" : "Adăugați descrierea directorului",
+    "Use current version" : "Folosește versiunea curentă",
+    "Use the saved version" : "Folosește versiuna salvată",
     "Info" : "Info",
     "Success" : "Succes",
-    "Warning" : "Atenție",
-    "Formatting" : "Formatare"
+    "Warning" : "Atenție"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
