@@ -3,11 +3,13 @@
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  *
  * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
+ * @author Christoph Wurst <christoph@winzerhof-wurst.at>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author Juan Pablo Villafáñez <jvillafanez@solidgear.es>
  * @author Lukas Reschke <lukas@statuscode.ch>
- * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <robin@icewind.nl>
- * @author Thomas Müller <thomas.mueller@tmit.eu>
+ * @author Roeland Jago Douma <roeland@famdouma.nl>
+ * @author Roger Szabo <roger.szabo@web.de>
  *
  * @license AGPL-3.0
  *
@@ -21,50 +23,40 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
-
 // Check user and app status
-OCP\JSON::checkAdminUser();
-OCP\JSON::checkAppEnabled('user_ldap');
-OCP\JSON::callCheck();
+\OC_JSON::checkAdminUser();
+\OC_JSON::checkAppEnabled('user_ldap');
+\OC_JSON::callCheck();
 
-$l = \OC::$server->getL10N('user_ldap');
+$l = \OCP\Util::getL10N('user_ldap');
 
-if(!isset($_POST['action'])) {
-	\OCP\JSON::error(array('message' => $l->t('No action specified')));
+if (!isset($_POST['action'])) {
+	\OC_JSON::error(['message' => $l->t('No action specified')]);
 }
 $action = (string)$_POST['action'];
 
-
-if(!isset($_POST['ldap_serverconfig_chooser'])) {
-	\OCP\JSON::error(array('message' => $l->t('No configuration specified')));
+if (!isset($_POST['ldap_serverconfig_chooser'])) {
+	\OC_JSON::error(['message' => $l->t('No configuration specified')]);
 }
 $prefix = (string)$_POST['ldap_serverconfig_chooser'];
 
 $ldapWrapper = new \OCA\User_LDAP\LDAP();
 $configuration = new \OCA\User_LDAP\Configuration($prefix);
 
-$con = new \OCA\User_LDAP\Connection($ldapWrapper, '', null);
+$con = new \OCA\User_LDAP\Connection($ldapWrapper, $prefix, null);
 $con->setConfiguration($configuration->getConfiguration());
 $con->ldapConfigurationActive = true;
 $con->setIgnoreValidation(true);
 
-$userManager = new \OCA\User_LDAP\User\Manager(
-	\OC::$server->getConfig(),
-	new \OCA\User_LDAP\FilesystemHelper(),
-	new \OCA\User_LDAP\LogWrapper(),
-	\OC::$server->getAvatarManager(),
-	new \OCP\Image(),
-	\OC::$server->getDatabaseConnection(),
-	\OC::$server->getUserManager());
-
-$access = new \OCA\User_LDAP\Access($con, $ldapWrapper, $userManager, new \OCA\User_LDAP\Helper());
+$factory = \OC::$server->get(\OCA\User_LDAP\AccessFactory::class);
+$access = $factory->get($con);
 
 $wizard = new \OCA\User_LDAP\Wizard($configuration, $ldapWrapper, $access);
 
-switch($action) {
+switch ($action) {
 	case 'guessPortAndTLS':
 	case 'guessBaseDN':
 	case 'detectEmailAttribute':
@@ -83,15 +75,15 @@ switch($action) {
 	case 'countInBaseDN':
 		try {
 			$result = $wizard->$action();
-			if($result !== false) {
-				OCP\JSON::success($result->getResultArray());
+			if ($result !== false) {
+				\OC_JSON::success($result->getResultArray());
 				exit;
 			}
 		} catch (\Exception $e) {
-			\OCP\JSON::error(array('message' => $e->getMessage(), 'code' => $e->getCode()));
+			\OC_JSON::error(['message' => $e->getMessage(), 'code' => $e->getCode()]);
 			exit;
 		}
-		\OCP\JSON::error();
+		\OC_JSON::error();
 		exit;
 		break;
 
@@ -99,41 +91,44 @@ switch($action) {
 		try {
 			$loginName = $_POST['ldap_test_loginname'];
 			$result = $wizard->$action($loginName);
-			if($result !== false) {
-				OCP\JSON::success($result->getResultArray());
+			if ($result !== false) {
+				\OC_JSON::success($result->getResultArray());
 				exit;
 			}
 		} catch (\Exception $e) {
-			\OCP\JSON::error(array('message' => $e->getMessage()));
+			\OC_JSON::error(['message' => $e->getMessage()]);
 			exit;
 		}
-		\OCP\JSON::error();
+		\OC_JSON::error();
 		exit;
 		break;
 	}
 
 	case 'save':
-		$key = isset($_POST['cfgkey']) ? $_POST['cfgkey'] : false;
-		$val = isset($_POST['cfgval']) ? $_POST['cfgval'] : null;
-		if($key === false || is_null($val)) {
-			\OCP\JSON::error(array('message' => $l->t('No data specified')));
+		$key = $_POST['cfgkey'] ?? false;
+		$val = $_POST['cfgval'] ?? null;
+		if ($key === false || is_null($val)) {
+			\OC_JSON::error(['message' => $l->t('No data specified')]);
 			exit;
 		}
-		$cfg = array($key => $val);
-		$setParameters = array();
+		if (is_array($key)) {
+			\OC_JSON::error(['message' => $l->t('Invalid data specified')]);
+			exit;
+		}
+		$cfg = [$key => $val];
+		$setParameters = [];
 		$configuration->setConfiguration($cfg, $setParameters);
-		if(!in_array($key, $setParameters)) {
-			\OCP\JSON::error(array('message' => $l->t($key.
-				' Could not set configuration %s', $setParameters[0])));
+		if (!in_array($key, $setParameters)) {
+			\OC_JSON::error(['message' => $l->t('Could not set configuration %1$s to %2$s', [$key, $setParameters[0]])]);
 			exit;
 		}
 		$configuration->saveConfiguration();
 		//clear the cache on save
 		$connection = new \OCA\User_LDAP\Connection($ldapWrapper, $prefix);
 		$connection->clearCache();
-		OCP\JSON::success();
+		\OC_JSON::success();
 		break;
 	default:
-		\OCP\JSON::error(array('message' => $l->t('Action does not exist')));
+		\OC_JSON::error(['message' => $l->t('Action does not exist')]);
 		break;
 }
