@@ -96,10 +96,10 @@ OC.L10N.register(
     "No" : "No",
     "Yes" : "Sí",
     "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar el link público a su Nextcloud",
-    "Date" : "Fecha",
-    "Today" : "Hoy",
-    "Load more results" : "Cargar más resultados",
     "Searching …" : "Buscando ...",
+    "Today" : "Hoy",
+    "Date" : "Fecha",
+    "Load more results" : "Cargar más resultados",
     "Log in" : "Ingresar",
     "Logging in …" : "Ingresando ...",
     "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
@@ -108,8 +108,8 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Favor de volver a intentarlo o contacte a su adminsitrador. ",
     "Password" : "Contraseña",
     "Reset password" : "Restablecer contraseña",
-    "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Favor de contactar a su adminsitrador. ",
     "Back to login" : "Volver para iniciar sesión",
+    "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Favor de contactar a su adminsitrador. ",
     "New password" : "Nueva contraseña",
     "I know what I'm doing" : "Sé lo que estoy haciendo",
     "Resetting password" : "Restableciendo contraseña",
@@ -119,16 +119,30 @@ OC.L10N.register(
     "Skip" : "Saltar",
     "Install recommended apps" : "Instalar apps recomendadas",
     "Settings menu" : "Menú de configuración",
+    "Loading your contacts …" : "Cargando sus contactos ... ",
+    "Looking for {term} …" : "Buscando {term} ...",
     "Reset search" : "Restablecer búsqueda",
     "Search contacts …" : "Buscar contactos ...",
     "Could not load your contacts" : "No se pudieron cargar tus contactos",
     "No contacts found" : "No se encontraron contactos",
     "Install the Contacts app" : "Instalar app de Contactos",
-    "Loading your contacts …" : "Cargando sus contactos ... ",
-    "Looking for {term} …" : "Buscando {term} ...",
     "Search" : "Buscar",
     "Forgot password?" : "¿Contraseña olvidada?",
     "Back" : "Atrás",
+    "Security warning" : "Advertencia de seguridad",
+    "Storage & database" : "Almacenamiento & base de datos",
+    "Data folder" : "Carpeta de datos",
+    "Install and activate additional PHP modules to choose other database types." : "Instale y active módulos adicionales de PHP para seleccionar otros tipos de bases de datos. ",
+    "For more details check out the documentation." : "Favor de consultar la documentación para más detalles. ",
+    "Performance warning" : "Advertencia de desempeño",
+    "Database user" : "Usuario de la base de datos",
+    "Database password" : "Contraseña de la base de datos",
+    "Database name" : "Nombre de la base de datos",
+    "Database tablespace" : "Espacio de tablas en la base de datos",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Favor de especificar el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
+    "Database host" : "Servidor de base de datos",
+    "Need help?" : "¿Necesita ayuda?",
+    "See the documentation" : "Ver la documentación",
     "Choose" : "Seleccionar",
     "Copy" : "Copiar",
     "Move" : "Mover",
@@ -157,11 +171,6 @@ OC.L10N.register(
     "Failed to add the item to the project" : "Error al agregar el elemento al proyecto",
     "New in" : "Nuevo en",
     "View changelog" : "Ver registro de cambios",
-    "Very weak password" : "Contraseña muy débil",
-    "Weak password" : "Contraseña débil",
-    "So-so password" : "Contraseña aceptable",
-    "Good password" : "Buena contraseña",
-    "Strong password" : "Contraseña fuerte",
     "No action available" : "No hay acciones disponibles",
     "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
     "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
@@ -189,23 +198,6 @@ OC.L10N.register(
     "File: %s" : "Archivo: %s",
     "Line: %s" : "Línea: %s",
     "Trace" : "Rastrear",
-    "Security warning" : "Advertencia de seguridad",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles desde Internet ya que el archivo .htaccess no funciona.",
-    "Show password" : "Mostrar contraseña",
-    "Storage & database" : "Almacenamiento & base de datos",
-    "Data folder" : "Carpeta de datos",
-    "Configure the database" : "Configurar la base de datos",
-    "Only %s is available." : "Sólo %s está disponible.",
-    "Install and activate additional PHP modules to choose other database types." : "Instale y active módulos adicionales de PHP para seleccionar otros tipos de bases de datos. ",
-    "For more details check out the documentation." : "Favor de consultar la documentación para más detalles. ",
-    "Database password" : "Contraseña de la base de datos",
-    "Database name" : "Nombre de la base de datos",
-    "Database tablespace" : "Espacio de tablas en la base de datos",
-    "Database host" : "Servidor de base de datos",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Favor de especificar el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
-    "Performance warning" : "Advertencia de desempeño",
-    "Need help?" : "¿Necesita ayuda?",
-    "See the documentation" : "Ver la documentación",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Favor de {linkstart}habilitar JavaScript{linkend} y vuelva a cargar la página. ",
     "Skip to main content" : "Saltar al contenido principal",
     "Skip to navigation of app" : "Saltar a la navegación de la app",
@@ -232,6 +224,15 @@ OC.L10N.register(
     "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte a su administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
-    "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}"
+    "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
+    "Very weak password" : "Contraseña muy débil",
+    "Weak password" : "Contraseña débil",
+    "So-so password" : "Contraseña aceptable",
+    "Good password" : "Buena contraseña",
+    "Strong password" : "Contraseña fuerte",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles desde Internet ya que el archivo .htaccess no funciona.",
+    "Show password" : "Mostrar contraseña",
+    "Configure the database" : "Configurar la base de datos",
+    "Only %s is available." : "Sólo %s está disponible."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
