@@ -98,29 +98,33 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications"],
     "No" : "نه",
     "Yes" : "بله",
-    "Create share" : "ساختن اشتراک",
     "Failed to add the public link to your Nextcloud" : "خطا در افزودن ادرس عمومی به نکس کلود شما",
+    "Create share" : "ساختن اشتراک",
     "Custom date range" : "بازه تاریخی سفارشی",
     "Pick start date" : "انتخاب تاریخ شروع",
     "Pick end date" : "انتخاب تاریخ پایان",
     "Search in date range" : "جستجو در بازه تاریخی",
-    "Unified search" : "جستجوی یکپارچه",
-    "Search apps, files, tags, messages" : "جستجوی برنامه‌ها، پرونده‌ها، برچسب‌ها، پیام‌ها",
-    "Places" : "مکان ها",
-    "Date" : "تاریخ",
+    "Searching …" : "جستجوکردن …",
+    "Start typing to search" : "Start typing to search",
     "Today" : "امروز",
     "Last 7 days" : "۷ روز گذشته",
     "Last 30 days" : "۳۰ روز گذشته",
     "This year" : "امسال",
     "Last year" : "پارسال",
+    "Unified search" : "جستجوی یکپارچه",
+    "Search apps, files, tags, messages" : "جستجوی برنامه‌ها، پرونده‌ها، برچسب‌ها، پیام‌ها",
+    "Places" : "مکان ها",
+    "Date" : "تاریخ",
     "Search people" : "جستجوی افراد",
     "People" : "مردم",
     "Results" : "نتایج",
     "Load more results" : "بار کردن نتیحه‌های بیش‌تر",
-    "Searching …" : "جستجوکردن …",
-    "Start typing to search" : "Start typing to search",
     "Log in" : "ورود",
     "Logging in …" : "ورود به سیستم ...",
+    "Log in to {productName}" : "Log in to {productName}",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "از این آی پی چندین بار تلاش ناموفق برای ورود انجام شده است فلذا برای ورود مجدد حداقل ۳۰ ثانیه باید صبر کنید.",
+    "Account name or email" : "نام کاربری یا آدرس ایمیل",
+    "Account name" : "Account name",
     "Server side authentication failed!" : "تأیید هویت از سوی سرور انجام نشد!",
     "Please contact your administrator." : "لطفا با مدیر وب‌سایت تماس بگیرید.",
     "Temporary error" : "خطای موقتی",
@@ -128,24 +132,25 @@ OC.L10N.register(
     "An internal error occurred." : "یک اشتباه داخلی رخ داد.",
     "Please try again or contact your administrator." : "لطفا مجددا تلاش کنید یا با مدیر سیستم تماس بگیرید.",
     "Password" : "گذرواژه",
-    "Log in to {productName}" : "Log in to {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "از این آی پی چندین بار تلاش ناموفق برای ورود انجام شده است فلذا برای ورود مجدد حداقل ۳۰ ثانیه باید صبر کنید.",
-    "Account name or email" : "نام کاربری یا آدرس ایمیل",
-    "Account name" : "Account name",
     "Log in with a device" : "Log in with a device",
     "Your account is not setup for passwordless login." : "Your account is not setup for passwordless login.",
-    "Browser not supported" : "Browser not supported",
-    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
     "Your connection is not secure" : "Your connection is not secure",
     "Passwordless authentication is only available over a secure connection." : "Passwordless authentication is only available over a secure connection.",
+    "Browser not supported" : "Browser not supported",
+    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
     "Reset password" : "تنظیم مجدد رمز عبور",
+    "Back to login" : "Back to login",
     "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
     "Password cannot be changed. Please contact your administrator." : "Password cannot be changed. Please contact your administrator.",
-    "Back to login" : "Back to login",
     "New password" : "گذرواژه جدید",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?",
     "I know what I'm doing" : "اطلاع از انجام این کار دارم",
     "Resetting password" : "در حال ریست کردن کلمه عبور...",
+    "Schedule work & meetings, synced with all your devices." : "زمان‌بندی کار و جلسات، همگام‌سازی‌شده با تمام دستگاه‌های شما",
+    "Keep your colleagues and friends in one place without leaking their private info." : "همکاران و دوستان خود را در یک مکان نگه دارید بدون اینکه اطلاعات خصوصی آنها را بشناسید.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "برنامه ایمیل ساده با پرونده ها ، مخاطبین و تقویم یکپارچه شده است.",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
+    "Distraction free note taking app." : "Distraction free note taking app.",
     "Recommended apps" : "Recommended apps",
     "Loading apps …" : "Loading apps …",
     "Could not fetch list of apps from the App Store." : "Could not fetch list of apps from the App Store.",
@@ -155,14 +160,10 @@ OC.L10N.register(
     "Skip" : "پرش",
     "Installing apps …" : "در حال نصب برنامه",
     "Install recommended apps" : "نصب کاره‌های پیشنهادی",
-    "Schedule work & meetings, synced with all your devices." : "زمان‌بندی کار و جلسات، همگام‌سازی‌شده با تمام دستگاه‌های شما",
-    "Keep your colleagues and friends in one place without leaking their private info." : "همکاران و دوستان خود را در یک مکان نگه دارید بدون اینکه اطلاعات خصوصی آنها را بشناسید.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "برنامه ایمیل ساده با پرونده ها ، مخاطبین و تقویم یکپارچه شده است.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
-    "Distraction free note taking app." : "Distraction free note taking app.",
-    "Settings menu" : "فهرست تنظیمات",
     "Avatar of {displayName}" : "نمایه {displayName}",
+    "Settings menu" : "فهرست تنظیمات",
+    "Loading your contacts …" : "بارگیری مخاطبین شما ...",
+    "Looking for {term} …" : "به دنبال {term} …",
     "Search contacts" : "Search contacts",
     "Reset search" : "Reset search",
     "Search contacts …" : "جستجو مخاطبین ...",
@@ -170,30 +171,43 @@ OC.L10N.register(
     "No contacts found" : "مخاطبین یافت نشد",
     "Show all contacts" : "نمایش تمام مخاطبین",
     "Install the Contacts app" : "Install the Contacts app",
-    "Loading your contacts …" : "بارگیری مخاطبین شما ...",
-    "Looking for {term} …" : "به دنبال {term} …",
-    "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
-    "Search for {name} only" : "Search for {name} only",
-    "Loading more results …" : "Loading more results …",
     "Search" : "جست‌و‌جو",
     "No results for {query}" : "No results for {query}",
     "Press Enter to start searching" : "Press Enter to start searching",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Please enter {minSearchLength} character or more to search","Please enter {minSearchLength} characters or more to search"],
     "An error occurred while searching for {type}" : "An error occurred while searching for {type}",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
+    "Search for {name} only" : "Search for {name} only",
+    "Loading more results …" : "Loading more results …",
     "Forgot password?" : "رمز فراموش شده؟",
     "Back to login form" : "Back to login form",
     "Back" : "بازگشت",
     "Login form is disabled." : "Login form is disabled.",
-    "Edit Profile" : "ویرایش نمایه",
-    "The headline and about sections will show up here" : "The headline and about sections will show up here",
-    "You have not added any info yet" : "You have not added any info yet",
-    "{user} has not added any info yet" : "{user} has not added any info yet",
-    "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
     "More actions" : "اقدامات بیشتر",
+    "Security warning" : "اخطار امنیتی",
+    "Storage & database" : "انبارش و پایگاه داده",
+    "Data folder" : "پوشه اطلاعاتی",
+    "Install and activate additional PHP modules to choose other database types." : "جهت انتخاب انواع دیگر پایگاه‌داده‌،ماژول‌های اضافی PHP را نصب و فعال‌سازی کنید.",
+    "For more details check out the documentation." : "برای جزئیات بیشتر به مستندات مراجعه کنید.",
+    "Performance warning" : "اخطار کارایی",
+    "You chose SQLite as database." : "شما SQLite را به عنوان پایگاه داده انتخاب کردید.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
+    "Database user" : "شناسه پایگاه داده",
+    "Database password" : "پسورد پایگاه داده",
+    "Database name" : "نام پایگاه داده",
+    "Database tablespace" : "جدول پایگاه داده",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
+    "Database host" : "هاست پایگاه داده",
+    "Installing …" : "Installing …",
+    "Install" : "نصب",
+    "Need help?" : "کمک لازم دارید ؟",
+    "See the documentation" : "مشاهده‌ی مستندات",
+    "{name} version {version} and above" : "{name} version {version} and above",
     "This browser is not supported" : "This browser is not supported",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
     "Continue with this unsupported browser" : "Continue with this unsupported browser",
     "Supported versions" : "Supported versions",
-    "{name} version {version} and above" : "{name} version {version} and above",
     "Search {types} …" : "Search {types} …",
     "Choose {file}" : "انتخاب {file}",
     "Choose" : "انتخاب کردن",
@@ -229,11 +243,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Type to search for existing projects",
     "New in" : "جدید در",
     "View changelog" : "مشاهده تغییرات",
-    "Very weak password" : "رمز عبور بسیار ضعیف",
-    "Weak password" : "رمز عبور ضعیف",
-    "So-so password" : "رمز عبور متوسط",
-    "Good password" : "رمز عبور خوب",
-    "Strong password" : "رمز عبور قوی",
     "No action available" : "هیچ عملی قابل انجام نیست",
     "Error fetching contact actions" : "خطا در دریافت فعالیتهای تماس",
     "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialog",
@@ -249,15 +258,12 @@ OC.L10N.register(
     "Admin" : "مدیر",
     "Help" : "راه‌نما",
     "Access forbidden" : "اجازه دسترسی به مناطق ممنوعه را ندارید",
-    "Profile not found" : "نمایه، یافت نشد",
-    "The profile does not exist." : "این نمایه وجود ندارد.",
-    "Back to %s" : "Back to %s",
     "Page not found" : "صفحه یافت نشد",
     "The page could not be found on the server or you may not be allowed to view it." : "The page could not be found on the server or you may not be allowed to view it.",
+    "Back to %s" : "Back to %s",
     "Too many requests" : "Too many requests",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
     "Error" : "خطا",
-    "Previous" : "قبلی",
     "Internal Server Error" : "خطای داخلی سرور",
     "The server was unable to complete your request." : "سرور قادر به تکمیل درخواست شما نبود.",
     "If this happens again, please send the technical details below to the server administrator." : "اگر این اتفاق دوباره افتاد، لطفا جزئیات فنی زیر را به مدیر سرور ارسال کنید.",
@@ -271,31 +277,6 @@ OC.L10N.register(
     "File: %s" : "فایل : %s",
     "Line: %s" : "خط: %s",
     "Trace" : "ردیابی",
-    "Security warning" : "اخطار امنیتی",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
-    "Create an <strong>admin account</strong>" : "لطفا یک <strong> شناسه برای مدیر</strong> بسازید",
-    "Show password" : "نمایش گذرواژه",
-    "Toggle password visibility" : "Toggle password visibility",
-    "Storage & database" : "انبارش و پایگاه داده",
-    "Data folder" : "پوشه اطلاعاتی",
-    "Configure the database" : "پایگاه داده برنامه ریزی شدند",
-    "Only %s is available." : "تنها %s موجود است.",
-    "Install and activate additional PHP modules to choose other database types." : "جهت انتخاب انواع دیگر پایگاه‌داده‌،ماژول‌های اضافی PHP را نصب و فعال‌سازی کنید.",
-    "For more details check out the documentation." : "برای جزئیات بیشتر به مستندات مراجعه کنید.",
-    "Database password" : "پسورد پایگاه داده",
-    "Database name" : "نام پایگاه داده",
-    "Database tablespace" : "جدول پایگاه داده",
-    "Database host" : "هاست پایگاه داده",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
-    "Performance warning" : "اخطار کارایی",
-    "You chose SQLite as database." : "شما SQLite را به عنوان پایگاه داده انتخاب کردید.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
-    "Install" : "نصب",
-    "Installing …" : "Installing …",
-    "Need help?" : "کمک لازم دارید ؟",
-    "See the documentation" : "مشاهده‌ی مستندات",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Could not remove CAN_INSTALL from the config folder. Please remove this file manually.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
@@ -313,6 +294,7 @@ OC.L10N.register(
     "Account connected" : "Account connected",
     "Your client should now be connected!" : "Your client should now be connected!",
     "You can close this window." : "You can close this window.",
+    "Previous" : "قبلی",
     "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
     "The password is wrong or expired. Please try again or request a new one." : "The password is wrong or expired. Please try again or request a new one.",
     "Please type in your email address to request a temporary password" : "Please type in your email address to request a temporary password",
@@ -349,34 +331,26 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
     "This page will refresh itself when the instance is available again." : "This page will refresh itself when the instance is available again.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "اگر این پیغام همچنان وجود داشت یا به صورت غیر منتظره ظاهر شد با مدیر سیستم تماس بگیرید.",
-    "The user limit of this instance is reached." : "The user limit of this instance is reached.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}.",
-    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}.",
-    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly.",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}.",
-    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!",
     "Currently open" : "Currently open",
-    "Wrong username or password." : "شناسه کاربری و کلمه عبور اشتباه است",
-    "User disabled" : "کاربر غیرفعال",
-    "Username or email" : "نام کاربری یا ایمیل",
-    "Apps and Settings" : "برنامه‌ها و تنظیمات",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
+    "You have not added any info yet" : "You have not added any info yet",
+    "{user} has not added any info yet" : "{user} has not added any info yet",
+    "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
+    "Edit Profile" : "ویرایش نمایه",
+    "The headline and about sections will show up here" : "The headline and about sections will show up here",
     "Error loading message template: {error}" : "خطا در بارگذاری قالب پیام : {error}",
-    "Users" : "کاربران",
-    "Username" : "نام کاربری",
-    "Database user" : "شناسه پایگاه داده",
-    "This action requires you to confirm your password" : "این اقدام نیاز به تایید رمز عبور شما دارد",
-    "Confirm your password" : "گذرواژه خود را تأیید کنید",
-    "Confirm" : "تایید",
-    "App token" : "App token",
-    "Alternative log in using app token" : "Alternative log in using app token",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Please use the command line updater because you have a big instance with more than 50 users."
+    "Very weak password" : "رمز عبور بسیار ضعیف",
+    "Weak password" : "رمز عبور ضعیف",
+    "So-so password" : "رمز عبور متوسط",
+    "Good password" : "رمز عبور خوب",
+    "Strong password" : "رمز عبور قوی",
+    "Profile not found" : "نمایه، یافت نشد",
+    "The profile does not exist." : "این نمایه وجود ندارد.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
+    "Show password" : "نمایش گذرواژه",
+    "Toggle password visibility" : "Toggle password visibility",
+    "Configure the database" : "پایگاه داده برنامه ریزی شدند",
+    "Only %s is available." : "تنها %s موجود است."
 },
 "nplurals=2; plural=(n > 1);");
