@@ -103,12 +103,12 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["通知 {count} 件"],
     "No" : "いいえ",
     "Yes" : "はい",
-    "Federated user" : "フェデレーションユーザー",
-    "user@your-nextcloud.org" : "user@your-nextcloud.org",
-    "Create share" : "共有を作成",
     "The remote URL must include the user." : "リモートURLにはユーザーを含める必要があります。",
     "Invalid remote URL." : "無効なリモートURLです。",
     "Failed to add the public link to your Nextcloud" : "このNextcloudに公開リンクを追加できませんでした",
+    "Federated user" : "フェデレーションユーザー",
+    "user@your-nextcloud.org" : "user@your-nextcloud.org",
+    "Create share" : "共有を作成",
     "Direct link copied to clipboard" : "クリップボードにコピーされた直接リンク",
     "Please copy the link manually:" : "手動でリンクをコピーしてください：",
     "Custom date range" : "カスタム日付の範囲",
@@ -118,27 +118,32 @@ OC.L10N.register(
     "Search in current app" : "現在のアプリケーションで検索",
     "Clear search" : "検索をクリア",
     "Search everywhere" : "あらゆる場所を検索",
-    "Unified search" : "統合検索",
-    "Search apps, files, tags, messages" : "アプリ、ファイル、タグ、メッセージを検索",
-    "Places" : "場所",
-    "Date" : "日付",
+    "Searching …" : "検索しています…",
+    "Start typing to search" : "入力して検索を開始します",
+    "No matching results" : "一致する結果はありません",
     "Today" : "今日",
     "Last 7 days" : "7日以内",
     "Last 30 days" : "30日以内",
     "This year" : "今年",
     "Last year" : "去年",
+    "Unified search" : "統合検索",
+    "Search apps, files, tags, messages" : "アプリ、ファイル、タグ、メッセージを検索",
+    "Places" : "場所",
+    "Date" : "日付",
     "Search people" : "人物を検索",
     "People" : "人間",
     "Filter in current view" : "現在のビューでフィルタ",
     "Results" : "結果",
     "Load more results" : "次の結果を読み込む",
     "Search in" : "検索対象",
-    "Searching …" : "検索しています…",
-    "Start typing to search" : "入力して検索を開始します",
-    "No matching results" : "一致する結果はありません",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "${this.dateFilter.startFrom.toLocaleDateString()} と ${this.dateFilter.endAt.toLocaleDateString()} の間",
     "Log in" : "ログイン",
     "Logging in …" : "ログイン中...",
+    "Log in to {productName}" : "{productName} へログイン",
+    "Wrong login or password." : "ログイン名またはパスワードが間違っています。",
+    "This account is disabled" : "アカウントが無効化されています",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "あなたのIPから複数の無効なログイン試行が検出されました。 したがって、次回のログインは最大30秒間抑制されます。",
+    "Account name or email" : "アカウント名またはメールアドレス",
+    "Account name" : "アカウント名",
     "Server side authentication failed!" : "サーバーサイドの認証に失敗しました！",
     "Please contact your administrator." : "管理者にお問い合わせください。",
     "Temporary error" : "一時的なエラー",
@@ -146,28 +151,28 @@ OC.L10N.register(
     "An internal error occurred." : "内部エラーが発生しました。",
     "Please try again or contact your administrator." : "もう一度やり直してみるか、管理者にお問い合わせください。",
     "Password" : "パスワード",
-    "Log in to {productName}" : "{productName} へログイン",
-    "Wrong login or password." : "ログイン名またはパスワードが間違っています。",
-    "This account is disabled" : "アカウントが無効化されています",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "あなたのIPから複数の無効なログイン試行が検出されました。 したがって、次回のログインは最大30秒間抑制されます。",
-    "Account name or email" : "アカウント名またはメールアドレス",
-    "Account name" : "アカウント名",
     "Log in with a device" : "デバイスを使ってログインする",
     "Login or email" : "ログイン名またはEメール",
     "Your account is not setup for passwordless login." : "あなたのアカウントはパスワードなしでログインできるように設定されていません。",
-    "Browser not supported" : "サポートされていないブラウザーです",
-    "Passwordless authentication is not supported in your browser." : "お使いのブラウザーはパスワードレス認証に対応していません。",
     "Your connection is not secure" : "この接続は安全ではありません",
     "Passwordless authentication is only available over a secure connection." : "パスワードレス認証は、セキュアな接続でのみ利用可能です。",
+    "Browser not supported" : "サポートされていないブラウザーです",
+    "Passwordless authentication is not supported in your browser." : "お使いのブラウザーはパスワードレス認証に対応していません。",
     "Reset password" : "パスワードをリセット",
+    "Back to login" : "ログインに戻る",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "このアカウントが存在する場合、パスワードリセットメッセージがメールアドレスに送信されています。もしメッセージが届かない場合は、メールアドレスやログイン名を確認するか、迷惑メールフォルダをチェックするか、もしくは管理者にお問い合わせください。",
     "Couldn't send reset email. Please contact your administrator." : "リセットメールを送信できませんでした。管理者に問い合わせてください。",
     "Password cannot be changed. Please contact your administrator." : "パスワードは変更できません。管理者に問い合わせてください。",
-    "Back to login" : "ログインに戻る",
     "New password" : "新しいパスワードを入力",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "ファイルが暗号化されます。パスワードがリセットされた後は、データを元に戻すことはできません。対処方法がわからない場合は、続行する前に管理者に問い合わせてください。本当に続行しますか?",
     "I know what I'm doing" : "どういう操作をしているか理解しています",
     "Resetting password" : "パスワードのリセット",
+    "Schedule work & meetings, synced with all your devices." : "すべての端末と同期して、仕事と会議をスケジュールに組み込みます",
+    "Keep your colleagues and friends in one place without leaking their private info." : "個人情報を漏らさずに、同僚や友人をまとめて保管します。",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "ファイル、連絡先、カレンダーとうまく合わさったシンプルなメールアプリ。",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "チャット、ビデオ通話、画面共有、オンラインミーティング、ウェブ会議 - ブラウザーとモバイルアプリで。",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collabora Online上に構築された、共同作業ドキュメント、スプレッドシート、およびプレゼンテーション",
+    "Distraction free note taking app." : "集中モードメモアプリ",
     "Recommended apps" : "推奨アプリ",
     "Loading apps …" : "アプリを読み込み中…",
     "Could not fetch list of apps from the App Store." : "App Storeからアプリのリストを取得できませんでした。",
@@ -177,14 +182,10 @@ OC.L10N.register(
     "Skip" : "スキップ",
     "Installing apps …" : "アプリをインストールしています…",
     "Install recommended apps" : "推奨アプリをインストール",
-    "Schedule work & meetings, synced with all your devices." : "すべての端末と同期して、仕事と会議をスケジュールに組み込みます",
-    "Keep your colleagues and friends in one place without leaking their private info." : "個人情報を漏らさずに、同僚や友人をまとめて保管します。",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "ファイル、連絡先、カレンダーとうまく合わさったシンプルなメールアプリ。",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "チャット、ビデオ通話、画面共有、オンラインミーティング、ウェブ会議 - ブラウザーとモバイルアプリで。",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collabora Online上に構築された、共同作業ドキュメント、スプレッドシート、およびプレゼンテーション",
-    "Distraction free note taking app." : "集中モードメモアプリ",
-    "Settings menu" : "メニュー設定",
     "Avatar of {displayName}" : "{displayName} のアバター",
+    "Settings menu" : "メニュー設定",
+    "Loading your contacts …" : "連絡先を読み込み中...",
+    "Looking for {term} …" : "{term} を確認中 ...",
     "Search contacts" : "連絡先を検索",
     "Reset search" : "検索をリセットする",
     "Search contacts …" : "連絡先を検索...",
@@ -192,31 +193,61 @@ OC.L10N.register(
     "No contacts found" : "連絡先が見つかりません",
     "Show all contacts" : "すべての連絡先を表示",
     "Install the Contacts app" : "連絡先アプリをインストール",
-    "Loading your contacts …" : "連絡先を読み込み中...",
-    "Looking for {term} …" : "{term} を確認中 ...",
-    "Search starts once you start typing and results may be reached with the arrow keys" : "入力が始まると検索が始まり、矢印キーで検索結果を表示することができます",
-    "Search for {name} only" : "{name}のみを検索",
-    "Loading more results …" : "次の結果を読み込み中 ...",
     "Search" : "検索",
     "No results for {query}" : "{query}の検索結果はありません",
     "Press Enter to start searching" : "Enterキーを押して検索を開始",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["検索には、{minSearchLength}文字以上が必要です"],
     "An error occurred while searching for {type}" : "{type} の検索中にエラーが発生しました",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "入力が始まると検索が始まり、矢印キーで検索結果を表示することができます",
+    "Search for {name} only" : "{name}のみを検索",
+    "Loading more results …" : "次の結果を読み込み中 ...",
     "Forgot password?" : "パスワードをお忘れですか?",
     "Back to login form" : "ログイン画面に戻る",
     "Back" : "戻る",
     "Login form is disabled." : "ログインフォームは無効です。",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud ログインフォームは無効になっています。 利用可能な場合は別のログインオプションを使用するか、管理者に問い合わせてください。",
-    "Edit Profile" : "プロフィールを編集",
-    "The headline and about sections will show up here" : "見出しと概要セクションがここに表示されます",
-    "You have not added any info yet" : "まだ情報が追加されていません",
-    "{user} has not added any info yet" : "{user}が、まだ情報を追加していません",
-    "Error opening the user status modal, try hard refreshing the page" : "ユーザーステータスモーダルを開くときにエラーが発生しました。ページを更新してみてください",
     "More actions" : "その他のアクション",
+    "Password is too weak" : "パスワードが脆弱すぎます",
+    "Password is weak" : "パスワードが脆弱です",
+    "Password is average" : "パスワードは普通です",
+    "Password is strong" : "パスワードは強力です",
+    "Password is very strong" : "パスワードは非常に強力です",
+    "Password is extremely strong" : "パスワードは極めて強力です",
+    "Unknown password strength" : "パスワード強度が不明です",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "<code>.htaccess</code>ファイルが動作していないため、おそらくあなたのデータディレクトリまたはファイルはインターネットからアクセス可能になっています。",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "サーバーを適切に設定する方法については、{linkStart}ドキュメントを参照してください{linkEnd}",
+    "Autoconfig file detected" : "自動設定ファイルが検出されました",
+    "The setup form below is pre-filled with the values from the config file." : "以下のセットアップフォームには、設定ファイルの値があらかじめ入力されています。",
+    "Security warning" : "セキュリティ警告",
+    "Create administration account" : "管理アカウントを作成",
+    "Administration account name" : "管理者アカウント名",
+    "Administration account password" : "管理者アカウントパスワード",
+    "Storage & database" : "ストレージとデータベース",
+    "Data folder" : "データフォルダー",
+    "Database configuration" : "データベース設定",
+    "Only {firstAndOnlyDatabase} is available." : "{firstAndOnlyDatabase} のみ有効です。",
+    "Install and activate additional PHP modules to choose other database types." : "他のデータベースタイプを選択するためには、追加の PHP モジュールインストールして有効化してください。",
+    "For more details check out the documentation." : "詳細は、ドキュメントを確認してください。",
+    "Performance warning" : "パフォーマンス警告",
+    "You chose SQLite as database." : "あなたはSQLiteをデータベースとして選択しました。",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLiteは小規模もしくは開発用のインスタンスでのみ利用できます。プロダクション環境では他のデータベースをお勧めします。",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ファイルの同期にクライアントを使用している場合、SQLiteの使用はお勧めできません。",
+    "Database user" : "データベースのユーザー名",
+    "Database password" : "データベースのパスワード",
+    "Database name" : "データベース名",
+    "Database tablespace" : "データベースの表領域",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "ポート番号をホスト名とともに指定してください(例：localhost：5432)。",
+    "Database host" : "データベースのホスト名",
+    "localhost" : "localhost",
+    "Installing …" : "インストールしています…",
+    "Install" : "インストール",
+    "Need help?" : "ヘルプが必要ですか？",
+    "See the documentation" : "ドキュメントを確認してください",
+    "{name} version {version} and above" : "{name} バージョン {version} 以上が対象",
     "This browser is not supported" : "お使いのブラウザーはサポートされていません",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "お使いのブラウザーはサポート対象外です。新しいバージョンにアップグレードするかサポートされているブラウザーへ切り替えてください",
     "Continue with this unsupported browser" : "サポート対象外のブラウザーで継続する",
     "Supported versions" : "サポート対象バージョン",
-    "{name} version {version} and above" : "{name} バージョン {version} 以上が対象",
     "Search {types} …" : "{types} を検索…",
     "Choose {file}" : "{file}を選択",
     "Choose" : "選択",
@@ -252,11 +283,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "入力して既存のプロジェクトを検索します",
     "New in" : "新機能",
     "View changelog" : "変更履歴を確認する",
-    "Very weak password" : "非常に弱いパスワード",
-    "Weak password" : "弱いパスワード",
-    "So-so password" : "まずまずのパスワード",
-    "Good password" : "良好なパスワード",
-    "Strong password" : "強いパスワード",
     "No action available" : "操作できません",
     "Error fetching contact actions" : "連絡先操作取得エラー",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\"ダイアログを閉じる",
@@ -268,16 +294,15 @@ OC.L10N.register(
     "Rename" : "名前の変更",
     "Collaborative tags" : "コラボタグ",
     "No tags found" : "タグが見つかりません",
+    "Clipboard not available, please copy manually" : "クリップボードが使用できません。手動でコピーしてください",
     "Personal" : "個人",
     "Accounts" : "アカウント",
     "Admin" : "管理",
     "Help" : "ヘルプ",
     "Access forbidden" : "アクセスが禁止されています",
-    "Profile not found" : "プロフィールが見つかりません",
-    "The profile does not exist." : "プロフィールはありません",
-    "Back to %s" : "%s に戻る",
     "Page not found" : "ページが見つかりません",
     "The page could not be found on the server or you may not be allowed to view it." : "サーバーからページを見つけられなかった、もしくは閲覧が許可されていないようです。",
+    "Back to %s" : "%s に戻る",
     "Too many requests" : "要求が多すぎます",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "ネットワークからのリクエストが多すぎました。このようなエラーが発生した場合は、後で再試行するか、管理者に連絡してください。",
     "Error" : "エラー",
@@ -295,32 +320,6 @@ OC.L10N.register(
     "File: %s" : "ファイル: %s",
     "Line: %s" : "行: %s",
     "Trace" : "トレース",
-    "Security warning" : "セキュリティ警告",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccessファイルが動作していないため、おそらくあなたのデータディレクトリまたはファイルはインターネットからアクセス可能になっています。",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "サーバーを適正に設定する情報は、こちらの<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ドキュメント</a>を参照してください。",
-    "Create an <strong>admin account</strong>" : "<strong>管理者アカウント</strong>を作成してください",
-    "Show password" : "パスワードを表示",
-    "Toggle password visibility" : "パスワードの表示/非表示を切り替える",
-    "Storage & database" : "ストレージとデータベース",
-    "Data folder" : "データフォルダー",
-    "Configure the database" : "データベースを設定してください",
-    "Only %s is available." : "%s のみ有効です。",
-    "Install and activate additional PHP modules to choose other database types." : "他のデータベースタイプを選択するためには、追加の PHP モジュールインストールして有効化してください。",
-    "For more details check out the documentation." : "詳細は、ドキュメントを確認してください。",
-    "Database account" : "データベースアカウント",
-    "Database password" : "データベースのパスワード",
-    "Database name" : "データベース名",
-    "Database tablespace" : "データベースの表領域",
-    "Database host" : "データベースのホスト名",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "ポート番号をホスト名とともに指定してください(例：localhost：5432)。",
-    "Performance warning" : "パフォーマンス警告",
-    "You chose SQLite as database." : "あなたはSQLiteをデータベースとして選択しました。",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLiteは小規模もしくは開発用のインスタンスでのみ利用できます。プロダクション環境では他のデータベースをお勧めします。",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ファイルの同期にクライアントを使用している場合、SQLiteの使用はお勧めできません。",
-    "Install" : "インストール",
-    "Installing …" : "インストールしています…",
-    "Need help?" : "ヘルプが必要ですか？",
-    "See the documentation" : "ドキュメントを確認してください",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloudを再インストールしようとしているようです。 しかし、CAN_INSTALLファイルがconfigディレクトリにありません。 続行するには、configフォルダーにCAN_INSTALLファイルを作成してください。",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "設定フォルダーからCAN_INSTALLを削除できませんでした。 このファイルを手動で削除してください。",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "このアプリケーションの動作にはJavaScriptが必要です。\n {linkstart}JavaScriptを有効にし{linkend} 、ページを更新してください。 ",
@@ -337,7 +336,7 @@ OC.L10N.register(
     "Account access" : "アカウントによるアクセス許可",
     "Currently logged in as %1$s (%2$s)." : "現在、%1$s (%2$s)としてログインしています。",
     "You are about to grant %1$s access to your %2$s account." : "%2$s アカウントに あなたのアカウント %1$s へのアクセスを許可",
-    "Account connected" : "アカウント接続済",
+    "Account connected" : "アカウントに接続しました",
     "Your client should now be connected!" : "クライアントはもう接続されているはずです！",
     "You can close this window." : "このウィンドウは閉じてしまって構いません。",
     "Previous" : "前へ",
@@ -379,37 +378,32 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "このサーバー %s は現在メンテナンスモードです。しばらくお待ちください。",
     "This page will refresh itself when the instance is available again." : "この画面は、サーバー の再起動後に自動的に更新されます。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "このメッセージが引き続き、または予期せず現れる場合は、システム管理者に問い合わせてください。",
-    "The user limit of this instance is reached." : "このインスタンスのユーザー制限に達しました。",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "サポートappへサブスクリプションキーを入力すると、ユーザー数の上限を増やすことができます。また、Nextcloud Enterpriseが提供するすべての追加特典が付与されますので、企業で運用に必須です",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAVインターフェースが動作していないようです。Webサーバーは、ファイルの同期を許可するよう適切に設定されていません。",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Webサーバーで \"{url}\" が解決されるように正しく設定されていません。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Webサーバーで \"{url}\" が解決されるように正しく設定されていません。これは、このフォルダーを直接配信するように更新されていないWebサーバー構成が影響している可能性があります。構成を、Apacheの \".htaccess\" にある設定済みの書き換えルールまたはNginxのドキュメントの{linkstart}ドキュメントページ↗{linkend}で提供されているルールと比較してください。 Nginxでは、これらは通常、修正が必要な \"location〜\" で始まる行です。",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Webサーバーで.woff2ファイルが配信されるように適切に設定されていません。これは通常、Nginx構成の問題です。 Nextcloud 15の場合、.woff2ファイルも配信するように調整する必要があります。 Nginx構成を{linkstart}ドキュメント↗{linkend}の推奨構成と比較してください。",
-    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "安全な接続でインスタンスにアクセスしていますが、インスタンスは安全でないURLを生成しています。これは、リバースプロキシの背後にあり、構成設定変数が正しく上書きされていない可能性があります。これについては、{linkend}ドキュメントページ↗{linkstart}をお読みください。",
-    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "データディレクトリやファイルがインターネットからアクセスされている可能性があります。.htaccessファイルが機能していません。データディレクトリにアクセスできないようにWebサーバーを設定するか、データディレクトリをWebサーバーのドキュメントルートの外に移動することを強くお勧めします。",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーが \"{expected}\"に設定されていません。 これらは潜在的なセキュリティまたはプライバシーのリスクになります。この設定を調整することをお勧めします",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーが \"{expected}\"に設定されていません。 一部の機能は正しく機能しない可能性があります。この設定を調整することを推奨します。",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーに \"{expected}\"が含まれていません。 これらは潜在的なセキュリティまたはプライバシーのリスクになります。この設定を調整することをお勧めします。",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTPヘッダの\"{header}\"に\"{val1}\"、\"{val2}\"、\"{val3}\"、\"{val4}\"、\"{val5}\"が設定されていません。これにより、リファラー情報が漏洩する可能性があります。 {linkstart} W3C勧告↗{linkend}を参照してください。",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Strict-Transport-Security \"HTTP ヘッダーの秒数が少なくとも\"{seconds}\" に設定されていません。セキュリティを強化するには、{linkstart}セキュリティのヒント↗{linkend}で説明されているようにHSTSを有効にすることをお勧めします。",
-    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "HTTP 経由で安全ではないサイトにアクセスします。 {linkstart}セキュリティのヒント ↗{linkend} で説明されているように、代わりに HTTPS を要求するようにサーバーを設定することを強くお勧めします。これがないと、「クリップボードにコピー」や「Service Worker」などの一部の重要な Web 機能が動作しません！",
     "Currently open" : "編集中",
-    "Wrong username or password." : "ユーザー名またはパスワードが間違っています",
-    "User disabled" : "ユーザーは無効です",
     "Login with username or email" : "ログインするユーザー名またはメールアドレス",
     "Login with username" : "ログインするユーザー名",
-    "Username or email" : "ユーザー名またはメールアドレス",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "このアカウントが存在したら、パスワード変更のメッセージがそのメールアドレスに送信されます。\nもしメールが届いていない場合は、メールアドレスまたはアカウント名を確認するか、メールが迷惑メールフォルダに入っていないか確認するか、もしくは管理者にお問い合わせください。",
-    "Apps and Settings" : "アプリと設定",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "チャット、ビデオ通話、画面共有、オンラインミーティング、ウェブ会議 - ブラウザーとモバイルアプリで。",
+    "You have not added any info yet" : "まだ情報が追加されていません",
+    "{user} has not added any info yet" : "{user}が、まだ情報を追加していません",
+    "Error opening the user status modal, try hard refreshing the page" : "ユーザーステータスモーダルを開くときにエラーが発生しました。ページを更新してみてください",
+    "Edit Profile" : "プロフィールを編集",
+    "The headline and about sections will show up here" : "見出しと概要セクションがここに表示されます",
     "Error loading message template: {error}" : "メッセージテンプレートの読み込みエラー: {error}",
-    "Users" : "ユーザー",
-    "Username" : "ユーザー名",
-    "Database user" : "データベースのユーザー名",
-    "This action requires you to confirm your password" : "この操作では、パスワードを確認する必要があります",
-    "Confirm your password" : "パスワードを確認",
-    "Confirm" : "確認",
-    "App token" : "アプリのトークン",
-    "Alternative log in using app token" : "アプリトークンを使って代替ログイン",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "50人以上が使う大規模システムの場合は、コマンドラインでアップグレードを行ってください。"
+    "Very weak password" : "非常に弱いパスワード",
+    "Weak password" : "弱いパスワード",
+    "So-so password" : "まずまずのパスワード",
+    "Good password" : "良好なパスワード",
+    "Strong password" : "強いパスワード",
+    "Profile not found" : "プロフィールが見つかりません",
+    "The profile does not exist." : "プロフィールはありません",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccessファイルが動作していないため、おそらくあなたのデータディレクトリまたはファイルはインターネットからアクセス可能になっています。",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "サーバーを適正に設定する情報は、こちらの<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ドキュメント</a>を参照してください。",
+    "<strong>Create an admin account</strong>" : "<strong>管理者アカウントを作成する</strong>",
+    "New admin account name" : "新しい管理者アカウント名",
+    "New admin password" : "新しい管理者パスワード",
+    "Show password" : "パスワードを表示",
+    "Toggle password visibility" : "パスワードの表示/非表示を切り替える",
+    "Configure the database" : "データベースを設定してください",
+    "Only %s is available." : "%s のみ有効です。",
+    "Database account" : "データベースアカウント"
 },
 "nplurals=1; plural=0;");
