@@ -38,7 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Server version %s or higher is required.",
     "Server version %s or lower is required." : "Server version %s or lower is required.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Logged in account must be an admin, a sub admin or gotten special right to access this setting",
-    "Your current IP address doesn’t allow you to perform admin actions" : "Your current IP address doesn’t allow you to perform admin actions",
+    "Your current IP address doesn't allow you to perform admin actions" : "Your current IP address doesn't allow you to perform admin actions",
     "Logged in account must be an admin or sub admin" : "Logged in account must be an admin or sub admin",
     "Logged in account must be an admin" : "Logged in account must be an admin",
     "Wiping of device %s has started" : "Wiping of device %s has started",
@@ -59,6 +59,11 @@ OC.L10N.register(
     "Avatar image is not square" : "Avatar image is not square",
     "Files" : "Files",
     "View profile" : "View profile",
+    "same time" : "same time",
+    "_%nh_::_%nh_" : ["%nh","%nh"],
+    "_%nm_::_%nm_" : ["%nm","%nm"],
+    "%s ahead" : "%s ahead",
+    "%s behind" : "%s behind",
     "Local time: %s" : "Local time: %s",
     "today" : "today",
     "tomorrow" : "tomorrow",
@@ -81,6 +86,12 @@ OC.L10N.register(
     "seconds ago" : "seconds ago",
     "Empty file" : "Empty file",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator.",
+    "No file conversion providers available" : "No file conversion providers available",
+    "File is too large to convert" : "File is too large to convert",
+    "Destination does not match conversion extension" : "Destination does not match conversion extension",
+    "Could not convert file" : "Could not convert file",
+    "Destination does not exist" : "Destination does not exist",
+    "Destination is not creatable" : "Destination is not creatable",
     "Dot files are not allowed" : "Dot files are not allowed",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" is a forbidden file or folder name.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" is a forbidden prefix for file or folder names.",
@@ -92,6 +103,13 @@ OC.L10N.register(
     "Invalid path" : "Invalid path",
     "Failed to create file from template" : "Failed to create file from template",
     "Templates" : "Templates",
+    "Storage %s cannot be moved" : "Storage %s cannot be moved",
+    "Moving a share (%s) into a shared folder is not allowed" : "Moving a share (%s) into a shared folder is not allowed",
+    "Moving a storage (%s) into a shared folder is not allowed" : "Moving a storage (%s) into a shared folder is not allowed",
+    "Moving a share (%s) into another share (%s) is not allowed" : "Moving a share (%s) into another share (%s) is not allowed",
+    "Moving a share (%s) into another storage (%s) is not allowed" : "Moving a share (%s) into another storage (%s) is not allowed",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "Moving a storage (%s) into a share (%s) is not allowed",
+    "Moving a storage (%s) into another storage (%s) is not allowed" : "Moving a storage (%s) into another storage (%s) is not allowed",
     "Path contains invalid segments" : "Path contains invalid segments",
     "Filename is a reserved word" : "Filename is a reserved word",
     "Filename contains at least one invalid character" : "Filename contains at least one invalid character",
@@ -126,6 +144,7 @@ OC.L10N.register(
     "Headline" : "Headline",
     "Organisation" : "Organisation",
     "Role" : "Role",
+    "Pronouns" : "Pronouns",
     "Unknown account" : "Unknown account",
     "Additional settings" : "Additional settings",
     "Enter the database Login and name for %s" : "Enter the database Login and name for %s",
@@ -137,7 +156,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Oracle connection could not be established",
     "Oracle Login and/or password not valid" : "Oracle Login and/or password not valid",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL Login and/or password not valid",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! ",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!",
     "For the best results, please consider using a GNU/Linux server instead." : "For the best results, please consider using a GNU/Linux server instead.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir setting has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP.",
@@ -147,28 +166,27 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Sharing backend %s must implement the interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Sharing backend %s not found",
     "Sharing backend for %s not found" : "Sharing backend for %s not found",
-    "%1$s shared »%2$s« with you" : "%1$s shared »%2$s« with you",
-    "%1$s shared »%2$s« with you." : "%1$s shared »%2$s« with you.",
-    "Click the button below to open it." : "Click the button below to open it.",
-    "Open »%s«" : "Open »%s«",
+    "%1$s shared %2$s with you" : "%1$s shared %2$s with you",
+    "Open %s" : "Open %s",
     "%1$s via %2$s" : "%1$s via %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s shared »%2$s« with you and wants to add:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
-    "»%s« added a note to a file shared with you" : "»%s« added a note to a file shared with you",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s shared %2$s with you and wants to add:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s shared %2$s with you and wants to add",
+    "%s added a note to a file shared with you" : "%s added a note to a file shared with you",
     "Passwords are enforced for link and mail shares" : "Passwords are enforced for link and mail shares",
-    "SharedWith is not a valid user" : "SharedWith is not a valid user",
-    "SharedWith is not a valid group" : "SharedWith is not a valid group",
-    "SharedWith should be empty" : "SharedWith should be empty",
-    "SharedWith should not be empty" : "SharedWith should not be empty",
-    "SharedWith is not a valid circle" : "SharedWith is not a valid circle",
+    "Share recipient is not a valid user" : "Share recipient is not a valid user",
+    "Share recipient is not a valid group" : "Share recipient is not a valid group",
+    "Share recipient should be empty" : "Share recipient should be empty",
+    "Share recipient should not be empty" : "Share recipient should not be empty",
+    "Share recipient is not a valid circle" : "Share recipient is not a valid circle",
     "Unknown share type" : "Unknown share type",
-    "SharedBy should be set" : "SharedBy should be set",
+    "Share initiator must be set" : "Share initiator must be set",
     "Cannot share with yourself" : "Cannot share with yourself",
-    "Path should be set" : "Path should be set",
-    "Path should be either a file or a folder" : "Path should be either a file or a folder",
+    "Shared path must be set" : "Shared path must be set",
+    "Shared path must be either a file or a folder" : "Shared path must be either a file or a folder",
     "You cannot share your root folder" : "You cannot share your root folder",
     "You are not allowed to share %s" : "You are not allowed to share %s",
-    "A share requires permissions" : "A share requires permissions",
+    "Valid permissions are required for sharing" : "Valid permissions are required for sharing",
+    "File shares cannot have create or delete permissions" : "File shares cannot have create or delete permissions",
     "Cannot increase permissions of %s" : "Cannot increase permissions of %s",
     "Shares need at least read permissions" : "Shares need at least read permissions",
     "Files cannot be shared with delete permissions" : "Files cannot be shared with delete permissions",
@@ -195,7 +213,7 @@ OC.L10N.register(
     "Cannot disable sending the password by Talk without setting a new password" : "Cannot disable sending the password by Talk without setting a new password",
     "Share provider does not support accepting" : "Share provider does not support accepting",
     "Cannot change target of link share" : "Cannot change target of link share",
-    "Invalid recipient" : "Invalid recipient",
+    "Invalid share recipient" : "Invalid share recipient",
     "Group \"%s\" does not exist" : "Group \"%s\" does not exist",
     "The requested share does not exist anymore" : "The requested share does not exist any more",
     "The requested share comes from a disabled user" : "The requested share comes from a disabled user",
@@ -260,8 +278,6 @@ OC.L10N.register(
     "Login canceled by app" : "Login cancelled by app",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s",
     "a safe home for all your data" : "a safe home for all your data",
-    "File is currently busy, please try again later" : "File is currently busy, please try again later",
-    "Cannot download file" : "Cannot download file",
     "Application is not enabled" : "Application is not enabled",
     "Authentication error" : "Authentication error",
     "Token expired. Please reload page." : "Token expired. Please reload page.",
@@ -306,12 +322,27 @@ OC.L10N.register(
     "Storage connection error. %s" : "Storage connection error. %s",
     "Storage is temporarily not available" : "Storage is temporarily not available",
     "Storage connection timeout. %s" : "Storage connection timeout. %s",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule.",
     "Transcribe audio" : "Transcribe audio",
     "Transcribe the things said in an audio" : "Transcribe the things said in an audio",
     "Audio input" : "Audio input",
     "The audio to transcribe" : "The audio to transcribe",
     "Transcription" : "Transcription",
     "The transcribed text" : "The transcribed text",
+    "ContextAgent" : "ContextAgent",
+    "Chat with an agent" : "Chat with an agent",
+    "Chat message" : "Chat message",
+    "A chat message to send to the agent." : "A chat message to send to the agent.",
+    "Confirmation" : "Confirmation",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation.",
+    "Conversation token" : "Conversation token",
+    "A token representing the conversation." : "A token representing the conversation.",
+    "Generated response" : "Generated response",
+    "The response from the chat model." : "The response from the chat model.",
+    "The new conversation token" : "The new conversation token",
+    "Send this along with the next interaction." : "Send this along with the next interaction.",
+    "Requested actions by the agent" : "Requested actions by the agent",
+    "Actions that the agent would like to carry out in JSON format." : "Actions that the agent would like to carry out in JSON format.",
     "Context write" : "Context write",
     "Writes text in a given style based on the provided source material." : "Writes text in a given style based on the provided source material.",
     "Writing style" : "Writing style",
@@ -338,15 +369,29 @@ OC.L10N.register(
     "Describe a task that you want the assistant to do or ask a question" : "Describe a task that you want the assistant to do or ask a question",
     "Generated reply" : "Generated reply",
     "The generated text from the assistant" : "The generated text from the assistant",
+    "Change Tone" : "Change Tone",
+    "Change the tone of a piece of text." : "Change the tone of a piece of text.",
+    "Write a text that you want the assistant to rewrite in another tone." : "Write a text that you want the assistant to rewrite in another tone.",
+    "Desired tone" : "Desired tone",
+    "In which tone should your text be rewritten?" : "In which tone should your text be rewritten?",
+    "The rewritten text in the desired tone, written by the assistant:" : "The rewritten text in the desired tone, written by the assistant:",
     "Chat" : "Chat",
     "Chat with the assistant" : "Chat with the assistant",
     "System prompt" : "System prompt",
     "Define rules and assumptions that the assistant should follow during the conversation." : "Define rules and assumptions that the assistant should follow during the conversation.",
-    "Chat message" : "Chat message",
     "Chat history" : "Chat history",
     "The history of chat messages before the current message, starting with a message by the user" : "The history of chat messages before the current message, starting with a message by the user",
     "Response message" : "Response message",
     "The generated response as part of the conversation" : "The generated response as part of the conversation",
+    "Chat with tools" : "Chat with tools",
+    "Chat with the language model with tool calling support." : "Chat with the language model with tool calling support.",
+    "Tool message" : "Tool message",
+    "The result of tool calls in the last interaction" : "The result of tool calls in the last interaction",
+    "Available tools" : "Available tools",
+    "The available tools in JSON format" : "The available tools in JSON format",
+    "The response from the chat model" : "The response from the chat model",
+    "Tool calls" : "Tool calls",
+    "Tools call instructions from the model in JSON format" : "Tools call instructions from the model in JSON format",
     "Formalize text" : "Formalize text",
     "Takes a text and makes it sound more formal" : "Takes a text and makes it sound more formal",
     "Write a text that you want the assistant to formalize" : "Write a text that you want the assistant to formalize",
@@ -357,6 +402,12 @@ OC.L10N.register(
     "Original text" : "Original text",
     "The original text to generate a headline for" : "The original text to generate a headline for",
     "The generated headline" : "The generated headline",
+    "Proofread" : "Proofread",
+    "Proofreads a text and lists corrections" : "Proofreads a text and lists corrections",
+    "Text" : "Text",
+    "The text to proofread" : "The text to proofread",
+    "Corrections" : "Corrections",
+    "The corrections that should be made in your text" : "The corrections that should be made in your text",
     "Reformulate text" : "Reformulate text",
     "Takes a text and reformulates it" : "Takes a text and reformulates it",
     "Write a text that you want the assistant to reformulate" : "Write a text that you want the assistant to reformulate",
@@ -393,32 +444,19 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Summarizes text by reducing its length without losing key information.",
     "Extracts topics from a text and outputs them separated by commas." : "Extracts topics from a text and outputs them separated by commas.",
     "Education Edition" : "Education Edition",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Logged in user must be an admin, a sub-admin or has special right to access this setting",
-    "Logged in user must be an admin or sub admin" : "Logged in user must be an admin or sub admin",
-    "Logged in user must be an admin" : "Logged in user must be an admin",
     "File name is a reserved word" : "File name is a reserved word",
     "File name contains at least one invalid character" : "File name contains at least one invalid character",
     "File name is too long" : "File name is too long",
-    "Help" : "Help",
     "Users" : "Users",
-    "Unknown user" : "Unknown user",
-    "Enter the database username and name for %s" : "Enter the database username and name for %s",
-    "Enter the database username for %s" : "Enter the database username for %s",
-    "MySQL username and/or password not valid" : "MySQL username and/or password not valid",
-    "Oracle username and/or password not valid" : "Oracle username and/or password not valid",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL username and/or password not valid",
-    "Set an admin username." : "Set an admin username.",
-    "Sharing %s failed, because this item is already shared with user %s" : "Sharing %s failed, because this item is already shared with user %s",
-    "The username is already being used" : "The username is already being used",
-    "Could not create user" : "Could not create user",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"",
-    "A valid username must be provided" : "A valid username must be provided",
-    "Username contains whitespace at the beginning or at the end" : "Username contains whitespace at the beginning or at the end",
-    "Username must not consist of dots only" : "Username must not consist of dots only",
-    "Username is invalid because files already exist for this user" : "Username is invalid because files already exist for this user",
-    "User disabled" : "User disabled",
-    "Your data directory is readable by other users." : "Your data directory is readable by other users.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Please change the permissions to 0770 so that the directory cannot be listed by other users.",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s shared »%2$s« with you and wants to add:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
+    "»%s« added a note to a file shared with you" : "»%s« added a note to a file shared with you",
+    "Open »%s«" : "Open »%s«",
+    "%1$s shared »%2$s« with you" : "%1$s shared »%2$s« with you",
+    "%1$s shared »%2$s« with you." : "%1$s shared »%2$s« with you.",
+    "Click the button below to open it." : "Click the button below to open it.",
+    "File is currently busy, please try again later" : "File is currently busy, please try again later",
+    "Cannot download file" : "Cannot download file",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ensure there is a file called \".ocdata\" in the root of the data directory."
 },
 "nplurals=2; plural=(n != 1);");
