@@ -19,7 +19,7 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s y %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s y %5$s",
-    "Education Edition" : "Edición Educativa",
+    "Education bundle" : "Paquete de educación",
     "Enterprise bundle" : "Paquete empresarial",
     "Groupware bundle" : "Paquete de Groupware",
     "Hub bundle" : "Paquete Hub",
@@ -58,6 +58,7 @@ OC.L10N.register(
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
     "Files" : "Archivos",
     "View profile" : "Ver perfil",
+    "_%nh_::_%nh_" : ["%nh","%nh","%nh"],
     "Local time: %s" : "Hora local: %s",
     "today" : "hoy",
     "tomorrow" : "mañana",
@@ -80,26 +81,29 @@ OC.L10N.register(
     "seconds ago" : "hace segundos",
     "Empty file" : "Archivo vacío",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID: %sno existe. Por favor hablíitalo en tus configuraciones de aplicación o contacta a tu administrador.  ",
+    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
+    "Invalid parent path" : "Ruta de carpeta superior inválida",
     "File already exists" : "El archivo ya existe",
     "Invalid path" : "Ruta inválida",
     "Failed to create file from template" : "No se pudo crear un archivo desde la plantilla",
     "Templates" : "Plantillas",
-    "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
-    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
-    "File name is too long" : "El nombre del archivo es demasiado largo",
-    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
+    "Path contains invalid segments" : "La ruta contiene segmentos inválidos",
+    "Filename is a reserved word" : "El nombre de archivo es una palabra reservada",
+    "Filename contains at least one invalid character" : "El nombre del archivo contiene al menos un carácter inválido",
+    "Filename is too long" : "El nombre del archivo es demasiado largo",
     "Empty filename is not allowed" : "El uso de nombres de archivo vacíos no está permitido",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "La aplicación \"%s\" no puede ser instalada porque el archivo appinfo no se puede leer. ",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "La aplicación \"%s\" no puede ser instalada porque no es compatible con esta versión del servidor. ",
     "__language_name__" : "Español (México)",
     "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, por favor no lo contestes. ",
+    "Help & privacy" : "Ayuda y privacidad",
     "Appearance and accessibility" : "Apariencia y accesibilidad",
     "Apps" : "Aplicaciones",
     "Personal settings" : "Configuración personal",
     "Administration settings" : "Configuración de administración",
     "Settings" : "Ajustes",
     "Log out" : "Cerrar sesión",
-    "Users" : "Usuarios",
+    "Accounts" : "Cuentas",
     "Email" : "Correo electrónico",
     "Mail %s" : "Correo %s",
     "Fediverse" : "Fediverso",
@@ -117,6 +121,7 @@ OC.L10N.register(
     "Headline" : "Título",
     "Organisation" : "Organización",
     "Role" : "Cargo",
+    "Pronouns" : "Pronombre",
     "Unknown account" : "Cuenta desconocida",
     "Additional settings" : "Configuraciones adicionales",
     "Enter the database Login and name for %s" : "Introduzca el usuario y el nombre para la base de datos %s",
@@ -128,7 +133,6 @@ OC.L10N.register(
     "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
     "Oracle Login and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
     "PostgreSQL Login and/or password not valid" : "Usuario y/o contraseña de PostgreSQL inválidos",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "OS X de Mac no está soportado y %s no funcionará correctamente en esta plataforma ¡Úsalo bajo tu propio riesgo!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para mejores resultados, por favor cosidera usar en su lugar un servidor GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Al parecer esta instancia %s está corriendo en un ambiente PHP de 32-bits y el open_basedir ha sido configurado en el archivo php.ini. Esto generará problemas con archivos de más de 4GB de tamaño y es altamente desalentado. ",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor elimina el ajuste open_basedir de tu archivo php.ini o cambia a PHP de 64 bits. ",
@@ -138,26 +142,55 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "No fue encontrado el Backend que comparte %s ",
     "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartió »%2$s« contigo y quiere añadir:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartió »%2$s« contigo y quiere añadir",
-    "»%s« added a note to a file shared with you" : "»%s« añadió una nota a un archivo compartido contigo",
-    "Open »%s«" : "Abrir »%s«",
+    "%1$s shared %2$s with you" : "%1$s le compartió %2$s",
+    "Open %s" : "Abrir %s",
     "%1$s via %2$s" : "%1$s vía %2$s",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s le compartió %2$s y quiere añadir:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s le compartió %2$s y quiere añadir",
+    "%s added a note to a file shared with you" : "%s añadió una nota a un archivo compartido con Ud.",
+    "Passwords are enforced for link and mail shares" : "Las contraseñas son obligatorias para las comparticiones por enlaces y correos",
+    "Share recipient is not a valid user" : "El nombre de usuario receptor del recurso compartido no es válido",
+    "Share recipient is not a valid group" : "El grupo receptor del recurso compartido no es válido",
+    "Share recipient should be empty" : "El receptor del recurso compartido debe estar vacío",
+    "Share recipient should not be empty" : "El receptor del recurso compartido no debe estar vacío",
+    "Share recipient is not a valid circle" : "El círculo receptor del recurso compartido no es válido",
+    "Unknown share type" : "Tipo de elemento compartido desconocido",
+    "Share initiator must be set" : "Se debe definir el iniciador del recurso compartido",
+    "Cannot share with yourself" : "No puedes compartir contigo mismo",
+    "Shared path must be set" : "La ruta del recurso compartido debe ser definida",
+    "Shared path must be either a file or a folder" : "La ruta del recurso compartido debe ser un archivo o una carpeta",
+    "You cannot share your root folder" : "No puedes compartir tu carpeta principal",
     "You are not allowed to share %s" : "No tienes permitido compartir %s",
+    "Valid permissions are required for sharing" : "Se requieren permisos válidos para compartir",
     "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
+    "Shares need at least read permissions" : "Los recursos compartidos requieren al menos permisos de lectura",
     "Files cannot be shared with delete permissions" : "No se pueden compartir archivos con permisos de eliminación",
     "Files cannot be shared with create permissions" : "No se pueden compartir archivos con permisos de creación",
     "Expiration date is in the past" : "La fecha de expiración se encuentra en el pasado",
+    "Expiration date is enforced" : "La fecha de vencimiento es obligatoria",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["No se puede fijar la fecha de caducidad más de %n día en el futuro","No se puede fijar la fecha de caducidad más de %n días en el futuro","No se puede fijar la fecha de caducidad más de %n días en el futuro"],
     "Sharing is only allowed with group members" : "Sólo está permitido compartir a los miembros del grupo",
     "Sharing %s failed, because this item is already shared with the account %s" : "No se pudo compartir %s porque este elemento ya está compartido con el usuario %s",
-    "%1$s shared »%2$s« with you" : "%1$s compartió »%2$s« contigo",
-    "%1$s shared »%2$s« with you." : "%1$s compartió »%2$s« contigo.",
-    "Click the button below to open it." : "Haz click en el botón inferior para abrirlo. ",
+    "Group sharing is now allowed" : "La compartición con grupos está ahora permitida",
+    "Sharing is only allowed within your own groups" : "Solo es posible compartir con grupos de los que se es miembro",
+    "Path is already shared with this group" : "La ruta ya ha sido compartida con este grupo",
+    "Link sharing is not allowed" : "La compartición mediante enlaces no está permitida",
+    "Public upload is not allowed" : "No se permite la subida pública de archivos",
+    "Path contains files shared with you" : "La ruta contiene archivos compartidos contigo",
+    "Sharing is disabled" : "Compartir está deshabilitado",
+    "Sharing is disabled for you" : "No estás habilitado para compartir",
+    "Cannot share with the share owner" : "No puedes compartir con el propietario del recurso compartido",
+    "Share does not have a full ID" : "El recurso compartido no tiene una ID completa",
+    "Cannot change share type" : "No se puede cambiar el tipo de compartición",
+    "Can only update recipient on user shares" : "Solo se puede actualizar el receptor en recursos compartidos propios",
+    "Cannot enable sending the password by Talk with an empty password" : "No puede habilitarse el envío de contraseñas vía Talk utilizando una contraseña en blanco",
+    "Cannot enable sending the password by Talk without setting a new password" : "No puede habilitarse el envío de contraseñas vía Talk sin establecer una nueva contraseña",
     "The requested share does not exist anymore" : "El recurso compartido solicitado ya no existe",
     "The requested share comes from a disabled user" : "El recurso compartido solicitado proviene de un usuario deshabilitado",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "No se creó el usuario porque se ha alcanzado el límite de usuarios. Consulta tus notificaciones para obtener más información.",
     "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
+    "Input text" : "Ingresar texto",
+    "The input text" : "El texto de entrada",
     "Sunday" : "Domingo",
     "Monday" : "Lunes",
     "Tuesday" : "Martes",
@@ -215,8 +248,6 @@ OC.L10N.register(
     "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "No se puede instalar la aplicación \"%1$s\" porque no se cumple con las siguientes dependencias: %2$s ",
     "a safe home for all your data" : "un lugar seguro para todos tus datos",
-    "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, por favor intentalo más tarde. ",
-    "Cannot download file" : "No se puede descargar el archivo",
     "Application is not enabled" : "La aplicación está deshabilitada",
     "Authentication error" : "Error de autenticación",
     "Token expired. Please reload page." : "La ficha ha expirado. Por favor recarga la página.",
@@ -249,7 +280,7 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "Su directorio de datos debe ser una ruta absoluta.",
     "Check the value of \"datadirectory\" in your configuration." : "Revise el valor de \"datadirectory\" en su configuración.",
     "Your data directory is invalid." : "Su directorio de datos es inválido.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegurate de que exista una archivo llamado \".ocdata\" en la raíz del directorio de datos. ",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Asegúrese que exista un archivo llamado \"%1$s\" en la raíz del directorio de datos. Debería contener: \"%2$s\"",
     "Action \"%s\" not supported or implemented." : "La acción \"%s\" no está soportada o no está implementada.",
     "Authentication failed, wrong token or provider ID given" : "Falló la autentificación, se proporcionó un token o un identificador de proveedor incorrecto",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Faltan parámetros para completar la solicitud. Parámetros faltantes: \"%s\"",
@@ -261,38 +292,107 @@ OC.L10N.register(
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
+    "Transcribe audio" : "Transcribir audio",
+    "Transcribe the things said in an audio" : "Transcribir lo que se dice en un audio",
+    "Audio input" : "Entrada de audio",
+    "The audio to transcribe" : "El audio a transcribir",
+    "Transcription" : "Transcripción",
+    "The transcribed text" : "El texto transcrito",
+    "Chat message" : "Mensaje de chat",
+    "Confirmation" : "Confirmación",
+    "Writes text in a given style based on the provided source material." : "Escribe el texto en un estilo dado basándose en el material fuente proporcionado.",
+    "Writing style" : "Estilo de escritura",
+    "Demonstrate a writing style that you would like to immitate" : "Demostrar un estilo de escritura que le gustaría imitar",
+    "Source material" : "Material fuente",
+    "The content that would like to be rewritten in the new writing style" : "El contenido que desea sea reescrito en un nuevo estilo de escritura",
+    "Generated text" : "Texto generado",
+    "The generated text with content from the source material in the given style" : "El texto generado con el contenido del material fuente en el estilo dado",
+    "Emoji generator" : "Generador de emojis",
+    "Takes text and generates a representative emoji for it." : "Toma un texto y genera un emoji representativo para éste.",
+    "The text to generate an emoji for" : "El texto para generar un emoji",
+    "Generated emoji" : "Emoji generado",
+    "The generated emoji based on the input text" : "El emoji generado basado en el texto de entrada",
+    "Generate image" : "Generar imagen",
+    "Generate an image from a text prompt" : "Generar una imagen desde un texto",
+    "Prompt" : "Prompt",
+    "Describe the image you want to generate" : "Describa la imagen que quiere generar",
+    "Number of images" : "Número de imágenes",
+    "How many images to generate" : "Cuántas imágenes generar",
+    "Output images" : "Salida de imágenes",
+    "The generated images" : "Las imágenes generadas",
+    "Free text to text prompt" : "Texto libre a prompt de texto",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "Ejecuta un prompt arbitrario a través de un modelo de lenguaje que regresa una respuesta",
+    "Describe a task that you want the assistant to do or ask a question" : "Describa una tarea que quiere que haga el asistente o haga una pregunta",
+    "Generated reply" : "Respuesta generada",
+    "The generated text from the assistant" : "El texto generado por el asistente",
+    "Chat" : "Chat",
+    "Chat with the assistant" : "Conversar con el asistente",
+    "System prompt" : "Prompt del sistema",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Define las reglas y suposiciones que el asistente debe seguir durante la conversación.",
+    "Chat history" : "Historial de la conversación",
+    "The history of chat messages before the current message, starting with a message by the user" : "El historial de mensajes del chat antes del mensaje actual, empezando con un mensaje de usuario",
+    "Response message" : "Mensaje de respuesta",
+    "The generated response as part of the conversation" : "La respuesta generada como parte de la conversación",
+    "Formalize text" : "Formalizar texto",
+    "Takes a text and makes it sound more formal" : "Toma un texto y lo hace sonar más formal",
+    "Write a text that you want the assistant to formalize" : "Escriba un texto que quiere que el asistente formalice",
+    "Formalized text" : "Texto formalizado",
+    "The formalized text" : "El texto formalizado",
+    "Generate a headline" : "Generar un titular",
+    "Generates a possible headline for a text." : "Genera un posible titular para un texto.",
+    "Original text" : "Texto original",
+    "The original text to generate a headline for" : "El texto original para generar un titular",
+    "The generated headline" : "El titular generado",
+    "Text" : "Texto",
+    "Reformulate text" : "Reformular texto",
+    "Takes a text and reformulates it" : "Toma un texto y lo reformula",
+    "Write a text that you want the assistant to reformulate" : "Escriba un texto que quiere que el asistente reformule",
+    "Reformulated text" : "Texto reformulado",
+    "The reformulated text, written by the assistant" : "El texto reformulado, escrito por el asistente",
+    "Simplify text" : "Simplificar texto",
+    "Takes a text and simplifies it" : "Toma un texto y lo simplifica",
+    "Write a text that you want the assistant to simplify" : "Escriba un texto que quiere que el asistente simplifique",
+    "Simplified text" : "Texto simplificado",
+    "The simplified text" : "El texto simplificado",
+    "Summarize" : "Resumir",
+    "Summarizes a text" : "Resume un texto",
+    "The original text to summarize" : "El texto original a resumir",
+    "Summary" : "Resumen",
+    "The generated summary" : "El resumen generado",
+    "Extract topics" : "Extraer temas",
+    "Extracts topics from a text and outputs them separated by commas" : "Extrae temas desde un texto y los muestra separados por comas",
+    "The original text to extract topics from" : "El texto original desde donde extraer los temas",
+    "Topics" : "Temas",
+    "The list of extracted topics" : "La lista de temas extraídos",
+    "Translate" : "Traducir",
+    "Translate text from one language to another" : "Traducir texto de un idioma a otro",
+    "Origin text" : "Texto de origen",
+    "The text to translate" : "El texto a traducir",
+    "Origin language" : "Idioma de origen",
+    "The language of the origin text" : "El idioma del texto de origen",
+    "Target language" : "Idioma destino",
+    "The desired language to translate the origin text in" : "El idioma deseado a traducir el texto de origen",
+    "Result" : "Resultado",
+    "The translated text" : "El texto traducido",
     "Free prompt" : "Liberar prompt",
     "Runs an arbitrary prompt through the language model." : "Ejecuta un prompt arbitrario a través del modelo de lenguaje.",
     "Generate headline" : "Generar titular",
-    "Generates a possible headline for a text." : "Genera un posible titular para un texto.",
-    "Summarize" : "Resumir",
     "Summarizes text by reducing its length without losing key information." : "Resume el texto reduciendo su longitud sin perder información clave.",
-    "Extract topics" : "Extraer temas",
     "Extracts topics from a text and outputs them separated by commas." : "Extrae los temas de un texto y genera una salida separada por comas. ",
-    "404" : "404",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "El usuario que ha iniciado sesión debe ser un administrador, un subadministrador o tener permisos especiales para acceder a esta configuración",
-    "Logged in user must be an admin or sub admin" : "El usuario conectado debe ser un administrador o un subadministrador",
-    "Logged in user must be an admin" : "El usuario firmado debe ser un administrador",
-    "Help" : "Ayuda",
-    "Unknown user" : "Ususario desconocido",
-    "Enter the database username and name for %s" : "Introduzca el usuario y el nombre para la base de datos %s",
-    "Enter the database username for %s" : "Introduzca el usuario de la base de datos %s",
-    "MySQL username and/or password not valid" : "Usuario y/o contraseña de MySQL inválidos",
-    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
-    "PostgreSQL username and/or password not valid" : "El Usuario y/o Contraseña de PostgreSQL inválido(s)",
-    "Set an admin username." : "Establecer un Usuario administrador",
-    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
-    "The username is already being used" : "Ese usuario ya está en uso",
-    "Could not create user" : "No fue posible crear el usuario",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Sólo los siguientes caracteres están permitidos en un nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", espacios y \"_.@-'\"",
-    "A valid username must be provided" : "Debes proporcionar un nombre de usuario válido",
-    "Username contains whitespace at the beginning or at the end" : "El usuario contiene un espacio en blanco al inicio o al final",
-    "Username must not consist of dots only" : "El usuario no debe consistir de solo puntos. ",
-    "Username is invalid because files already exist for this user" : "El nombre de usuario es inválido porque ya existen archivos para éste",
-    "User disabled" : "Usuario deshabilitado",
-    "PostgreSQL >= 9 required." : "Se requiere PostgreSQL >= 9.",
-    "Please upgrade your database version." : "Por favor, actualice la versión de la base de datos.",
-    "Your data directory is readable by other users." : "Su directorio de datos puede ser leído por otros usuarios.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambia los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. "
+    "Education Edition" : "Edición Educativa",
+    "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
+    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
+    "File name is too long" : "El nombre del archivo es demasiado largo",
+    "Users" : "Usuarios",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartió »%2$s« contigo y quiere añadir:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartió »%2$s« contigo y quiere añadir",
+    "»%s« added a note to a file shared with you" : "»%s« añadió una nota a un archivo compartido contigo",
+    "Open »%s«" : "Abrir »%s«",
+    "%1$s shared »%2$s« with you" : "%1$s compartió »%2$s« contigo",
+    "%1$s shared »%2$s« with you." : "%1$s compartió »%2$s« contigo.",
+    "Click the button below to open it." : "Haz click en el botón inferior para abrirlo. ",
+    "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, por favor intentalo más tarde. ",
+    "Cannot download file" : "No se puede descargar el archivo",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegurate de que exista una archivo llamado \".ocdata\" en la raíz del directorio de datos. "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
