@@ -38,6 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Потрібна версія сервера %s або вище.",
     "Server version %s or lower is required." : "Потрібна версія сервера %s або нижча.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Обліковий запис для входу має бути адміністратором, заступником адміністратора або мати спеціальні права доступу до цих налаштувань.",
+    "Your current IP address doesn't allow you to perform admin actions" : "Ваша поточна адреса IP не дозволяє вам виконувати адміністративні дії",
     "Logged in account must be an admin or sub admin" : "Обліковий запис для входу має бути адміністратором, заступником адміністратора",
     "Logged in account must be an admin" : "Обліковий запис для входу має бути адміністратором",
     "Wiping of device %s has started" : "Розпочато очищення пристрою %s",
@@ -58,6 +59,11 @@ OC.L10N.register(
     "Avatar image is not square" : "Зображення аватара не квадратне",
     "Files" : "Файли",
     "View profile" : "Перегляд профілю",
+    "same time" : "той саме час",
+    "_%nh_::_%nh_" : ["%n год","%n год","%n год","%n год"],
+    "_%nm_::_%nm_" : ["%n хв","%n хв","%n хв","%n хв"],
+    "%s ahead" : "%s попереду",
+    "%s behind" : "%s позаду",
     "Local time: %s" : "Місцевий час: %s",
     "today" : "сьогодні",
     "tomorrow" : "завтра",
@@ -80,12 +86,34 @@ OC.L10N.register(
     "seconds ago" : "кілька секунд тому",
     "Empty file" : "Порожній файл",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модуль з ID: %s не існує. Будь ласка, увімкніть це в налаштуваннях застосунку або зверніться до адміністратора.",
+    "No file conversion providers available" : "Відсутні постачальники послуг з конвертування",
+    "File is too large to convert" : "Файл завеликий для конвертування",
+    "Destination does not match conversion extension" : "Призначення не відповідає розширенню конвертування",
+    "Could not convert file" : "Неможливо сконвертувати файл",
+    "Destination does not exist" : "Призначення відсутнє",
+    "Destination is not creatable" : "Неможливо створити призначення",
     "Dot files are not allowed" : "Файли які починаються з крапки не допустимі",
+    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" є недозволеним ім'ям файлів або каталогів.",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" є недозволеним префіксом у іменах файлів або каталоів.",
+    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" не дозволено всередині імени файлів або каталогів.",
+    "\"%1$s\" is a forbidden file type." : "\"%1$s\" є недозволеним типом файлів.",
+    "Filenames must not end with \"%1$s\"." : "Ім'я файлу не може закінчуватися на \"%1$s\".",
+    "Invalid parent path" : "Недійсний батьківський шлях",
     "File already exists" : "Файл вже існує",
     "Invalid path" : "Недійсний шлях",
     "Failed to create file from template" : "Не вдалося створити файл із шаблону",
     "Templates" : "Шаблони",
+    "Storage %s cannot be moved" : "Неможливо перемістити сховище даних %s",
+    "Moving a share (%s) into a shared folder is not allowed" : "Переміщення спільного ресурсу (%s) до спільного каталогу не дозволено",
+    "Moving a storage (%s) into a shared folder is not allowed" : "Переміщення сховища (%s) до спільного каталогу не дозволено",
+    "Moving a share (%s) into another share (%s) is not allowed" : "Переміщення спільного ресурсу (%s) до іншого спільного ресурсу (%s) не дозволено",
+    "Moving a share (%s) into another storage (%s) is not allowed" : "Переміщення спільного ресурсу (%s) до іншого сховища (%s) не дозволено",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "Переміщення сховища (%s) до спільного ресурсу (%s) не дозволено",
+    "Moving a storage (%s) into another storage (%s) is not allowed" : "Переміщення сховища (%s) до іншого сховища (%s) не дозволено",
+    "Path contains invalid segments" : "Шлях містить недійсні елементи в назві",
+    "Filename is a reserved word" : "Ім'я файлу є зарезервованим словом",
     "Filename contains at least one invalid character" : "У назві файлу міститься щонайменше один неправильний символ",
+    "Filename is too long" : "Ім'я файлу задовге",
     "Empty filename is not allowed" : "Порожні імена файлів не допускаються",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Застосунок \"%s\" не може бути встановлений через те, що файл appinfo не може бути прочитано.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Застосунок \"%s\" неможливо встановити, оскільки він не сумісний з цією версією сервера.",
@@ -110,12 +138,13 @@ OC.L10N.register(
     "Website" : "Вебсайт",
     "Visit %s" : "Відвідайте %s",
     "Address" : "Адреса",
-    "Profile picture" : "Зображення облікового запису",
+    "Profile picture" : "Зображення користувача",
     "About" : "Опис",
     "Display name" : "Ім'я для показу",
     "Headline" : "Заголовок",
     "Organisation" : "Організація",
     "Role" : "Роль",
+    "Pronouns" : "Займенники",
     "Unknown account" : "Невідомий обліковий запис",
     "Additional settings" : "Додатково",
     "Enter the database Login and name for %s" : "Введіть ім’я користувача та назву бази даних для %s",
@@ -127,7 +156,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Не можемо з'єднатися з Oracle ",
     "Oracle Login and/or password not valid" : "Ім'я користувача та/або пароль Oracle не дійсні",
     "PostgreSQL Login and/or password not valid" : "Ім'я користувача та/або пароль PostgreSQL не дійсні",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не підтримується і %s не буде коректно працювати на цій платформі. Випробовуєте на свій риск!",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X не підтримується, отже %s не працюватиме належним чиним на цій платформі. Використовуйте на ваш страх і ризик.",
     "For the best results, please consider using a GNU/Linux server instead." : "Для кращих результатів розгляньте можливість використання GNU/Linux серверу",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Ймовірно, що сервер %s працює в 32-бітному PHP середовищі і open_basedir повинен бути налаштований в php.ini. Це призведе до проблем з файлами більше 4 ГБ і це дуже не рекомендується.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Будь ласка, вилучіть параметр open_basedir у вашому php.ini або перейдіть на 64-бітний PHP.",
@@ -137,27 +166,61 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бекенд спільного доступу %s повинен реалізовувати інтерфейс OCP\\Share_Backend",
     "Sharing backend %s not found" : "Бекенд спільного доступу %s не знайдено",
     "Sharing backend for %s not found" : "Бекенд спільного доступу для %s не знайдено",
-    "%1$s shared »%2$s« with you" : "%1$s надав(-ла) доступ до \"%2$s\"",
-    "%1$s shared »%2$s« with you." : "%1$s надав(-ла) доступ до \"%2$s\".",
-    "Click the button below to open it." : "Щоб відкрити файл, натисніть кнопку нижче.",
-    "Open »%s«" : "Відкрити %s",
+    "%1$s shared %2$s with you" : "%1$s поділив(ла)ся %2$s з вами",
+    "Open %s" : "Відкрити %s",
     "%1$s via %2$s" : "%1$s через %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s надав(-ла) доступ до \"%2$s\" та хоче додати:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s надав(-ла) доступ до \"%2$s\" та хоче додати",
-    "»%s« added a note to a file shared with you" : "\"%s\" додано примітку до файлу у спільному доступі",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s поділив(ла)ся %2$s з вами та бажає додати:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s поділив(ла)ся %2$s з вами та бажає додати",
+    "%s added a note to a file shared with you" : "%s додав(-ла) примітку до файлу, яким поділилися з вами",
+    "Passwords are enforced for link and mail shares" : "Для надання доступу до спільних ресурсів через посилання та ел. пошту має бути встановлено пароль на ресурс",
+    "Share recipient is not a valid user" : "Такий отримувач спільного ресурсу відсутній",
+    "Share recipient is not a valid group" : "Така група спільного ресурсу відсутня",
+    "Share recipient should be empty" : "Значення отримувача ресурсу має бути порожнє",
+    "Share recipient should not be empty" : "Значення отримувача ресурсу не має бути порожнє",
+    "Share recipient is not a valid circle" : "Отримувач ресурсу відсутній у застосунку \"Кола\"",
     "Unknown share type" : "Невідомий тип спільного ресурсу",
+    "Share initiator must be set" : "Потрібно встановити ініціатора надання ресурсу у спільний доступ",
+    "Cannot share with yourself" : "Неможливо поділитися з самим(-ою) собою",
+    "Shared path must be set" : "Потрібно встановити шлях спільного ресурсу",
+    "Shared path must be either a file or a folder" : "Шлях спільного ресурсу має бути або файлом, або каталогом",
+    "You cannot share your root folder" : "Ви не можете надавати у спільний доступ кореневий каталог",
     "You are not allowed to share %s" : "Вам заборонено поширювати %s",
+    "Valid permissions are required for sharing" : "Потрібний чинний дозвіл для надання у спільний доступ",
+    "File shares cannot have create or delete permissions" : "Відсутні дозволи сторення або вилучення для спільних файлів",
     "Cannot increase permissions of %s" : "Не вдалося підвищити дозволи для %s",
+    "Shares need at least read permissions" : "Для спільних ресурсів має визначено щонайменше дозвіл на читання",
     "Files cannot be shared with delete permissions" : "Не можна надавати у спільний доступ файли з дозволами на вилучення",
     "Files cannot be shared with create permissions" : "Не можна ділитися файлами з дозволом на створення",
     "Expiration date is in the past" : "Дата закінчення в минулому",
+    "Expiration date is enforced" : "Потрібно встановити термін завершення доступу",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможливо встановити дату закінчення більше ніж %n день у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому"],
     "Sharing is only allowed with group members" : "Спільний доступ дозволений лише для учасників групи",
     "Sharing %s failed, because this item is already shared with the account %s" : "Не вдалося надати у спільний доступ%s, оскільки цей ресурс вже у спільному доступі з обліковим записом %s",
+    "Group sharing is now allowed" : "Тепер дозволено спільний доступ для груп",
+    "Sharing is only allowed within your own groups" : "Спільний доступ дозволено в рамках ваших груп",
+    "Path is already shared with this group" : "Шлях вже надано у спільний доступ для цієї групи",
+    "Link sharing is not allowed" : "Спільний доступ через посилання не дозволено",
+    "Public upload is not allowed" : "Публічні завантаження не дозволено",
+    "Path contains files shared with you" : "Шлях містить файли, якими поділилися з вами",
+    "Sharing is disabled" : "Спільний доступ вимкнено",
+    "Sharing is disabled for you" : "Ви не маєте права надавати у доступ файли або каталоги",
+    "Cannot share with the share owner" : "Неможливо надавати у доступ власникові спільного ресурсу",
+    "Share does not have a full ID" : "Спільний ресурс не має повного ідентифікатора",
+    "Cannot change share type" : "Неможливо змінити тип спільного ресурсу",
+    "Can only update recipient on user shares" : "Можна лише оновити отримувача для спільних ресурсів користувача",
+    "Cannot enable sending the password by Talk with an empty password" : "Не вдалося увімкнути надсилання паролю за допомогою Talk з порожнім паролем",
+    "Cannot enable sending the password by Talk without setting a new password" : "Не вдалося увімкнути надсилання паролю за допомогою Talk без встановлення нового паролю",
+    "Cannot disable sending the password by Talk without setting a new password" : "Не вдалося вимкнути надсилання паролю за допомогою Talk без встановлення нового паролю",
+    "Share provider does not support accepting" : "Провайдер спільного доступу не підтримує прийняття",
+    "Cannot change target of link share" : "Неможливо змінити призначення для спільного ресурсу через посилання",
+    "Invalid share recipient" : "Недійсний отримувач спільного ресурсу",
+    "Group \"%s\" does not exist" : "Група \"%s\" відсутня",
     "The requested share does not exist anymore" : "Запитуваний спільний ресурс більше недоступний",
     "The requested share comes from a disabled user" : "Отримано запит на спільний доступ від неактивного користувача",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Користувача не створено, оскільки досягнуто обмеження на кількість користувачів. Перевірте сповіщення для докладної інформації.",
     "Could not find category \"%s\"" : "Не вдалося знайти категорію \"%s\"",
+    "Input text" : "Текст для введення",
+    "The input text" : "Текст для введення",
     "Sunday" : "Неділя",
     "Monday" : "Понеділок",
     "Tuesday" : "Вівторок",
@@ -203,7 +266,7 @@ OC.L10N.register(
     "Oct." : "Жов.",
     "Nov." : "Лис.",
     "Dec." : "Гру.",
-    "A valid password must be provided" : "Потрібно задати вірний пароль",
+    "A valid password must be provided" : "Потрібно зазначити дійсний пароль",
     "The Login is already being used" : "Це ім'я облікового запису вже використовується",
     "Could not create account" : "Не вдалося створити обліковий запис",
     "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Лише такі символи дозволено у імені облікового запису: \"a-z\", \"A-Z\", \"0-9\", пробіл та \"_.@-'\"",
@@ -214,9 +277,7 @@ OC.L10N.register(
     "Account disabled" : "Обліковий запис вимкнено",
     "Login canceled by app" : "Вхід скасовано застосунком",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Застосунок \"%1$s\" неможливо встановити, оскільки не виконано такі залежності: %2$s",
-    "a safe home for all your data" : "безпечний дім для ваших даних",
-    "File is currently busy, please try again later" : "Файл на разі зайнятий, будь ласка, спробуйте пізніше",
-    "Cannot download file" : "Неможливо звантажити файл",
+    "a safe home for all your data" : "безпечна домівка для ваших даних",
     "Application is not enabled" : "Застосунок не увімкнено",
     "Authentication error" : "Помилка авторизації",
     "Token expired. Please reload page." : "Строк дії токена скінчився. Будь ласка, перезавантажте сторінку.",
@@ -249,6 +310,7 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "Ваш каталог даних має бути абсолютним шляхом.",
     "Check the value of \"datadirectory\" in your configuration." : "Перевірте значення «каталогу даних» у вашій конфігурації.",
     "Your data directory is invalid." : "Ваш каталог даних недійсний.",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Перевірте, що в корені каталогу з даними присутній файл \"%1$s\". Він має містити: \"%2$s\"",
     "Action \"%s\" not supported or implemented." : "Дія \"%s\" не підтримується або не реалізована.",
     "Authentication failed, wrong token or provider ID given" : "Помилка авторизації, надано неправильний токен або ідентифікатор постачальника",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Немає параметрів для виконання запиту. Відсутні параметри: \"%s\"",
@@ -260,8 +322,22 @@ OC.L10N.register(
     "Storage connection error. %s" : "Помилка з'єднання зі сховищем. %s",
     "Storage is temporarily not available" : "Сховище тимчасово недоступне",
     "Storage connection timeout. %s" : "Час під'єднання до сховища вичерпався. %s",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Щоби дозволити запуск цієї перевірки, потрібно пересвідчитися, що ваш вебсервер може з'єднуватися з самим собою, що передбачає можливість резолвити та з'єднуватися з одним з `trusted_domains` або `overwrite.cli.url`. Неможливість цього може бути результатом незбігу DNS на стороні сервера або встановленими правилами брандмауера.",
+    "Transcribe audio" : "Транскрибувати аудіо",
+    "Transcribe the things said in an audio" : "Транскрибувати голос",
+    "Audio input" : "Аудіовхід",
+    "The audio to transcribe" : "Аудіо для транскрибування",
+    "The transcribed text" : "Транскрибований текст",
+    "Confirmation" : "Підтвердження",
+    "Writing style" : "Стиль письма",
+    "Generated text" : "Зґенерований текст",
+    "Emoji generator" : "Ґенератор емоційок",
+    "Generated emoji" : "Зґенеровані емоційки",
+    "Generate image" : "Зґенерувати зображення",
+    "Prompt" : "Запрошення",
     "Chat" : "Чат",
     "Generates a possible headline for a text." : "Створює ймовірний заголовок тексту.",
+    "Text" : "Текст",
     "Summarize" : "Підсумок",
     "Summary" : "Загалом",
     "Extract topics" : "Виділити теми",
@@ -274,32 +350,19 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Викокремлює головне у тексті шляхом зменшення довжини тексту без втрати ключової інформації.",
     "Extracts topics from a text and outputs them separated by commas." : "Виділяє теми, які висвітлює текст, зводить їх у перелік, що розділено комами.",
     "Education Edition" : "Для навчання",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Користувач, який увійшов у систему, має бути адміністратором, підадміністратором або мати спеціальні права доступу до цього налаштування",
-    "Logged in user must be an admin or sub admin" : "Увійшовши в систему користувач повинен бути адміністратором або підадміністратором",
-    "Logged in user must be an admin" : "Зареєстрований користувач має бути адміністратором",
     "File name is a reserved word" : "Ім’я файлу є зарезервованим словом",
     "File name contains at least one invalid character" : "Ім’я файлу містить принаймні один некоректний символ",
     "File name is too long" : "Ім’я файлу занадто довге",
-    "Help" : "Допомога",
     "Users" : "Користувачі",
-    "Unknown user" : "Невідомий користувач",
-    "Enter the database username and name for %s" : "Введіть ім’я користувача та назву бази даних %s",
-    "Enter the database username for %s" : "Введіть ім’я користувача бази даних для %s",
-    "MySQL username and/or password not valid" : "Ім'я користувача та/або пароль MySQL недійсні",
-    "Oracle username and/or password not valid" : "Oracle ім'я користувача та/або пароль не дійсні",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL ім'я користувача та/або пароль не дійсні",
-    "Set an admin username." : "Встановіть ім'я адміністратора.",
-    "Sharing %s failed, because this item is already shared with user %s" : "Не вдалося поділитися %s, оскільки %s вже має до нього доступ",
-    "The username is already being used" : "Ім'я користувача вже використовується",
-    "Could not create user" : "Не вдалося створити користувача",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Лише такі символи дозволено у імені користувача: \"a-z\", \"A-Z\", \"0-9\", пробіл та \"_.@-'\"",
-    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
-    "Username contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу в початку або в кінці",
-    "Username must not consist of dots only" : "Ім'я користувача не повинно складатися лише з крапок",
-    "Username is invalid because files already exist for this user" : "Ім'я користувача недійсне, оскільки файли для цього користувача вже існують",
-    "User disabled" : "Користувач виключений",
-    "Your data directory is readable by other users." : "Ваш каталог даних доступний для читання іншим користувачам.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу.",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s надав(-ла) доступ до \"%2$s\" та хоче додати:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s надав(-ла) доступ до \"%2$s\" та хоче додати",
+    "»%s« added a note to a file shared with you" : "\"%s\" додано примітку до файлу у спільному доступі",
+    "Open »%s«" : "Відкрити %s",
+    "%1$s shared »%2$s« with you" : "%1$s надав(-ла) доступ до \"%2$s\"",
+    "%1$s shared »%2$s« with you." : "%1$s надав(-ла) доступ до \"%2$s\".",
+    "Click the button below to open it." : "Щоб відкрити файл, натисніть кнопку нижче.",
+    "File is currently busy, please try again later" : "Файл на разі зайнятий, будь ласка, спробуйте пізніше",
+    "Cannot download file" : "Неможливо звантажити файл",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Переконайтеся, що в корені каталогу даних є файл під назвою \".ocdata\"."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
